* =============================================================================================
*  Replication program for Figure 4:
*  Julien Grenet, YingHua He, and Dorothea Kübler
*  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
*  The Journal of Political Economy
*  28 November 2021
* =============================================================================================

* ---------------------------------------------------------------------- *
* Figure 4 – Offer Arrival, Program Selectivity and Program Desirability *
* ---------------------------------------------------------------------- *

if "${path}" == "" {
	display "{red: ERROR: Specify path to folder containing replication files in current_directory.do and execute script}"
}

global data "${path}\data"
global output "${path}\output"

do "${path}\figures_tables\do\macros.do"

*** COMPUTE MEASURES OF PROGRAM SELECTIVITY/DESIRABILITY

* Compute program desirability measure: program fixed-effect estimates (standardized to have a mean of zero and a unit variance across programs) from a conditional logit model)

use "${data}\main_data.dta", clear
keep if estimation_sample == 1 & feasible == 1

* Convert distance to multiple of 1000 km
replace distance = distance / 1000
gen distance2 = distance^2

clogit_model, y("accepted_pgm") x("early_feasible first_early_feasible distance distance2 same_land") showreg(0)

* Extract program fixed effects
matrix estimates=e(b)'
mat li estimates
local rownames : rowfullnames estimates
local c : word count `rownames'
svmat double estimates, names("pgm_fe")
rename pgm_fe1 pgm_fe
keep pgm_fe 
gen var_name = ""
forvalues i = 1/`c' {
    replace var_name = "`:word `i' of `rownames''" in `i'
}
drop if _n <=5
drop if var_name == ""
destring var_name , gen(pgm_id) i(:_cons)

drop var_name
order pgm_id

tempfile pgm_fe
save `pgm_fe'

* Import all programs in main analysis sample
use "${data}\main_data.dta", clear
keep if estimation_sample == 1 & feasible == 1
keep pgm_id
duplicates drop
destring pgm_id, replace
sort pgm_id
merge 1:1 pgm_id using `pgm_fe'

* Set the base alternative to 0
replace pgm_fe = 0 if missing(pgm_fe)

* Normalize values
egen pgm_desirability = std(pgm_fe)
drop pgm_fe _merge 

tempfile pgm_desirability
save `pgm_desirability'

use "${data}\potential_offers.dta", clear
destring pgm_id, replace
merge m:1 pgm_id using `pgm_desirability'
drop _merge 

* Compute correlation between measures of selectivity/desirability -> 0.17 */

preserve

drop date n_potential_offers
duplicates drop
correlate pgm_selectivity pgm_desirability

restore

sort date pgm_id

*** Mean and and variance of selectivity/desirability measures throughout the DoSV procedure (weighted by number of potential offers)

foreach v in selectivity desirability {
gen n_offers_`v' = n_potential_offers*!missing(pgm_`v')
egen nn_offers_`v' = sum(n_offers_`v'), by(date)
egen tag_`v' = tag(pgm_id date) if !missing(pgm_`v')
egen n_pgm_`v' = total(tag_`v'), by(date)
drop tag_`v'
gen w_`v' = n_offers_`v'/nn_offers_`v'
egen m_`v' = sum(pgm_`v'*w_`v'), by(date)
gen coeff_`v' = n_pgm_`v'/(n_pgm_`v'-1)
gen SS_`v' = (w_`v'^2)*( (pgm_`v' - m_`v')^2)
egen s_`v' = sum(SS_`v'), by(date)
replace s_`v' = sqrt(coeff_`v'*s_`v')
gen T_`v' = invttail(n_pgm_`v', 0.025) if n_pgm_`v' >1
gen lb_`v' = m_`v' - s_`v'*T_`v'
gen ub_`v' = m_`v' + s_`v'*T_`v'

replace m_`v' = . if nn_offers_`v' <150
replace lb_`v' = . if nn_offers_`v' <150
replace ub_`v' = . if nn_offers_`v' <150

drop pgm_`v' n_pgm_`v' n_offers_`v' w_`v' SS_`v' s_`v' T_`v'
}

drop pgm_id n_potential_offers

duplicates drop

tempfile offer_selectivity
save `offer_selectivity'

clear
set obs 41
gen date = mdy(07,15,2015) + _n
format date %d

merge m:1 date using `offer_selectivity'

drop _merge

replace nn_offers_selectivity = 0 if missing(nn_offers_selectivity)
replace nn_offers_desirability = 0 if missing(nn_offers_desirability)

*** FIGURE 4

* A. Program selectivity: Abitur percentile of last admitted applicant

* color

gen up=15000
gen low=0

twoway (rarea up low date if inrange(date,td(17jul2015),td(20jul2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(24jul2015),td(27jul2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(31jul2015),td(03aug2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(07aug2015),td(10aug2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(14aug2015),td(17aug2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(21aug2015),td(24aug2015)), fc(gs15) lc(bg) lw(none)) ///
(bar nn_offers_selectivity date, yaxis(1) barw(0.4) color(navy) ylabel(0(5000)16000, labsize(small) gmax format(%9.0gc) axis(1))) ///
(scatter m_selectivity date, c(l) msize(small) lc(maroon) mc(maroon) yaxis(2) ylabel(0(0.2)1,  labsize(small)  angle(0) axis(2) format(%9.1f)) yscale(range(-1 1.13) axis(2))) ///
(rcap ub_selectivity lb_selectivity date, lcolor(maroon) lwidth(thin) msize(small) yaxis(2)), ///
tlabel(16jul2015(5)25aug2015, labsize(small)  format(%tdMon_dd))  ///
xline(`=d(19aug2015)-0.5', lcolor(red) lpattern(solid) lw(medthick)) ///
graphregion(color(white)) bgcolor(white) ///
xtitle("Date", height(5) axis(1)) ///
ytitle("Number of (potential) offers", axis(1)) ///
ytitle("Average program selectivity",orientation(rvertical) axis(2)) ///
legend(rows(3) order(7 "Number of (potential) offers" 8 "Abitur percentile of last admitted student" 9 "95% confidence intervals")) ///
ttext(16000 1aug2015 "Phase 1", yaxis(1) place(c) size(medsmall) color(black) ) ///
ttext(16000 22aug2015 "Phase 2", yaxis(1) place(c) size(medsmall) color(black) )

graph export "${output}\figure_4a_color.pdf", replace

* black & white

twoway (rarea up low date if inrange(date,td(17jul2015),td(20jul2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(24jul2015),td(27jul2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(31jul2015),td(03aug2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(07aug2015),td(10aug2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(14aug2015),td(17aug2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(21aug2015),td(24aug2015)), fc(gs15) lc(bg) lw(none)) ///
(bar nn_offers_selectivity date, yaxis(1) barw(0.4) fcolor(gs11) lcolor(black) ylabel(0(5000)16000, glcolor(gs15) labsize(small) gmax format(%9.0gc) axis(1))) ///
(scatter m_selectivity date, c(l) msize(small) lc(black) mc(black) yaxis(2) ylabel(0(0.2)1,  labsize(small)  angle(0) axis(2) format(%9.1f)) yscale(range(-1 1.13) axis(2))) ///
(rcap ub_selectivity lb_selectivity date, lcolor(black) lwidth(thin) msize(small) yaxis(2)), ///
tlabel(16jul2015(5)25aug2015, labsize(small) format(%tdMon_dd))  ///
xline(`=d(19aug2015)-0.5', lcolor(black) lpattern(dash) lw(medthick)) ///
graphregion(color(white)) bgcolor(white) ///
xtitle("Date", height(5) axis(1)) ///
ytitle("Number of (potential) offers", axis(1)) ///
ytitle("Average program selectivity",orientation(rvertical) axis(2)) ///
legend(rows(3) order(7 "Number of (potential) offers" 8 "Abitur percentile of last admitted student" 9 "95% confidence intervals")) ///
ttext(16000 1aug2015 "Phase 1", yaxis(1) place(c) size(medsmall) color(black) ) ///
ttext(16000 22aug2015 "Phase 2", yaxis(1) place(c) size(medsmall) color(black) )

graph export "${output}\figure_4a.pdf", replace

* B. Program desirability: based on students' acceptance decisions

* color

twoway (rarea up low date if inrange(date,td(17jul2015),td(20jul2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(24jul2015),td(27jul2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(31jul2015),td(03aug2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(07aug2015),td(10aug2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(14aug2015),td(17aug2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(21aug2015),td(24aug2015)), fc(gs15) lc(bg) lw(none)) ///
(bar nn_offers_desirability date, yaxis(1) barw(0.4) color(navy) ylabel(0(5000)16000, labsize(small) gmax format(%9.0gc) axis(1))) ///
(scatter m_desirability date, c(l) msize(small) lc(maroon) mc(maroon) yaxis(2) ylabel(-1 -0.5 0 0.5 1,  labsize(small)  angle(0) axis(2) format(%9.1f)) yscale(range(-3 2) axis(2))) ///
(rcap ub_desirability lb_desirability date, lcolor(maroon) lwidth(thin) msize(small) yaxis(2)), ///
tlabel(16jul2015(5)25aug2015, labsize(small)  format(%tdMon_dd))  ///
xline(`=d(19aug2015)-0.5', lcolor(red) lpattern(solid) lw(medthick)) ///
graphregion(color(white)) bgcolor(white) ///
xtitle("Date", height(5) axis(1)) ///
ytitle("Number of (potential) offers", axis(1)) ///
ytitle("Average program desirability",orientation(rvertical) axis(2)) ///
legend(rows(3) order(7 "Number of (potential) offers" 8 "Standardized program fixed effects (conditional logit)" 9 "95% confidence intervals")) ///
ttext(16000 1aug2015 "Phase 1", yaxis(1) place(c) size(medsmall) color(black) ) ///
ttext(16000 22aug2015 "Phase 2", yaxis(1) place(c) size(medsmall) color(black) )

graph export "${output}\figure_4b_color.pdf", replace

* B. Program desirability: based on students' acceptance decisions

* black & white

twoway (rarea up low date if inrange(date,td(17jul2015),td(20jul2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(24jul2015),td(27jul2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(31jul2015),td(03aug2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(07aug2015),td(10aug2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(14aug2015),td(17aug2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(21aug2015),td(24aug2015)), fc(gs15) lc(bg) lw(none)) ///
(bar nn_offers_desirability date, yaxis(1) barw(0.4) fcolor(gs11) lcolor(black) ylabel(0(5000)16000, glcolor(gs15) labsize(small) gmax format(%9.0gc) axis(1))) ///
(scatter m_desirability date, c(l) msize(small) lc(black) mc(black) yaxis(2) ylabel(-1 -0.5 0 0.5 1,  labsize(small)  angle(0) axis(2) format(%9.1f)) yscale(range(-3 2) axis(2))) ///
(rcap ub_desirability lb_desirability date, lcolor(black) lwidth(thin) msize(small) yaxis(2)), ///
tlabel(16jul2015(5)25aug2015, labsize(small)  format(%tdMon_dd))  ///
xline(`=d(19aug2015)-0.5', lcolor(black) lpattern(dash) lw(medthick)) ///
graphregion(color(white)) bgcolor(white) ///
xtitle("Date", height(5) axis(1)) ///
ytitle("Number of (potential) offers", axis(1)) ///
ytitle("Average program desirability",orientation(rvertical) axis(2)) ///
legend(rows(3) order(7 "Number of (potential) offers" 8 "Standardized program fixed effects (conditional logit)" 9 "95% confidence intervals")) ///
ttext(16000 1aug2015 "Phase 1", yaxis(1) place(c) size(medsmall) color(black) ) ///
ttext(16000 22aug2015 "Phase 2", yaxis(1) place(c) size(medsmall) color(black) )

graph export "${output}\figure_4b.pdf", replace
