* =============================================================================================
*  Replication program for Figure 6:
*  Julien Grenet, YingHua He, and Dorothea Kübler
*  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
*  The Journal of Political Economy
*  28 November 2021
* =============================================================================================

* --------------------------------------------------------------------------- *
* Figure 6 – Comparing the DA, M-DA, and MB-DA Mechanisms: Simulation Results *
* --------------------------------------------------------------------------- *

if "${path}" == "" {
	display "{red: ERROR: Specify path to folder containing replication files in current_directory.do and execute script}"
}

global output "${path}\output"

* Macro to label y axis
capture program drop ylabel
	program  ylabel
	syntax [, y_min(real 0) y_max(real 0) y_inc(real 0) ]
global ylabel
forval y = `y_min'(`y_inc')`y_max' {
local y_val  = round(`y'/100,0.01)
global ylabel ${ylabel} `y_val' "`y'%"
}

end

*** A. Submitted ROLs

import excel using "${output}/simulation_results.xlsx", sheet("ranking_behavior") firstrow clear

*keep if mechanism == "DA" | mechanism == "M-DA" | mechanism == "BM-DA"

gen same_feas_rol_pct = string(same_feas_rol*100, "%3.1f") + "%"

ylabel, y_min(37) y_max(45) y_inc(1)

* color

twoway (bar same_feas_rol id, barw(0.6) color("180 198 231") lc(gs6)) ///
(scatter same_feas_rol id, msym(none) mlab(same_feas_rol_pct) mlabpos(12) mlabcolor(black) mlabsize(small) ), ///
subtitle(,size(4) bcolor(white)) ///
xtitle("Mechanism",  margin(0 0 0 2) size(medlarge)) ///
xlabel(1 "DA" 2 "M-DA" 3 "BM-DA" , angle(0) labsize(medsmall) ) ///
ylabel(${ylabel}, gmax angle(0) labsize(small) format(%9.2f)) ///
ytitle("Share of students",  margin(0 0 0 0) size(3))  ///
legend(ring(7) col(1)  rows(2) ///
order(1 "% of students ranking ex post" "feasible programs in the order" "of full information preferences") ///
size(medium) bmargin(0 0 0 3)  symp(w) ) ///
graphregion(color(white)) bgcolor(white) graphregion(fcolor(white) margin(0 5 1 2))  xsize(5) ysize(5) aspect(0.72, placement(top)) plotregion(margin(none))

graph export "${output}\figure_6a_color.pdf", replace

* black & white

twoway (bar same_feas_rol id, barw(0.6) color(gs11) lc(gs3)) ///
(scatter same_feas_rol id, msym(none) mlab(same_feas_rol_pct) mlabpos(12) mlabcolor(black) mlabsize(small) ), ///
subtitle(,size(4) bcolor(white)) ///
xtitle("Mechanism",  margin(0 0 0 2) size(medlarge)) ///
xlabel(1 "DA" 2 "M-DA" 3 "BM-DA" , angle(0) labsize(medsmall) ) ///
ylabel(${ylabel}, gmax glcolor(gs15) angle(0) labsize(small) format(%9.2f)) ///
ytitle("Share of students",  margin(0 0 0 0) size(3))  ///
legend(ring(7) col(1)  rows(2) ///
order(1 "% of students ranking ex post" "feasible programs in the order" "of full information preferences") ///
size(medium) bmargin(0 0 0 3)  symp(w) ) ///
graphregion(color(white)) bgcolor(white) graphregion(fcolor(white) margin(0 5 1 2))  xsize(5) ysize(5) aspect(0.72, placement(top)) plotregion(margin(none))

graph export "${output}\figure_6a.pdf", replace

*** B. Expected utility 

import excel using "${output}/simulation_results.xlsx", sheet("expected_utility") firstrow clear

gen worse_same = worse + same
gen worse_same_better = worse + same + better
gen worse_pct = string(worse*100, "%3.1f") + "%" if worse>0.01
gen same_pct = string(same*100, "%3.1f") + "%" if same >0.01
gen better_pct = string(better*100, "%3.1f") + "%" if better >0.01
gen y_worse = 0.5*worse
gen y_same = worse + 0.5*(same)
gen y_better = worse + same + 0.5*(better)

replace same_pct = string(same*100, "%3.1f") + "%" if same <= 0.01
replace y_same = y_same + 0.04 if same <= 0.01

gen xleg = 0.98 if id == 1
replace xleg = 1.02 if id == 2
gen yleg = 0.075 if id == 1
replace yleg = 0.06 if id == 2

* color

twoway (bar worse_same_better id, barw(0.8) fcolor("35 139 69") lc(gs6)) ///
(bar worse_same id, barw(0.8) fcolor("255 237 160") lc(gs6))  ///
(bar worse id, barw(0.8) fcolor("253 141 60") lc(gs6)) ///
(scatter y_worse id, msym(none) mlab(worse_pct) mlabpos(0) mlabcolor(black) mlabsize(small) ) ///
(scatter y_same id, msym(none) mlab(same_pct) mlabpos(0) mlabcolor(black) mlabsize(small) ) ///
(scatter y_better id, msym(none) mlab(better_pct) mlabpos(0) mlabcolor(black) mlabsize(small) ) ///
(line yleg xleg, color(black) lw(vthin)), ///
xlabel(1 `""Full info" "vs." "DA""' 2 `""M-DA" "vs." "DA""' 3 `""BM-DA" "vs." "DA""'  4 `""BM-DA" "vs." "M-DA""', angle(0) labsize(medsmall) ) ///
ylabel(0 "0" .2 "20%" .4  "40%" .6 "60%" .8 "80%" 1 "100%", angle(0) labsize(small) format(%9.2f)) ///
yscale(titlegap(*-5)) ///
ytitle("Share of students", margin(0 0 0 0) size(3) )  ///
legend(subtitle("Expected utility of matching outcome:", size(medsmall) justification(left)) ///
ring(3) col(1)  rows(3) order(1 "Strictly higher                       " 2 "Equal" 3 "Strictly lower") bmargin(0 0 0 3)  symp(w) ) ///
graphregion(color(white)) bgcolor(white) graphregion(fcolor(white) margin(0 0 1 2))  ///
xsize(5) ysize(5) aspect(0.8, placement(top)) plotregion(margin(none))

graph export "${output}\figure_6b_color.pdf", replace

* black & white

twoway (bar worse_same_better id, barw(0.8) fcolor(gs12) lc(gs3)) ///
(bar worse_same id, barw(0.8) fcolor(white) lc(gs3))  ///
(bar worse id, barw(0.8) fcolor(black) lc(gs3)) ///
(scatter y_worse id, msym(none) mlab(worse_pct) mlabpos(0) mlabcolor(white) mlabsize(small) ) ///
(scatter y_same id, msym(none) mlab(same_pct) mlabpos(0) mlabcolor(black) mlabsize(small) ) ///
(scatter y_better id, msym(none) mlab(better_pct) mlabpos(0) mlabcolor(black) mlabsize(small) ) ///
(line yleg xleg, color(black) lw(vthin)), ///
xlabel(1 `""Full info" "vs." "DA""' 2 `""M-DA" "vs." "DA""' 3 `""BM-DA" "vs." "DA""'  4 `""BM-DA" "vs." "M-DA""', angle(0) labsize(medsmall) ) ///
ylabel(0 "0" .2 "20%" .4  "40%" .6 "60%" .8 "80%" 1 "100%", angle(0) glcolor(gs15) labsize(small) format(%9.2f)) ///
yscale(titlegap(*-5)) ///
ytitle("Share of students", margin(0 0 0 0) size(3) )  ///
legend(subtitle("Expected utility of matching outcome:", size(medsmall) justification(left)) ///
ring(3) col(1)  rows(3) order(1 "Strictly higher                       " 2 "Equal" 3 "Strictly lower") bmargin(0 0 0 3)  symp(w) ) ///
graphregion(color(white)) bgcolor(white) graphregion(fcolor(white) margin(0 0 1 2))  ///
xsize(5) ysize(5) aspect(0.8, placement(top)) plotregion(margin(none))

graph export "${output}\figure_6b.pdf", replace
