* =============================================================================================
*  Replication program for Table 1:
*  Julien Grenet, YingHua He, and Dorothea Kübler
*  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
*  The Journal of Political Economy
*  28 November 2021
* =============================================================================================

* ------------------------------------------------------------------------------- *
* Table 1 – Summary Statistics of DoSV Application Data for 2015-16 (Winter Term) *
* ------------------------------------------------------------------------------- *

if "${path}" == "" {
	display "{red: ERROR: Specify path to folder containing replication files in current_directory.do and execute script}"
}

global data "${path}\data"
global output "${path}\output"

use "${data}\main_data.dta", clear

*** Compute outcomes of interest

* Student re-ranked programs during Phase 1
egen student_reranked_phase1 = max(rk_init != rk_finalm), by(stu_id)
* Fraction of programs located in student's region (Land)
egen m_same_land = mean(same_land), by(stu_id)
* Fraction of programs located in student's municipality
egen m_same_city = mean(same_city), by(stu_id)
* Average distance to ranked programs (km)
egen m_distance = mean(distance), by(stu_id)
* Grouping of majors
gen pgm_math_engineer_cs = (pgm_engineer==1 | pgm_math_cs==1)
gen pgm_grouped_other = (pgm_other==1 | pgm_arch_design==1 | pgm_teaching==1 | pgm_medic_health==1 | pgm_soc_sci==1 | pgm_lang_cult==1)
* Number of majors
gen nb_majors = pgm_econ + pgm_psycho + pgm_law + pgm_math_engineer_cs + pgm_nat_sciences + pgm_soc_work + pgm_grouped_other
* Top-ranked programs (on July 15): field of study
global fields econ psycho law math_engineer_cs nat_sciences soc_work grouped_other
foreach m in $fields {
gen f_`m' = pgm_`m' / nb_majors
gen _f_`m'1 = f_`m' if rk_init==1
egen f_`m'1 = max(_f_`m'1), by(stu_id)
replace f_`m'1 = 0 if missing(f_`m'1)
drop _f_`m'1
}
* At least one feasible program
egen stu_has_feasible = max(feasible), by(stu_id)
* Received one of more early offers in Phase 1
egen stu_has_early_offer = max(early_offer), by(stu_id)

* Accepted an early offer in Phase 1
egen stu_accept_eo_phase1 = max(early_offer_accepted_phase1==1), by(stu_id)
* of which: not initially top ranked
egen stu_accept_eo_of_which_not1 = max(accepted_pgm==1 & rk_final>1 & early_offer_accepted_phase1==1) if stu_accept_eo_phase1==1, by(stu_id)

* Number of days between offer arrival and acceptance
egen m_lag_offer_acceptance = mean(lag_offer_acceptance), by(stu_id)

* Outcomes of interest
global outcomes_students		stu_female stu_age stu_abitur_pctile
global outcomes_applications 	stu_length_init_rol stu_reranked_before_phase1 student_reranked_phase1 m_same_city m_same_land m_distance ///
								f_econ1 f_psycho1 f_soc_work1 f_law1 f_math_engineer_cs1 f_nat_sciences1 f_grouped_other1
global outcomes_offers			stu_has_feasible stu_has_early_offer
global outcomes_admission 		stu_cancel_phase1 stu_accept_eo_phase1 stu_accept_eo_of_which_not1 stu_particip_phase2 stu_matched m_lag_offer_acceptance
global outcomes $outcomes_students $outcomes_applications $outcomes_offers $outcomes_admission

keep stu_id estimation_sample $outcomes 

duplicates drop

*** Output summary statistics

global columns 1 2 3

foreach c in $columns{
* Column (1): All applicants to standard programs
if "`c'" == "1" {
local cond ""
}
* Column (2): Applied to more than one program
if "`c'" == "2" {
local cond "if !missing(stu_length_init_rol) & stu_length_init_rol>1"
}
* Column (3): Applied to at least two feasible programs and accepted an offer
if "`c'" == "3" {
local cond "if estimation_sample == 1"
}

qui su stu_id `cond'
scalar n_`c' = r(N) 

foreach v in $outcomes {
qui su `v' `cond'
scalar m_`v'_`c' = r(mean) 
scalar sd_`v'_`c' = r(sd) 
}
}

foreach men in black {
* Column width
local col1 60
local col2 80
local col3 100
local width 120
* Formats
local fmt %4.3f
local fmt2 %2.1f
local fmt3 %4.2f
local fmt4 %3.0f
* Build table
cap log close
set linesize 130
cap log using "${output}/table_1.txt", text replace
	di "Table 1 - Summary Statistics of DoSV Application Data for 2015-16 (Winter Term)"
	di ""
	di _dup(`width') "-"
	di  _col(`=`col2'+3') "Sample"
	di _dup(`width') "-"
	di _col(`col1') "All applicants" _col(`col2') "Applied to" 	_col(`col3') "Applied to at least"
	di _col(`col1') "to standard" 	_col(`col2') "more than" 	_col(`col3') "two feasible"
	di _col(`col1') "programs" 		_col(`col2') "one program" 	_col(`col3') "programs and"
	di 															_col(`col3') "accepted an offer"
	di _col(`=`col1'+4') "(1)" _col(`=`col2'+4') "(2)" _col(`=`col3'+4') "(3)"
	di _dup(`width') "-"
	di "A. Students"
	di "-----------"
	di ""
	di "Female"	///
	_col(`col1') `fmt' = m_stu_female_1 ///
	_col(`col2') `fmt' = m_stu_female_2	///
	_col(`col3') `fmt' = m_stu_female_3
	di ""
	di "Age" ///
	_col(`col1') `fmt2' = m_stu_age_1 ///
	_col(`col2') `fmt2' = m_stu_age_2 ///
	_col(`col3') `fmt2' = m_stu_age_3
	di "" ///
	_col(`col1') "("`fmt2' = sd_stu_age_1 ")" ///
	_col(`col2') "("`fmt2' = sd_stu_age_2 ")" ///
	_col(`col3') "("`fmt2' = sd_stu_age_3 ")"
	di ""
	di "Abitur percentile rank (between 0 and 1)" ///
	_col(`col1') `fmt3' = m_stu_abitur_pctile_1 ///
	_col(`col2') `fmt3' = m_stu_abitur_pctile_2 ///
	_col(`col3') `fmt3' = m_stu_abitur_pctile_3
	di "" ///
	_col(`col1') "("`fmt3' = sd_stu_abitur_pctile_1 ")" ///
	_col(`col2') "("`fmt3' = sd_stu_abitur_pctile_2 ")" ///
	_col(`col3') "("`fmt3' = sd_stu_abitur_pctile_3 ")"
	di ""	
	di "B. Applications"
	di "---------------"
	di ""
	di "Length of initial ROL (on July 15)" ///
	_col(`col1') `fmt2' = m_stu_length_init_rol_1 ///
	_col(`col2') `fmt2' = m_stu_length_init_rol_2 ///
	_col(`col3') `fmt2' = m_stu_length_init_rol_3
	di "" ///
	_col(`col1') "("`fmt2' = sd_stu_length_init_rol_1 ")" ///
	_col(`col2') "("`fmt2' = sd_stu_length_init_rol_2 ")" ///
	_col(`col3') "("`fmt2' = sd_stu_length_init_rol_3 ")"
	di ""	
	di "Re-ranked programs before Phase 1" ///
	_col(`col1') `fmt' = m_stu_reranked_before_phase1_1 ///
	_col(`col2') `fmt' = m_stu_reranked_before_phase1_2	///
	_col(`col3') `fmt' = m_stu_reranked_before_phase1_3
	di ""	
	di "Re-ranked programs during Phase 1" ///
	_col(`col1') `fmt' = m_student_reranked_phase1_1 ///
	_col(`col2') `fmt' = m_student_reranked_phase1_2	///
	_col(`col3') `fmt' = m_student_reranked_phase1_3
	di ""	
	di "Fraction of programs located in student's municipality" ///
	_col(`col1') `fmt' = m_m_same_city_1 ///
	_col(`col2') `fmt' = m_m_same_city_2 ///
	_col(`col3') `fmt' = m_m_same_city_3
	di "" ///
	_col(`col1') "("`fmt' = sd_m_same_city_1 ")" ///
	_col(`col2') "("`fmt' = sd_m_same_city_2 ")" ///
	_col(`col3') "("`fmt' = sd_m_same_city_3 ")"
	di ""	
	di "Fraction of programs located in student's region (Land)" ///
	_col(`col1') `fmt' = m_m_same_land_1 ///
	_col(`col2') `fmt' = m_m_same_land_2 ///
	_col(`col3') `fmt' = m_m_same_land_3
	di "" ///
	_col(`col1') "("`fmt' = sd_m_same_land_1 ")" ///
	_col(`col2') "("`fmt' = sd_m_same_land_2 ")" ///
	_col(`col3') "("`fmt' = sd_m_same_land_3 ")"
	di ""	
	di "Average distance to ranked programs (km)" ///
	_col(`col1') `fmt4' = m_m_distance_1 ///
	_col(`col2') `fmt4' = m_m_distance_2 ///
	_col(`col3') `fmt4' = m_m_distance_3
	di "" ///
	_col(`col1') "("`fmt4' = sd_m_distance_1 ")" ///
	_col(`col2') "("`fmt4' = sd_m_distance_2 ")" ///
	_col(`col3') "("`fmt4' = sd_m_distance_3 ")"
	di ""	
	di "Top-ranked program (on July 15): Field of study" 
	di "   Economics and Business Administration" ///
	_col(`col1') `fmt' = m_f_econ1_1 ///
	_col(`col2') `fmt' = m_f_econ1_2 ///
	_col(`col3') `fmt' = m_f_econ1_3
	di "   Psychology" ///
	_col(`col1') `fmt' = m_f_psycho1_1 ///
	_col(`col2') `fmt' = m_f_psycho1_2 ///
	_col(`col3') `fmt' = m_f_psycho1_3
	di "   Social work" ///
	_col(`col1') `fmt' = m_f_soc_work1_1 ///
	_col(`col2') `fmt' = m_f_soc_work1_2 ///
	_col(`col3') `fmt' = m_f_soc_work1_3
	di "   Law" ///
	_col(`col1') `fmt' = m_f_law1_1 ///
	_col(`col2') `fmt' = m_f_law1_2 ///
	_col(`col3') `fmt' = m_f_law1_3
	di "   Math/Engineering/Computer science" ///
	_col(`col1') `fmt' = m_f_math_engineer_cs1_1 ///
	_col(`col2') `fmt' = m_f_math_engineer_cs1_2 ///
	_col(`col3') `fmt' = m_f_math_engineer_cs1_3
	di "   Natural sciences" ///
	_col(`col1') `fmt' = m_f_nat_sciences1_1 ///
	_col(`col2') `fmt' = m_f_nat_sciences1_2 ///
	_col(`col3') `fmt' = m_f_nat_sciences1_3
	di "   Other" ///
	_col(`col1') `fmt' = m_f_grouped_other1_1 ///
	_col(`col2') `fmt' = m_f_grouped_other1_2 ///
	_col(`col3') `fmt' = m_f_grouped_other1_3
	di ""
	di "C. Feasible programs and offers received"
	di "----------------------------------------"
	di ""
	di "At least one feasible program" ///
	_col(`col1') `fmt' = m_stu_has_feasible_1 ///
	_col(`col2') `fmt' = m_stu_has_feasible_2 ///
	_col(`col3') `fmt' = m_stu_has_feasible_3
	di ""
	di "Received one or more early offers in Phase 1" ///
	_col(`col1') `fmt' = m_stu_has_early_offer_1 ///
	_col(`col2') `fmt' = m_stu_has_early_offer_2 ///
	_col(`col3') `fmt' = m_stu_has_early_offer_3
	di ""
	di "D. Admission outcome"
	di "--------------------"
	di ""
	di "Canceled application before Phase 2" ///
	_col(`col1') `fmt' = m_stu_cancel_phase1_1 ///
	_col(`col2') `fmt' = m_stu_cancel_phase1_2 ///
	_col(`col3') `fmt' = m_stu_cancel_phase1_3
	di ""
	di "Accepted an early offer in Phase 1" ///
	_col(`col1') `fmt' = m_stu_accept_eo_phase1_1 ///
	_col(`col2') `fmt' = m_stu_accept_eo_phase1_2 ///
	_col(`col3') `fmt' = m_stu_accept_eo_phase1_3
	di "   of which: not initially top ranked" ///
	_col(`col1') `fmt' = m_stu_accept_eo_of_which_not1_1 ///
	_col(`col2') `fmt' = m_stu_accept_eo_of_which_not1_2 ///
	_col(`col3') `fmt' = m_stu_accept_eo_of_which_not1_3
	di ""	
	di "Participated in Phase 2" ///
	_col(`col1') `fmt' = m_stu_particip_phase2_1 ///
	_col(`col2') `fmt' = m_stu_particip_phase2_2 ///
	_col(`col3') `fmt' = m_stu_particip_phase2_3
	di ""
	di "Accepted an offer in Phase 1 or Phase 2" ///
	_col(`col1') `fmt' = m_stu_matched_1 ///
	_col(`col2') `fmt' = m_stu_matched_2 ///
	_col(`col3') `fmt' = m_stu_matched_3
	di ""
	di "Number of days between offer arrival and acceptance" ///
	_col(`col1') `fmt3' = m_m_lag_offer_acceptance_1 ///
	_col(`col2') `fmt3' = m_m_lag_offer_acceptance_2 ///
	_col(`col3') `fmt3' = m_m_lag_offer_acceptance_3
	di "" ///
	_col(`col1') "("`fmt3' = sd_m_lag_offer_acceptance_1 ")" ///
	_col(`col2') "("`fmt3' = sd_m_lag_offer_acceptance_2 ")" ///
	_col(`col3') "("`fmt3' = sd_m_lag_offer_acceptance_3 ")"
	di ""
	di "Number of students" ///
	_col(`col1') %7.0fc = n_1 ///
	_col(`col2') %7.0fc = n_2 ///
	_col(`col3') %7.0fc = n_3
	di _dup(`width') "-"
cap log close
}
