* =============================================================================================
*  Replication program for Table 2:
*  Julien Grenet, YingHua He, and Dorothea Kübler
*  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
*  The Journal of Political Economy
*  28 November 2021
* =============================================================================================

* ------------------------------------------------------------------------------------------ *
* Table 2 – Offer Arrival, Program Selectivity and Program Desirability: Regression Analyses *
* ------------------------------------------------------------------------------------------ *

if "${path}" == "" {
	display "{red: ERROR: Specify path to folder containing replication files in current_directory.do and execute script}"
}

global data "${path}\data"
global output "${path}\output"

do "${path}\figures_tables\do\macros.do"

*** COMPUTE MEASURES OF PROGRAM SELECTIVITY/DESIRABILITY

* Compute program desirability measure: program fixed-effect estimates (standardized to have a mean of zero and a unit variance across programs) from a conditional logit model)

use "${data}\main_data.dta", clear
keep if estimation_sample == 1 & feasible == 1

* Convert distance to multiple of 1000 km
replace distance = distance / 1000
gen distance2 = distance^2

clogit_model, y("accepted_pgm") x("early_feasible first_early_feasible distance distance2 same_land") showreg(0)

* Extract program fixed effects
matrix estimates=e(b)'
mat li estimates
local rownames : rowfullnames estimates
local c : word count `rownames'
svmat double estimates, names("pgm_fe")
rename pgm_fe1 pgm_fe
keep pgm_fe 
gen var_name = ""
forvalues i = 1/`c' {
    replace var_name = "`:word `i' of `rownames''" in `i'
}
drop if _n <=5
drop if var_name == ""
destring var_name , gen(pgm_id) i(:_cons)

drop var_name
order pgm_id

tempfile pgm_fe
save `pgm_fe'

* Import all programs in main analysis sample
use "${data}\main_data.dta", clear
keep if estimation_sample == 1 & feasible == 1
keep pgm_id
duplicates drop
destring pgm_id, replace
sort pgm_id
merge 1:1 pgm_id using `pgm_fe'

* Set the base alternative to 0
replace pgm_fe = 0 if missing(pgm_fe)

* Normalize values
egen pgm_desirability = std(pgm_fe)
drop pgm_fe _merge 

tempfile pgm_desirability
save `pgm_desirability'

use "${data}\potential_offers.dta", clear
destring pgm_id, replace
merge m:1 pgm_id using `pgm_desirability'
drop _merge 
* Numbering of weeks
gen week = 1 	 if date>=date("16/07/2015","DMY") & date<=date("22/07/2015","DMY")
replace week = 2 if date>=date("23/07/2015","DMY") & date<=date("29/07/2015","DMY")
replace week = 3 if date>=date("30/07/2015","DMY") & date<=date("05/08/2015","DMY")
replace week = 4 if date>=date("06/08/2015","DMY") & date<=date("12/08/2015","DMY")
replace week = 5 if date>=date("13/08/2015","DMY") & date<=date("19/08/2015","DMY")
replace week = 6 if date>=date("20/08/2015","DMY") & date<=date("26/08/2015","DMY")
sort date week
* Number of days since start of Phase 1
gen days_since_start = date - date("16/07/2015","DMY")

gen nmiss_pgm_selectivity = !missing(pgm_selectivity)
gen nmiss_pgm_desirability = !missing(pgm_desirability)

* Mean and variable of selectivity/desirability of programs making offers on a given day
collapse ///
(sum) nmiss_pgm_selectivity nmiss_pgm_desirability ///
(mean) m_pgm_selectivity=pgm_selectivity m_pgm_desirability=pgm_desirability ///
(sd) sd_pgm_selectivity=pgm_selectivity sd_pgm_desirability=pgm_desirability [fweight = n_potential_offers], by(date days_since_start week) 

gen v_pgm_selectivity = sd_pgm_selectivity^2
gen v_pgm_desirability = sd_pgm_desirability^2
drop sd_pgm_selectivity sd_pgm_desirability

* Number of potential offers
su nmiss_pgm_selectivity
scalar n_potential_offers = r(sum) 

*** TABLE 2

label variable days_since_start "Days since start of Phase 1"

** A. Dependent variable: average selectivity/desirability of programs making offers on a given day
eststo clear

* Column (1)
eststo: qui reg m_pgm_selectivity days_since_start [pweight=nmiss_pgm_selectivity], robust
estadd scalar n_potential_offers = n_potential_offers

* Column (2)
eststo: qui reg m_pgm_selectivity ib3.week [pweight=nmiss_pgm_selectivity], robust
estadd scalar n_potential_offers = n_potential_offers

* Column (3)
eststo: qui reg m_pgm_desirability days_since_start [pweight=nmiss_pgm_desirability], robust
estadd scalar n_potential_offers = n_potential_offers

* Column (4)
eststo: qui reg m_pgm_desirability ib3.week [pweight=nmiss_pgm_desirability], robust
estadd scalar n_potential_offers = n_potential_offers

esttab using "${output}\table_2.txt", replace ///
prehead("Table 2 - Offer Arrival, Program Selectivity and Program Desirability: Regression Analyses" "" ///
"A. Dependent variable: average selectivity/desirability of programs making offers on a given day" "") ///
drop(_cons) varwidth(40) modelwidth(20) starlevels(* 0.10 ** 0.05 *** 0.01) ///
cells(b(star fmt(4 3 )) se(par fmt(4 3)) ) ///
mgroups("Program selectivity" "Program desirability", pattern(1 0 1 0)) ///
label gaps notes nomtitles collabels(none) eqlabels(" ") noobs 

** B. Dependent variable: variance of selectivity/desirability of programs making offers on a given day
eststo clear

* Column (1)
eststo: qui reg v_pgm_selectivity days_since_start [pweight=nmiss_pgm_selectivity], robust
estadd scalar n_potential_offers = n_potential_offers

* Column (2)
eststo: qui reg v_pgm_selectivity ib3.week [pweight=nmiss_pgm_selectivity], robust
estadd scalar n_potential_offers = n_potential_offers

* Column (3)
eststo: qui reg v_pgm_desirability days_since_start [pweight=nmiss_pgm_desirability], robust
estadd scalar n_potential_offers = n_potential_offers

* Column (4)
eststo: qui reg v_pgm_desirability ib3.week [pweight=nmiss_pgm_desirability], robust 
estadd scalar n_potential_offers = n_potential_offers

** Export table
esttab using "${output}\table_2.txt", append ///
prehead("" "B. Dependent variable: variance of selectivity/desirability of programs making offers on a given day" "") ///
drop(_cons) varwidth(40) modelwidth(20) starlevels(* 0.10 ** 0.05 *** 0.01) ///
cells(b(star fmt(4 3 )) se(par fmt(4 3)) ) ///
stats(N n_potential_offers, labels("N (days in Phase 1)" "Number of potential offers") fmt(0 %9.0fc)) ///
mgroups("Program selectivity" "Program desirability", pattern(1 0 1 0)) ///
label gaps notes nomtitles collabels(none) eqlabels(" ")
