* =============================================================================================
*  Replication program for Table 4:
*  Julien Grenet, YingHua He, and Dorothea Kübler
*  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
*  The Journal of Political Economy
*  28 November 2021
* =============================================================================================

* ---------------------------------------------------------------------------- *
* Table 4 – Initial vs. Final Ranking of Feasible Programs: Rank-Ordered Logit *
* ---------------------------------------------------------------------------- *

if "${path}" == "" {
	display "{red: ERROR: Specify path to folder containing replication files in current_directory.do and execute script}"
}

global data "${path}\data"
global output "${path}\output"

do "${path}\figures_tables\do\macros.do"

*** INITIAL ROL

use "${data}\main_data.dta", clear
keep if estimation_sample == 1 & feasible == 1
convert_exploded, pref_rk(rk_feas_init)

* Convert distance to multiple of 1000 km
replace distance = distance / 1000
gen distance2 = distance^2

* Proxy for chances of not receiving an offer in Phase2 
gen chances_phase2 = 0
replace chances_phase2 = ratio_cutoff1 if early_feasible == 0

egen tag_stu = tag(stu_id) 
egen n_stu = total(tag_stu)
egen n_pgm = count(pgm_id) if first_choice_sit == 1

* Column (1): Early offer
rologit_model, y("choice") x("early_feasible") ///
model("Table_4_1")

* Column (2): (1) + first early offer
rologit_model, y("choice") x("early_feasible first_early_feasible") ///
model("Table_4_2")

* Column (3): (2) + distance + same region + + program's ranking of applicant (between 0 and 1) + + chances of not receiving an offer from program in Phase 2
rologit_model, y("choice") x("early_feasible first_early_feasible distance distance2 same_land quota_pctile chances_phase2") ///
model("Table_4_3")

*** FINAL ROL

use "${data}\main_data.dta", clear
keep if estimation_sample == 1 & feasible == 1
convert_exploded, pref_rk(rk_feas_finalm)

* Convert distance to multiple of 1000 km
replace distance = distance / 1000
gen distance2 = distance^2

* Proxy for chances of not receiving an offer in Phase2 
gen chances_phase2 = 0
replace chances_phase2 = ratio_cutoff1 if early_feasible == 0

egen tag_stu = tag(stu_id) 
egen n_stu = total(tag_stu)
egen n_pgm = count(pgm_id) if first_choice_sit == 1

* Column (4): Early offer
rologit_model, y("choice") x("early_feasible")  ///
model("Table_4_4")
mfx_logit, type("early") first_choice_sit(1)

* Column (5) = (4) + first offer
rologit_model, y("choice") x("early_feasible first_early_feasible") ///
model("Table_4_5")
mfx_logit, type("early_first") first_choice_sit(1)

* Column (6) = (5) + distance + same region + + program's ranking of applicant (between 0 and 1) + + chances of not receiving an offer from program in Phase 2
rologit_model, y("choice") x("early_feasible first_early_feasible distance distance2 same_land quota_pctile chances_phase2") ///
model("Table_4_6")
mfx_logit, type("early_first") first_choice_sit(1)
dist_eq_U

*** TABLE 4
esttab Table_4_1 Table_4_2 Table_4_3 Table_4_4 Table_4_5 Table_4_6 ///
using "${output}\table_4.txt", replace ///
title("Table 4 - Initial vs. Final Ranking of Feasible Programs: Rank-Ordered Logit") ///
keep(early_feasible first_early_feasible distance distance2 same_land quota_pctile chances_phase2) ///
cells(b(star fmt(3 3 2 2 3 3 3)) se(par fmt(3 3 2 2 3 3 3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
stats(fe k_alt n_stu n_pgm ///
mp0 diff_early sd_diff_early marg_early sd_marg_early diff_first sd_diff_first marg_first sd_marg_first ///
U_nonfirstearlyoffer U_firstearlyoffer, ///
labels("Program fixed effects" "N programs" "N students" "N feasible programs" ///
"Baseline acceptance prob" "Non-first early offer (ppt)" " " "Non-first early offer (%)" " " "First early offer (ppt)" " " "First early offer (%)" " " ///
"Non-first early offer (in km)" "First early offer (in km)") fmt(0 0 %6.0fc %6.0fc 3 1 1 1 1 1 1 1 1 0 0)) ///
mgroups(" " "Init. ROL" " " " " "Final ROL" " ", pattern(1 1 1 1 1 1)) ///
varwidth(60) modelwidth(10 10 10 10 10 10) ///
label gaps notes nomtitles collabels(none) eqlabels(" ")
