* =============================================================================================
*  Replication program for Appendix Figure B2:
*  Julien Grenet, YingHua He, and Dorothea Kübler
*  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
*  The Journal of Political Economy
*  28 November 2021
* =============================================================================================

* ------------------------------------------------------------------------------------------------------------------- *
* Appendix Figure B2 – Accepted Offer: Cumulative Distribution of Number of Days Elapsed between Offer and Acceptance *
* ------------------------------------------------------------------------------------------------------------------- *

if "${path}" == "" {
	display "{red: ERROR: Specify path to folder containing replication files in current_directory.do and execute script}"
}

global data "${path}\data"
global output "${path}\output"

use "${data}\main_data.dta", clear

keep if estimation_sample == 1 & feasible == 1

* Average waiting time among students who accepted an offer: 9.1 days
su lag_offer_acceptance
scalar mean_waiting_time = r(mean)
local mean_waiting_time : display %2.1f mean_waiting_time

gen lag = lag_offer_acceptance
rename lag_offer_acceptance acceptance
gen acceptance_top_ranked = acceptance if rk_init == 1
gen acceptance_not_top_ranked = acceptance if !missing(rk_final) & rk_init > 1

keep lag acceptance acceptance_top_ranked acceptance_not_top_ranked

* cumulative distribution of number of days between offer and acceptance
global outcomes acceptance acceptance_top_ranked acceptance_not_top_ranked

foreach v in $outcomes{
preserve
keep lag `v'
keep if !missing(`v') & `v'>=0
bysort lag: gen cum_`v' = _N if _n == 1
collapse cum_`v', by(lag)
keep lag cum_`v'

tempfile `v'
save ``v''
restore
}

use `acceptance', clear

merge 1:1 lag using `acceptance_top_ranked'
drop _merge
merge 1:1 lag using `acceptance_not_top_ranked'
drop _merge

replace cum_acceptance_top_ranked = 0 if missing(cum_acceptance_top_ranked)
replace cum_acceptance_not_top_ranked = 0 if missing(cum_acceptance_not_top_ranked)

foreach v in $outcomes{
replace cum_`v' = sum(cum_`v')
egen tot_`v' = max(cum_`v')
gen pct_`v' = cum_`v'/tot_`v'
}

keep lag pct_acceptance pct_acceptance_top_ranked pct_acceptance_not_top_ranked

*** APPENDIX FIGURE B2

twoway (line pct_acceptance lag, c(connect) lp(solid) lcolor(black) lw(medthick) mcolor(black) msize(small) ylabel(0(0.2)1, gmax format(%9.1f))) ///
(line pct_acceptance_top_ranked lag, c(connect) lp(longdash) lcolor(blue) lw(medthick) mcolor(blue) msize(small) ylabel(0(0.2)1, gmax format(%9.1f))) ///
(line pct_acceptance_not_top_ranked lag, c(connect) lp(dash) lcolor(red) lw(medthick) mcolor(red) msize(small) ylabel(0(0.2)1, gmax format(%9.1f))),  ///
xline(9.14, lc(black) lw(thin)) ///
legend (pos(5) bmargin(3 0 5 12) ring(0) col(1) size(medium)  ///
	   order(1 "All accepted offers"  2 "Accepted offers that were" "initially top ranked" 3 "Accepted offers that were" "not initially top ranked" ))	///
ytitle("Cumulative probability") ///
xtitle("Accepted offer: days elapsed between offer and acceptance", height(5) axis(1)) ///
ttext(0.9 9.11 "Average waiting time " "among students who " "accepted an offer: " "`mean_waiting_time' days  ", place(w) justification(left) size(small)  ) ///
graphregion(color(white)) bgcolor(white) 

graph export "${output}\xfigure_B2.pdf", replace
