* =============================================================================================
*  Replication program for Appendix Table B1:
*  Julien Grenet, YingHua He, and Dorothea Kübler
*  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
*  The Journal of Political Economy
*  28 November 2021
* =============================================================================================

* ---------------------------------------------------------------------------------------------- *
* Appendix Table B1 – Early Offer and Acceptance among Feasible Programs: Heterogeneity Analysis *
* ---------------------------------------------------------------------------------------------- *

if "${path}" == "" {
	display "{red: ERROR: Specify path to folder containing replication files in current_directory.do and execute script}"
}

global data "${path}\data"
global output "${path}\output"

do "${path}\figures_tables\do\macros.do"

use "${data}\main_data.dta", clear

* Sample: students with at least two feasible choices who accepted an offer
keep if estimation_sample == 1 & feasible == 1
* Convert distance to multiple of 1000 km
replace distance = distance / 1000
gen distance2 = distance^2
* Proxy for chances of not receiving an offer in Phase2 
gen chances_phase2 = 0
replace chances_phase2 = ratio_cutoff1 if early_feasible == 0
* Interactions
gen early_feasible_fem = early_feasible*stu_female
gen first_early_feasible_fem= first_early_feasible*stu_female
gen early_feasible_abitur = early_feasible*stu_abitur_pctile
gen first_early_feasible_abitur= first_early_feasible*stu_abitur_pctile
bysort stu_id: egen n_feasible = sum(feasible)
gen early_feasible_nfeas = early_feasible*(n_feasible-2)
gen first_early_feasible_nfeas= first_early_feasible*(n_feasible-2)

* Create labels 
create_labels
label variable early_feasible_fem "EarlyOffer x female student"
label variable early_feasible_abitur "EarlyOffer x Abitur percentile (between 0 and 1)"
label variable early_feasible_nfeas "EarlyOffer x number of feasible programs (in excess of two)"
label variable first_early_feasible_fem "FirstEarlyOffer x female student"
label variable first_early_feasible_abitur "FirstEarlyOffer x Abitur percentile (between 0 and 1)"
label variable first_early_feasible_nfeas "FirstEarlyOffer x number of feasible programs (in excess of two)"

global baseline_offers "early_feasible first_early_feasible"
global baseline_controls "distance distance2 same_land quota_pctile chances_phase2"
global inter_gender "early_feasible_fem first_early_feasible_fem"
global inter_abitur "early_feasible_abitur first_early_feasible_abitur"
global inter_nfeas "early_feasible_nfeas first_early_feasible_nfeas"

capture program drop estadd_controls
	program estadd_controls 

	estadd local cont_distance "Yes"
	estadd local cont_region "Yes"
	estadd local cont_ranking "Yes"
	estadd local cont_chances "Yes"
end;
	
* Column (1): Baseline
clogit_model, y("accepted_pgm") x("$baseline_offers $baseline_controls") ///
model("Table_B1_1")
estadd_controls

* Column (2): (1) + interactions with female student
clogit_model, y("accepted_pgm") x("$baseline_offers $inter_gender $baseline_controls") ///
model("Table_B1_2")
estadd_controls

* Column (3): (1) + Iiteractions with Abitur percentile (between 0 and 1)
clogit_model, y("accepted_pgm") x("$baseline_offers $inter_abitur $baseline_controls") ///
model("Table_B1_3")
estadd_controls

* Column (4): (1) + interactions with number of feasible programs
clogit_model, y("accepted_pgm") x("$baseline_offers $inter_nfeas $baseline_controls") ///
model("Table_B1_4")
estadd_controls

* Column (5): (1) + all interactions
clogit_model, y("accepted_pgm") x("$baseline_offers $inter_gender $inter_abitur $inter_nfeas $baseline_controls") ///
model("Table_B1_5")
estadd_controls

*** APPENDIX TABLE B1
esttab Table_B1_1 Table_B1_2 Table_B1_3 Table_B1_4 Table_B1_5 ///
using "${output}\xtable_B1.txt", replace ///
title("Table B1 - Early Offer and Acceptance among Feasible Programs: Heterogeneity Analysis" "") ///
keep(early_feasible early_feasible_fem early_feasible_abitur early_feasible_nfeas ///
first_early_feasible first_early_feasible_fem first_early_feasible_abitur first_early_feasible_nfeas) ///
order(early_feasible early_feasible_fem early_feasible_abitur early_feasible_nfeas ///
first_early_feasible first_early_feasible_fem first_early_feasible_abitur first_early_feasible_nfeas) ///
cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
stats(cont_distance cont_region cont_ranking cont_chances fe ///
k_alt N_case N, ///
labels( "Distance to university (quadratic)" "Program in student's region (Land)" "Program's ranking of student (between 0 and 1)" ///
"Chances of not receiving an offer from program in Phase 2" "Program fixed effects" ///
"N programs" "N students" "N feasible programs") fmt(0 0 0 0 0 0 %6.0fc %6.0fc))  ///
varwidth(70) modelwidth(10 10 10 10 10) ///
label gaps notes nomtitles collabels(none) eqlabels(" ")
