* =============================================================================================
*  Replication program for Appendix Table B2:
*  Julien Grenet, YingHua He, and Dorothea Kübler
*  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
*  The Journal of Political Economy
*  28 November 2021
* =============================================================================================

* ------------------------------------------------------------------------------------------------------------------------- *
* Appendix Table B2 – Early Offer and Acceptance among Feasible Programs: Robustness to Contracting Students' Feasible Sets *
* ------------------------------------------------------------------------------------------------------------------------- *

if "${path}" == "" {
	display "{red: ERROR: Specify path to folder containing replication files in current_directory.do and execute script}"
}

global data "${path}\data"
global output "${path}\output"

do "${path}\figures_tables\do\macros.do"

*** Macro to contract set of feasible programs and modify acceptance decisions accordingly

capture program drop contract_feasible_set
	program contract_feasible_set 
	syntax [, upper_cut(real 1)]
	
* Define contracted set of feasible programs
gen feasible_contracted = feasible
replace feasible_contracted = 0 if (early_feasible == 0 & ratio_cutoff2>=`upper_cut')
* Identify student who were assigned to a barely feasible Phase 2 program
egen stu_lost_assignment = max(early_feasible == 0 & ratio_cutoff2>=`upper_cut' & accepted_pgm == 1), by (stu_id)

* Compute number of feasible programs in the contracted set
keep if feasible_contracted == 1
egen n_feasible_contracted = count(feasible_contracted), by (stu_id)
keep if n_feasible_contracted>= 2

* Define top-ranked feasible choice in the contracted set
gen rk_final_contracted = rk_final if rk_final >0
egen rk_final_contracted_1 = min(rk_final_contracted), by(stu_id)
gen top_feas_pgm_contracted = 0
replace top_feas_pgm_contracted = 1 if rk_final_contracted == rk_final_contracted_1

* Re-define assignment outcome
gen accepted_pgm_contracted = accepted_pgm 
replace accepted_pgm_contracted = 1 if (stu_lost_assignment == 1 & top_feas_pgm_contracted == 1)
drop rk_final_contracted top_feas_pgm_contracted

* Convert distance to multiple of 1000 km
replace distance = distance / 1000
gen distance2 = distance^2

create_labels, chances(0)

end

*** Column (1):  Baseline

use "${data}/main_data.dta", clear
keep if estimation_sample == 1 & feasible == 1
* Convert distance to multiple of 1000 km
replace distance = distance / 1000
gen distance2 = distance^2
clogit_model, y("accepted_pgm") x("early_feasible") ///
model("Table_B2_1_bsl")
mfx_logit, type("early")
local mp0 = e(mp0)
clogit_model, y("accepted_pgm") x("early_feasible first_early_feasible distance distance2 same_land quota_pctile") ///
model("Table_B2_1")
mfx_logit, type("early_first")
estadd scalar mp0 = `mp0'

*** Columns (2) to (6): Loop over upper admission cutoffs

forvalues i=1/5 {
    if `i' == 1 {
	local upper_cut 0.9
	local table_no "B2_2"
	}
    if `i' == 2 {
	local upper_cut 0.8
	local table_no "B2_3"
	}
    if `i' == 3 {
	local upper_cut 0.7
	local table_no "B2_4"
	}
    if `i' == 4 {
	local upper_cut 0.6
	local table_no "B2_5"
	}
    if `i' == 5 {
	local upper_cut 0.5
	local table_no "B2_6"
	}
use "${data}/main_data.dta", clear
keep if estimation_sample == 1
contract_feasible_set, upper_cut(`upper_cut')
create_labels, chances(0)
clogit_model, y("accepted_pgm_contracted") x("early_feasible") showreg(0) ///
model("Table_`table_no'_bsl")
mfx_logit, type("early")
local mp0 = e(mp0)
clogit_model, y("accepted_pgm_contracted") x("early_feasible first_early_feasible distance distance2 same_land quota_pctile") ///
model("Table_`table_no'")
mfx_logit, type("early_first")
estadd scalar mp0 = `mp0'
}

*** APPENDIX TABLE B2

esttab Table_B2_1 Table_B2_2 Table_B2_3 Table_B2_4 Table_B2_5 Table_B2_6 ///
using "${output}\xtable_B2.txt", replace ///
title("Table B2 - Early Offer and Acceptance among Feasible Programs: Robustness to Contracting Students' Feasible Sets" "") ///
keep(early_feasible first_early_feasible distance distance2 same_land quota_pctile) ///
cells(b(star fmt(3 3 2 2 3 3)) se(par fmt(3 3 2 2 3 3))) starlevels(* 0.10 ** 0.05 *** 0.01)  ///
stats(fe k_alt N_case N ///
mp0 diff_early sd_diff_early marg_early sd_marg_early diff_first sd_diff_first marg_first sd_marg_first, ///
labels("Program fixed effects" "N programs" "N students" "N feasible programs" ///
"Baseline (no early offer) acceptance probability" "Non-first early offer (ppt)" " " "Non-first early offer (%)" " " ///
"First early offer (ppt)" " " "First early offer (%)" " ") fmt(0 %6.0fc %6.0fc %6.0fc 3 1))  ///
mgroups("r=1.0" "r=0.9" "r=0.8" "r=0.7" "r=0.6" "r=0.5", pattern(1 1 1 1 1 1)) ///
varwidth(60) modelwidth(10 10 10 10 10 10) ///
label gaps notes nomtitles collabels(none) eqlabels(" ")
