* =============================================================================================
*  Replication program for Appendix Table B3:
*  Julien Grenet, YingHua He, and Dorothea Kübler
*  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
*  The Journal of Political Economy
*  28 November 2021
* =============================================================================================

* ----------------------------------------------------------------------------------------------------------------------- *
* Appendix Table B3 – Early Offer and Acceptance among Feasible Programs: Robustness to Expanding Students' Feasible Sets *
* ----------------------------------------------------------------------------------------------------------------------- *

if "${path}" == "" {
	display "{red: ERROR: Specify path to folder containing replication files in current_directory.do and execute script}"
}

global data "${path}\data"
global output "${path}\output"

do "${path}\figures_tables\do\macros.do"

*** Macro to extended the set of feasible programs and modify acceptance decisions accordingly

capture program drop expand_feasible_set
	program expand_feasible_set 
	syntax [, upper_cut(real 1)]
	
* Define expanded set of feasible programs
gen feasible_expanded = 0
replace feasible_expanded = 1 if ratio_cutoff2 <= `upper_cut'

* Compute number of feasible programs in the expanded set
keep if feasible_expanded == 1
egen n_feasible_expanded = count(feasible_expanded), by (stu_id)
keep if n_feasible_expanded >= 2

* Define top-ranked feasible choice in the expanded set
gen rk_final_expanded = rk_final if rk_final >0
egen rk_final_expanded_1 = min(rk_final_expanded), by (stu_id)
gen top_feas_pgm_expanded = 0
replace top_feas_pgm_expanded = 1 if rk_final_expanded == rk_final_expanded_1

* Re-define assignment outcome
gen accepted_pgm_expanded = 0
replace accepted_pgm_expanded = accepted_pgm if  stu_exit_phase1 == 1 | stu_active_acceptance == 1
replace accepted_pgm_expanded = 1 if stu_exit_phase1 == 0 & stu_active_acceptance ==0 & top_feas_pgm_expanded == 1

* Convert distance to multiple of 1000 km
replace distance = distance / 1000
gen distance2 = distance^2

create_labels, chances(0)

end

*** Column (1):  Baseline

use "${data}/main_data.dta", clear
keep if estimation_sample == 1 & feasible == 1
* Convert distance to multiple of 1000 km
replace distance = distance / 1000
gen distance2 = distance^2
clogit_model, y("accepted_pgm") x("early_feasible") ///
model("Table_B3_1_bsl")
mfx_logit, type("early")
local mp0 = e(mp0)
clogit_model, y("accepted_pgm") x("early_feasible first_early_feasible distance distance2 same_land quota_pctile") ///
model("Table_B3_1")
mfx_logit, type("early_first")
estadd scalar mp0 = `mp0'

*** Columns (2) to (6): Loop over upper admission cutoffs

forvalues i=1/5 {
    if `i' == 1 {
	local upper_cut 1.1
	local table_no "B3_2"
	}
    if `i' == 2 {
	local upper_cut 1.2
	local table_no "B3_3"
	}
    if `i' == 3 {
	local upper_cut 1.3
	local table_no "B3_4"
	}
    if `i' == 4 {
	local upper_cut 1.4
	local table_no "B3_5"
	}
    if `i' == 5 {
	local upper_cut 1.5
	local table_no "B3_6"
	}
use "${data}/main_data.dta", clear
keep if extended_sample == 1
expand_feasible_set, upper_cut(`upper_cut')
create_labels, chances(0)
clogit_model, y("accepted_pgm_expanded") x("early_feasible") ///
model("Table_`table_no'_bsl")
mfx_logit, type("early")
local mp0 = e(mp0)
clogit_model, y("accepted_pgm_expanded") x("early_feasible first_early_feasible distance distance2 same_land quota_pctile") ///
model("Table_`table_no'")
mfx_logit, type("early_first")
estadd scalar mp0 = `mp0'
}

*** APPENDIX TABLE B3

esttab Table_B3_1 Table_B3_2 Table_B3_3 Table_B3_4 Table_B3_5 Table_B3_6 ///
using "${output}\xtable_B3.txt", replace ///
title("Table B3 - Early Offer and Acceptance among Feasible Programs: Robustness to Expanding Students' Feasible Sets" " ") ///
keep(early_feasible first_early_feasible distance distance2 same_land quota_pctile) ///
cells(b(star fmt(3 3 2 2 3 3 3)) se(par fmt(3 3 2 2 3 3 3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
stats(fe k_alt N_case N ///
mp0 diff_early sd_diff_early marg_early sd_marg_early diff_first sd_diff_first marg_first sd_marg_first, ///
labels("Program fixed effects" "N programs" "N students" "N feasible programs" ///
"Baseline (no early offer) acceptance probability" "Non-first early offer (ppt)" " " "Non-first early offer (%)" " " ///
"First early offer (ppt)" " " "First early offer (%)" " ") fmt(0 %6.0fc %6.0fc %6.0fc 3 1))  ///
mgroups("r=1.0" "r=1.1" "r=1.2" "r=1.3" "r=1.4" "r=1.5", pattern(1 1 1 1 1 1)) ///
varwidth(70) modelwidth(10 10 10 10 10 10) ///
label gaps notes nomtitles collabels(none) eqlabels(" ")
