* =============================================================================================
*  Replication program for Appendix Table B4:
*  Julien Grenet, YingHua He, and Dorothea Kübler
*  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
*  The Journal of Political Economy
*  28 November 2021
* =============================================================================================

* ---------------------------------------------------------------------------------------------------------------- *
* Appendix Table B4 – Early Offer and Acceptance among Feasible Programs: By Week in which Program Became Feasible *
* ---------------------------------------------------------------------------------------------------------------- *

if "${path}" == "" {
	display "{red: ERROR: Specify path to folder containing replication files in current_directory.do and execute script}"
}

global data "${path}\data"
global output "${path}\output"

do "${path}\figures_tables\do\macros.do"

use "${data}\main_data.dta", clear

keep if estimation_sample == 1 & feasible == 1

* Convert distance to multiple of 1000 km
replace distance = distance / 1000
gen distance2 = distance^2

* Proxy for chances of not receiving an offer in Phase2 
gen chances_phase2 = 0
replace chances_phase2 = ratio_cutoff1 if early_feasible == 0

* Define days since start of Phase 1
gen days_since_start = date_feasible - mdy(7,16,2015)

* Interact early offers with weeks
gen early_feasible_week12 = early_feasible*(days_since_start<=13)
gen early_feasible_week3p = early_feasible*(days_since_start>13)
gen first_early_feasible_week12 = first_early_feasible*(days_since_start<=13)
gen first_early_feasible_week3p = first_early_feasible*(days_since_start>13)

create_labels
label variable early_feasible_week12 "EarlyOffer x Weeks 1-2"
label variable early_feasible_week3p "EarlyOffer x Weeks 3-5"
label variable first_early_feasible_week12 "FirstEarlyOffer x Weeks 1-2"
label variable first_early_feasible_week3p "FirstEarlyOffer x Weeks 3-5"

global early_feasible_week = "early_feasible_week12 early_feasible_week3p"
global first_early_feasible_week = "first_early_feasible_week12 first_early_feasible_week3p"

* Column (1): early offer
clogit_model, y("accepted_pgm") x("${early_feasible_week}") ///
model("Table_B4_1")

* Column (2): (1) + first early offer
clogit_model, y("accepted_pgm") x("${early_feasible_week} ${first_early_feasible_week}") ///
model("Table_B4_2")

* Column (3): (2) + distance + same region
clogit_model, y("accepted_pgm") x("${early_feasible_week} ${first_early_feasible_week} distance distance2 same_land") ///
model("Table_B4_3")

* Column (4): (3) + how student is ranked
clogit_model, y("accepted_pgm") x("${early_feasible_week} ${first_early_feasible_week} distance distance2 quota_pctile same_land") ///
model("Table_B4_4")

* Column (5): (4) +  chances of not receiving offer in Phase 2
clogit_model, y("accepted_pgm") x("${early_feasible_week} ${first_early_feasible_week} distance distance2 quota_pctile chances_phase2 same_land") ///
model("Table_B4_5")

global covariates = "early_feasible_week12 early_feasible_week3p first_early_feasible_week12 first_early_feasible_week3p distance distance2 same_land quota_pctile chances_phase2"

*** APPENDIX TABLE B4

esttab Table_B4_1 Table_B4_2 Table_B4_3 Table_B4_4 Table_B4_5 ///
using "${output}\xtable_B4.txt", replace /// 
title("Table B4 - Early Offer and Acceptance among Feasible Programs: By Week in which Program Became Feasible") ///
keep(${covariates}) ///
order(${covariates}) ///
cells(b(star fmt(3 3 3 3 2 2 3 3 3)) se(par fmt(3 3 3 3 2 2 3 3 3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
stats(fe k_alt N_case N, labels("Program fixed effects"  "N programs" "N students" "N feasible programs") fmt(%6.0fc))  ///
varwidth(60) modelwidth(10 10 10 10 10) ///
label gaps notes nomtitles collabels(none) eqlabels(" ")
