* =============================================================================================
*  Replication program for Appendix Table B5:
*  Julien Grenet, YingHua He, and Dorothea Kübler
*  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
*  The Journal of Political Economy
*  28 November 2021
* =============================================================================================

* --------------------------------------------------------------------------------------------------------------------------- *
* Appendix Table B5 – Acceptance among Feasible Programs and Final ROLs: Controlling for How Students Initially Rank Programs *
* --------------------------------------------------------------------------------------------------------------------------- *

if "${path}" == "" {
	display "{red: ERROR: Specify path to folder containing replication files in current_directory.do and execute script}"
}

global data "${path}\data"
global output "${path}\output"

do "${path}\figures_tables\do\macros.do"

use "${data}\main_data.dta", clear

* Sample restriction
keep if estimation_sample == 1 & feasible == 1

*** macro to add variables

capture program drop add_variables
	program add_variables 

* Convert distance to multiple of 1000 km
replace distance = distance / 1000
gen distance2 = distance^2

* Proxy for chances of not receiving an offer in Phase2 
gen chances_phase2 = 0
replace chances_phase2 = ratio_cutoff1 if early_feasible == 0

* Create dummies for student's initial ranking of programs

levelsof rk_init, local(levels)
foreach l of local levels {
gen rk_init`l' = (rk_init==`l')
}
gen rk_init5_12 = (rk_init>=5 & rk_init<=12)

create_labels, dranking(1)

egen tag_stu = tag(stu_id) 
egen n_stu = total(tag_stu)
egen tag_pgm = tag(pgm_id) 
egen n_pgm = total(tag_pgm)

end

add_variables

su n_stu 
scalar n_stu = r(max)
scalar n_feas = r(N)
su n_pgm
scalar n_pgm = r(max)

clogit_model, y("accepted_pgm") x("early_feasible first_early_feasible distance distance2 same_land quota_pctile chances_phase2 rk_init2 rk_init3 rk_init4 rk_init5_12") ///
model("Table_B5_1")

estadd scalar n_stu = n_stu
estadd scalar n_pgm = n_pgm
estadd scalar n_feas = n_feas

*** FINAL ROL
use "${data}/main_data.dta", clear
keep if estimation_sample == 1 & feasible == 1
convert_exploded, pref_rk(rk_feas_finalm)

add_variables

egen n_feas = count(pgm_id) if first_choice_sit == 1
su n_pgm 
scalar n_feas = r(max)

rologit_model, y("choice") x("early_feasible first_early_feasible distance distance2 same_land quota_pctile chances_phase2 rk_init2 rk_init3 rk_init4 rk_init5_12")  ///
model("Table_B5_2")

estadd scalar n_feas = n_feas

*** APPENDIX TABLE B5

esttab Table_B5_1 Table_B5_2 ///
using "${output}\xtable_B5.txt", replace ///
title("Table B5 - Acceptance among Feasible Programs and Final ROLs: Controlling for How Students Initially Rank Programs" "") ///
keep(early_feasible first_early_feasible distance distance2 same_land quota_pctile chances_phase2 rk_init2 rk_init3 rk_init4 rk_init5_12) ///
cells(b(star fmt(3 3 2 2 3 3 3 3 3 3 3)) se(par fmt(3 3 2 2 3 3 3 3 3 3 3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
stats(fe n_pgm n_stu n_feas, labels("Program fixed effects" "N programs" "N students" "N feasible programs") fmt(%6.0fc)) ///
mgroups("Acceptance among feasible" "Final ROL", pattern(1 1)) ///
varwidth(70) modelwidth(25 25) ///
label gaps notes nomtitles collabels(none) eqlabels(" ")
