* =============================================================================================
*  Replication program for Appendix Table B7:
*  Julien Grenet, YingHua He, and Dorothea Kübler
*  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
*  The Journal of Political Economy
*  28 November 2021
* =============================================================================================

* ------------------------------------------------------------------------ *
* Appendix Table B7 – How Long do Students Wait before Accepting an Offer? *
* ------------------------------------------------------------------------ *

if "${path}" == "" {
	display "{red: ERROR: Specify path to folder containing replication files in current_directory.do and execute script}"
}

global data "${path}\data"
global output "${path}\output"

eststo clear

*** Individual offers

use "${data}\main_data.dta", clear
keep if estimation_sample == 1 & accepted_pgm == 1 

* Number of days between start of Phase 1 and date of offer arrival
gen n_days_offer = date_offer - mdy(7,16,2015) if !missing(date_offer)

* Convert distance to multiple of 1000 km
replace distance = distance / 1000
gen distance2 = distance^2

* Initial ranking of accepted offer
gen rk_init2 = (rk_init == 2)
gen rk_init3 = (rk_init == 3)
gen rk_init4 = (rk_init == 4)
gen rk_init5_12 = (rk_init >= 5)

gen diff_land = 1-same_land
gen stu_length_init_rol_2 = stu_length_init_rol-2

* Regressors
global regressors "stu_female stu_abitur_pctile distance distance2 diff_land rk_init2 rk_init3 rk_init4 rk_init5_12 n_days_offer stu_length_init_rol_2 n_other_offers"

* Labels
label variable stu_female "Female"
label variable stu_abitur_pctile "Abitur percentile (between 0 and 1)"
label variable distance "Distance to university (in thousand km)"
label variable distance2 "Distance to university (in thousand km) - squared"
label variable diff_land "Program is not in student's region (Land)"
label variable n_days_offer "Number of days between start of Phase 1 and date of offer arrival"
label variable stu_length_init_rol_2 "Number of programs in initial ROL (in excess of 2)"
label variable n_other_offers "Number of other offers held when accepting offer"
label variable rk_init2 "Student's initial ranking of program = 2"
label variable rk_init3 "Student's initial ranking of program = 3"
label variable rk_init4 "Student's initial ranking of program = 4"
label variable rk_init5_12 "Student's initial ranking of program = 5 or above"

su lag_offer_acceptance if early_offer_accepted_phase1 == 1
scalar m_lag1 = r(mean) 
scalar sd_lag1= r(sd) 

su lag_offer_acceptance
scalar m_lag2 = r(mean) 
scalar sd_lag2 = r(sd) 

* Column (1): Students with a least two feasible programs who actively accepted an offer in Phase 1
eststo: reg lag_offer_acceptance ${regressors} if early_offer_accepted_phase1 == 1
estadd scalar m_lag = m_lag1
estadd local sd_lag = "("+string(sd_lag1,"%3.2f")+")"

* Column (2): Sample 1 + students who were automatically assigned to a program in Phase 2
eststo: reg lag_offer_acceptance ${regressors}
estadd scalar m_lag = m_lag2
estadd local sd_lag = "("+string(sd_lag2,"%3.2f")+")"

*** APPENDIX TABLE B7

esttab using "${output}/xtable_B7.txt", replace ///
title("Table B7 - How Long do Students Wait before Accepting an Offer?" "") ///
order(_cons) cells(b(star fmt(2 3 3 2 2 3)) se(par fmt(2 3 3 2 2 3)) ) ///
stats(N r2_a m_lag sd_lag, ///
labels("Number of observations" "Adjusted R-squared" "Mean waiting time before accepting an offer (in days)" " ") ///
fmt(%6.0fc 3 2)) ///
varwidth(65) modelwidth(15 15) ///
mgroups("Sample 1" "Sample 2", pattern(1 1)) ///
label gaps notes nomtitles collabels(none) eqlabels(" ")
