* =============================================================================================
*  Replication program for Appendix Table B8:
*  Julien Grenet, YingHua He, and Dorothea Kübler
*  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
*  The Journal of Political Economy
*  28 November 2021
* =============================================================================================

* -------------------------------------------------------------------------------------------------------------------------------------- *
* Appendix Table B8 – Early Offer and Acceptance among Feasible Programs: Using Flexible Controls for a Program's Ranking of the Student *
* -------------------------------------------------------------------------------------------------------------------------------------- *

if "${path}" == "" {
	display "{red: ERROR: Specify path to folder containing replication files in current_directory.do and execute script}"
}

global data "${path}\data"
global output "${path}\output"

do "${path}\figures_tables\do\macros.do"

use "${data}\main_data.dta", clear
keep if estimation_sample == 1 & feasible == 1

* Convert distance to multiple of 1000 km
replace distance = distance / 1000
gen distance2 = distance^2

* Proxy for chances of not receiving an offer in Phase2 
gen chances_phase2 = 0
replace chances_phase2 = ratio_cutoff1 if early_feasible == 0

* Polynomials
gen quota_pctile2 = quota_pctile^2
gen quota_pctile3 = quota_pctile^3
gen quota_pctile4 = quota_pctile^4
* Quartiles
gen q2_rk = (quota_pctile>=0.25 & quota_pctile<0.5)
gen q3_rk = (quota_pctile>=0.5 & quota_pctile<0.75)
gen q4_rk= (quota_pctile>=0.75 & quota_pctile<=1)
* Deciles
gen d2_rk = (quota_pctile>=0.1 & quota_pctile<0.2)
gen d3_rk = (quota_pctile>=0.2 & quota_pctile<0.3)
gen d4_rk = (quota_pctile>=0.3 & quota_pctile<0.4)
gen d5_rk = (quota_pctile>=0.4 & quota_pctile<0.5)
gen d6_rk = (quota_pctile>=0.5 & quota_pctile<0.6)
gen d7_rk = (quota_pctile>=0.6 & quota_pctile<0.7)
gen d8_rk = (quota_pctile>=0.7 & quota_pctile<0.8)
gen d9_rk = (quota_pctile>=0.8 & quota_pctile<0.9)
gen d10_rk = (quota_pctile>=0.9 & quota_pctile<1)

create_labels

global baseline_regressors early_feasible first_early_feasible distance distance2 same_land chances_phase2

* Baseline acceptance probability
clogit_model, y("accepted_pgm") x("early_feasible") ///
model("Table_B8_bsl")
mfx_logit, type("early")
local mp0 = e(mp0)

* Column (1): Linear control
clogit_model, y("accepted_pgm") x("${baseline_regressors} quota_pctile") ///
model("Table_B8_1")
mfx_logit, type("early_first")
estadd local cont_ranking "Linear"

* Column (2): Quadratic control 
clogit_model, y("accepted_pgm") x("${baseline_regressors} quota_pctile quota_pctile2") ///
model("Table_B8_2")
mfx_logit, type("early_first")
estadd local cont_ranking "Quadratic"

* Column (3): Quartic control
clogit_model, y("accepted_pgm") x("${baseline_regressors} quota_pctile quota_pctile2 quota_pctile3 quota_pctile4") ///
model("Table_B8_3")
mfx_logit, type("early_first")
estadd local cont_ranking "Quartic"

* Column (4): Quartiles
clogit_model, y("accepted_pgm") x("${baseline_regressors} q2_rk q3_rk q4_rk") ///
model("Table_B8_4")
mfx_logit, type("early_first")
estadd local cont_ranking "Quartiles"

* Column (5): Deciles
clogit_model, y("accepted_pgm") x("${baseline_regressors} d2_rk d3_rk d4_rk d5_rk d6_rk d7_rk d8_rk d9_rk d10_rk") ///
model("Table_B8_5")
mfx_logit, type("early_first")
estadd local cont_ranking "Deciles"

clogit_model, y("accepted_pgm") x("early_feasible") ///
model("Table_B8_bsl")
mfx_logit, type("early")

*** APPENDIX TABLE B8

esttab Table_B8_1 Table_B8_2 Table_B8_3 Table_B8_4 Table_B8_5 ///
using "${output}/xtable_B8.txt", replace ///
title("Table B8 - Early Offer and Acceptance among Feasible Programs: Using Flexible Controls for a Program's Ranking of the Student") ///
keep(early_feasible first_early_feasible distance distance2 same_land chances_phase2) ///
cells(b(star fmt(3 3 2 2 3 3)) se(par fmt(3 3 2 2 3 3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
stats(cont_ranking fe k_alt N_case N ///
mp0 diff_early sd_diff_early marg_early sd_marg_early diff_first sd_diff_first marg_first sd_marg_first, ///
labels("Program's ranking of student (between 0 and 1)" "Program fixed effects" "N students" "N feasible programs" " " ///
"Baseline (no early offer) acceptance probability: `:di %4.3f `mp0''" "Non-first early offer (ppt)" " " "Non-first early offer (%)" " " "First early offer (ppt)" " " "First early offer (%)" " ") ///
fmt(0 0 0 %6.0fc %6.0fc 1 1 1 1 1 1 1 1)) ///
varwidth(60) modelwidth(10 10 10 10 10) ///
label gaps notes nomtitles collabels(none) eqlabels(" ")
