* =============================================================================================
*  Replication program for Appendix Table C1:
*  Julien Grenet, YingHua He, and Dorothea Kübler
*  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
*  The Journal of Political Economy
*  28 November 2021
* =============================================================================================

* ---------------------------------------------------------------------------------------------- *
* Appendix Table C1 – Impact of (Potential) Early Offers on Acceptance Probability: RD Estimates *
* ---------------------------------------------------------------------------------------------- *

*global path "C:\Users\j.grenet\Desktop\replication_files"

if "${path}" == "" {
	display "{red: ERROR: Specify path to folder containing replication files in current_directory.do and execute script}"
}

global data "${path}\data"
global output "${path}\output"

use "${data}\rd_data.dta", clear

* Drop cutoff student since always receives offer (de Chaisemartin and Behahghel, 2020)
drop if distance_phase1_cutoff == 0

* Create program fixed effects
tabulate pgm_quota_id, generate(pq)

* Compute baseline means
su feasible if distance_phase1_cutoff>0
scalar bsl_feasible = r(mean)
su accepted_pgm if distance_phase1_cutoff>0
scalar bsl_accepted_pgm = r(mean)

*** RD estimates

capture program drop rd_dosv
	program rd_dosv 
	syntax [, y(string) h(string) b(string) controls(integer 0)]
	
if "`controls'" == "0" {
}
if "`controls'" == "1" {
local covs "covs(pq*)"
}	

rdrobust `y' distance_phase1_cutoff, vce(nncluster stu_id) `covs' h(`h') b(`b') all

ereturn list

scalar co1_cl_`y'_`controls' = _b[Conventional]
scalar co1_bc_`y'_`controls' = _b[Bias-corrected]
scalar se1_cl_`y'_`controls' = _se[Conventional]
scalar se1_rb_`y'_`controls' = _se[Robust]


di _b["Bias-corrected"]

scalar st1_cl_`y'_`controls' = ""
if  e(pv_cl)<0.01 {
	scalar st1_cl_`y'_`controls' = "***"
}
if e(pv_cl)>= 0.01 & e(pv_cl)<0.05 {
	scalar st1_cl_`y'_`controls' = "**"
}
if e(pv_cl)>= 0.05 & e(pv_cl)<0.10 {
	scalar st1_cl_`y'_`controls' = "*"
}

scalar st1_rb_`y'_`controls' = ""
if  e(pv_rb)<0.01 {
	scalar st1_rb_`y'_`controls' = "***"
}
if e(pv_rb)>= 0.01 & e(pv_rb)<0.05 {
	scalar st1_rb_`y'_`controls' = "**"
}
if e(pv_rb)>= 0.05 & e(pv_rb)<0.10 {
	scalar st1_rb_`y'_`controls' = "*"
}

end

*** 2SLS estimates (without controls)

* Determine bandwith estimate and bandwidth bias from 2SLS and store in local macros
rdrobust accepted_pgm distance_phase1_cutoff, fuzzy(feasible) vce(nncluster stu_id) all

global h0 = e(h_l)
global b0 = e(b_l)
scalar Nobs = e(N)

di Nobs
unique stu_id
scalar Nstudents = r(sum)
di Nstudents

scalar co2_cl_accepted_pgm_0 = _b[Conventional]
scalar co2_bc_accepted_pgm_0 = _b[Bias-corrected]
scalar se2_cl_accepted_pgm_0 = _se[Conventional]
scalar se2_rb_accepted_pgm_0 = _se[Robust]

scalar st2_cl_accepted_pgm_0 = ""
if  e(pv_cl)<0.01 {
	scalar st2_cl_accepted_pgm_0 = "***"
}
if e(pv_cl)>= 0.01 & e(pv_cl)<0.05 {
	scalar st2_cl_accepted_pgm_0 = "**"
}
if e(pv_cl)>= 0.05 & e(pv_cl)<0.10 {
	scalar st2_cl_accepted_pgm_0 = "*"
}

scalar st2_rb_accepted_pgm_0 = ""
if  e(pv_rb)<0.01 {
	scalar st2_rb_accepted_pgm_0 = "***"
}
if e(pv_rb)>= 0.01 & e(pv_rb)<0.05 {
	scalar st2_rb_accepted_pgm_0 = "**"
}
if e(pv_rb)>= 0.05 & e(pv_rb)<0.10 {
	scalar st2_rb_accepted_pgm_0 = "*"
}

* First stage estimates (without controls)
rd_dosv, y("feasible") h($h0) b($b0) controls(0)
rd_dosv, y("accepted_pgm") h($h0) b($b0) controls(0)

ereturn list

*** 2SLS estimates (with controls)

* Determine bandwith estimate and bandwidth bias from 2SLS and store in local macros
rdrobust accepted_pgm distance_phase1_cutoff, fuzzy(feasible) vce(nncluster stu_id) covs(pq*) all
global h1 = e(h_l)
global b1 = e(b_l)

scalar co2_cl_accepted_pgm_1 = _b[Conventional]
scalar co2_bc_accepted_pgm_1 = _b[Bias-corrected]
scalar se2_cl_accepted_pgm_1 = _se[Conventional]
scalar se2_rb_accepted_pgm_1 = _se[Robust]

scalar st2_cl_accepted_pgm_1 = ""
if  e(pv_cl)<0.01 {
	scalar st2_cl_accepted_pgm_1 = "***"
}
if e(pv_cl)>= 0.01 & e(pv_cl)<0.05 {
	scalar st2_cl_accepted_pgm_1 = "**"
}
if e(pv_cl)>= 0.05 & e(pv_cl)<0.10 {
	scalar st2_cl_accepted_pgm_1 = "*"
}

scalar st2_rb_accepted_pgm_1 = ""
if  e(pv_rb)<0.01 {
	scalar st2_rb_accepted_pgm_1 = "***"
}
if e(pv_rb)>= 0.01 & e(pv_rb)<0.05 {
	scalar st2_rb_accepted_pgm_1 = "**"
}
if e(pv_rb)>= 0.05 & e(pv_rb)<0.10 {
	scalar st2_rb_accepted_pgm_1 = "*"
}

* First stage estimates (with controls)
rd_dosv, y("feasible") h($h1) b($b1) controls(1)
rd_dosv, y("accepted_pgm") h($h1) b($b1) controls(1)

* Number of program-quotas

egen temp = group(pgm_quota_id)
su temp
scalar n_pgm_quotas = r(max)

*** APPENDIX TABLE C1

foreach men in black {
local col1 45
local col2 60
local col3 75
local col4 90
local width 105

cap log close
set linesize 150
cap log using "${output}/xtable_C1.txt", text replace
	di "Table C1 - Impact of  (Potential) Early Offers on Acceptance Probability: RD estimates"
	di ""
	di _dup(`width') "-"
	di _col(`col1') "(1)" _col(`col2') "(2)" _col(`col3') "(3)" _col(`col4') "(4)"
	di _dup(`width') "-"
	di ""
	di "A. First Stage: Discontinuity in probability of (potential) early offer from program"
	di "1(Rank <= Phase 1 cutoff)"  					_col(`col1') %4.3f = -co1_cl_feasible_0 st1_cl_feasible_0	/// 
														_col(`col2') %4.3f = -co1_bc_feasible_0 st1_rb_feasible_0	///
														_col(`col3') %4.3f = -co1_cl_feasible_1 st1_cl_feasible_1	///
														_col(`col4') %4.3f = -co1_bc_feasible_1 st1_rb_feasible_1	
	di                              					_col(`col1') "(" %4.3f = se1_cl_feasible_0 ")" ///
														_col(`col2') "(" %4.3f = se1_rb_feasible_0 ")" ///
														_col(`col3') "(" %4.3f = se1_cl_feasible_1 ")" ///
														_col(`col4') "(" %4.3f = se1_rb_feasible_1 ")"	
	di ""	
	di "Baseline mean (Rank > Phase 1 cutoff)"  		_col(`col1') %4.3f = bsl_feasible ///
														_col(`col2') %4.3f = bsl_feasible ///
														_col(`col3') %4.3f = bsl_feasible ///
														_col(`col4') %4.3f = bsl_feasible
	di ""
	di "B. Reduced Form: Discontinuity in probability of accepting a program’s offer"
	di "1(Rank <= Phase 1 cutoff)"  					_col(`col1') %4.3f = -co1_cl_accepted_pgm_0 st1_cl_accepted_pgm_0 ///
														_col(`col2') %4.3f = -co1_bc_accepted_pgm_0 st1_rb_accepted_pgm_0	///
														_col(`col3') %4.3f = -co1_cl_accepted_pgm_1 st1_cl_accepted_pgm_1	 ///
														_col(`col4') %4.3f = -co1_bc_accepted_pgm_1 st1_rb_accepted_pgm_1
	di                              					_col(`col1') "(" %4.3f = se1_cl_accepted_pgm_0 ")" ///
														_col(`col2') "(" %4.3f = se1_rb_accepted_pgm_0 ")" /// 
														_col(`col3') "(" %4.3f = se1_cl_accepted_pgm_1 ")" ///
														_col(`col4') "(" %4.3f = se1_rb_accepted_pgm_1 ")"
	di ""
	di "Baseline mean (Rank > Phase 1 cutoff)"  		_col(`col1') %4.3f = bsl_accepted_pgm ///
														_col(`col2') %4.3f = bsl_accepted_pgm ///
														_col(`col3') %4.3f = bsl_accepted_pgm ///
														_col(`col4') %4.3f = bsl_accepted_pgm
	di ""
	di "C. RD IV: Impact of early offer on acceptance probability"
	di "EarlyOffer"  									_col(`col1') %4.3f = co2_cl_accepted_pgm_0 st2_cl_accepted_pgm_0 ///
														_col(`col2') %4.3f = co2_bc_accepted_pgm_0 st2_rb_accepted_pgm_0	///
														_col(`col3') %4.3f = co2_cl_accepted_pgm_1 st2_cl_accepted_pgm_1	///
														_col(`col4') %4.3f = co2_bc_accepted_pgm_1 st2_rb_accepted_pgm_1
	di                              					_col(`col1') "(" %-4.3f = se2_cl_accepted_pgm_0 ")" ///
														_col(`col2') "(" %-4.3f = se2_rb_accepted_pgm_0 ")" /// 
														_col(`col3') "(" %-4.3f = se2_cl_accepted_pgm_1 ")" ///
														_col(`col4') "(" %-4.3f = se2_rb_accepted_pgm_1 ")"	
	di ""
	di _dup(`width') "-"
	di "Number of observations"  						_col(`col1') %6.0fc = Nobs ///
														_col(`col2') %6.0fc = Nobs	///
														_col(`col3') %6.0fc = Nobs	///
														_col(`col4') %6.0fc = Nobs
	di "Number of students" 	 						_col(`col1') %6.0fc = Nstudents	///
														_col(`col2') %6.0fc = Nstudents	///
														_col(`col3') %6.0fc = Nstudents	 ///
														_col(`col4') %6.0fc = Nstudents
	di "RD estimation method" 	 						_col(`col1') "Conventional" ///
														_col(`col2') "Bias-corrected" ///
														_col(`col3') "Conventional"	 ///
														_col(`col4') "Bias-corrected"	
	di "Bandwidth (rank-distance to Phase 1 cutoff)"	_col(`col1') "+/-"%4.1f `=$h0'	///
														_col(`col2') "+/-"%4.1f `=$h0'	///
														_col(`col3') "+/-"%4.1f `=$h1'	///
														_col(`col4') "+/-"%4.1f `=$h1'
	di "Spline" 	 									_col(`col1') "Linear" ///
														_col(`col2') "Linear" ///
														_col(`col3') "Linear" ///
														_col(`col4') "Linear"	
	di "Program-quota fixed effects (" %3.0fc = n_pgm_quotas ")" ///	 				
														_col(`col1') "No" ///
														_col(`col2') "No" ///
														_col(`col3') "Yes" ///
														_col(`col4') "Yes"		
	di _dup(`width') "-"
cap log close
}
