* =============================================================================================
*  Replication program for Section IV.D (simulations):
*  Julien Grenet, YingHua He, and Dorothea Kübler
*  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
*  The Journal of Political Economy
*  28 November 2021
* =============================================================================================

* ----------------------------------------- *
* Prepare data for simulations (APPENDIX E) *
* ----------------------------------------- *

if "${path}" == "" {
	display "{red: ERROR: Specify path to folder containing replication files in current_directory.do and execute script}"
}

global data "${path}\data"

use "${data}\main_data.dta", clear

set matsize 1000

* Use rank-order logit model to estimate preferences under no information and full information

use "${data}\main_data.dta", clear
keep if estimation_sample == 1
	
replace distance = (distance-126)/1000
gen distance2=distance^2

*keep distance dist dist2 distance2
 
replace univ_id="9901" if univ_id=="DS01"
destring pgm_id, replace
destring univ_id, replace

** Interact "early offer" and "first early offer" with distance, distance squared, whether the program is in the student's region, university fixed effects and field-of-study fixed effects

qui rologit rk_feas_finalm early_feasible first_early_feasible ///
ib1210.pgm_id ///
distance distance2 same_land ///
c.distance#c.early_feasible c.distance#c.first_early_feasible ///
c.distance2#c.early_feasible c.distance2#c.first_early_feasible ///
c.same_land#c.early_feasible c.same_land#c.first_early_feasible ///
i.univ_id#c.early_feasible ///
i.univ_id#c.first_early_feasible ///
c.pgm_arch_design#c.early_feasible c.pgm_arch_design#c.first_early_feasible ///
c.pgm_nat_sciences#c.early_feasible c.pgm_nat_sciences#c.first_early_feasible ///
c.pgm_law#c.early_feasible c.pgm_law#c.first_early_feasible ///
c.pgm_teaching#c.early_feasible c.pgm_teaching#c.first_early_feasible ///
c.pgm_engineer#c.early_feasible c.pgm_engineer#c.first_early_feasible ///
c.pgm_math_cs#c.early_feasible c.pgm_math_cs#c.first_early_feasible ///
c.pgm_medic_health#c.early_feasible c.pgm_medic_health#c.first_early_feasible ///
c.pgm_psycho#c.early_feasible c.pgm_psycho#c.first_early_feasible ///
c.pgm_soc_work#c.early_feasible c.pgm_soc_work#c.first_early_feasible ///
c.pgm_soc_sci#c.early_feasible c.pgm_soc_sci#c.first_early_feasible ///
c.pgm_lang_cult#c.early_feasible c.pgm_lang_cult#c.first_early_feasible ///
c.pgm_econ#c.early_feasible c.pgm_econ#c.first_early_feasible ///
c.pgm_other#c.early_feasible c.pgm_other#c.first_early_feasible, ///	     
group(stu_id) reverse ltolerance(1e-2) nonrtolerance 

*** PREDICT IN DATASET WITH ADDED FEASIBLE PROGRAM

drop _all

use "${data}\main_data.dta", clear
keep if simulation_sample == 1

replace distance = (distance-126)/1000
gen distance2=distance^2

replace univ_id="9901" if univ_id=="DS01"
ta univ_id

destring pgm_id, replace
destring univ_id, replace

*save true values
gen EO = early_feasible
gen FEO = first_early_feasible

* V_Fullinfo = V(EO=1,FEO=1)
replace early_feasible = 1
replace first_early_feasible = 1
predict V_Fullinfo, xb
predict V_Fullinfo_se, stdp

* Restore true values
replace early_feasible = EO
replace first_early_feasible = FEO

* Keep only relevant variables
keep stu_id pgm_id stu_abitur_pctile EO FEO accepted_pgm ///
V_Fullinfo V_Fullinfo_se stu_length_init_rol feasible_added1
   
* Save data for 1 added feasible program
save "${data}\simulations_data.dta", replace

*** PREPARE DATA FOR SIMULATIONS

* Replace stu_id and university id by numerical ids
keep stu_id
duplicates drop
sort stu_id

gen stu_num = _n

tempfile stu_num
save `stu_num'

use "${data}\simulations_data.dta", clear

merge m:1 stu_id using `stu_num'
drop _merge stu_id
rename stu_num stu_id

save "${data}\simulations_data.dta", replace

keep pgm_id
duplicates drop
sort pgm_id

gen pgm_num = _n

tempfile pgm_num
save `pgm_num'

use "${data}\simulations_data.dta", clear

merge m:1 pgm_id using `pgm_num'
drop _merge pgm_id
rename pgm_num pgm_id

* Number of feasible programs per student (using extended definition)
egen stu_n_feasible_ext = sum(feasible_added1), by(stu_id)
* Program capacity = number of admitted students (set to 1 if no student from the sample was admitted)
egen pgm_capacity = sum(accepted_pgm), by(pgm_id)
replace pgm_capacity = max(pgm_capacity,1)

save "${data}\simulations_data.dta", replace

* Students' ranking by programs: percentile rank among students in the simulation data

use "${data}\simulations_data.dta", clear

keep stu_id stu_abitur_pctile
duplicates drop
sort stu_abitur_pctile 

egen double rg_abitur = rank(stu_abitur_pctile), track
egen double freq_abitur = sum(rg_abitur>0), by(rg_abitur)
egen double n_obs = sum(rg_abitur>0)
drop stu_abitur_pctile

gen double stu_abitur_rk = (rg_abitur - 1 + 0.5*freq_abitur)/n_obs
drop rg_abitur freq_abitur n_obs 
sort stu_id

tempfile stu_abitur_rk
save `stu_abitur_rk'

use "${data}\simulations_data.dta", clear

merge m:1 stu_id using `stu_abitur_rk'
drop _merge

sort stu_id pgm_id

keep stu_id pgm_id stu_abitur_rk pgm_capacity ///
V_Fullinfo V_Fullinfo_se stu_length_init_rol stu_n_feasible_ext

order stu_id pgm_id stu_abitur_rk pgm_capacity ///
V_Fullinfo V_Fullinfo_se stu_length_init_rol stu_n_feasible_ext

erase "${data}\simulations_data.dta"

*** Export data
export delimited using "${data}\simulation_data.csv", replace 
