%==========================================================================
%  Replication program for Section IV.D (simulations):
%  Julien Grenet, YingHua He, and Dorothea Kbler
%  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
%  The Journal of Political Economy
%  28 November 2021
%==========================================================================

function [assigned, matched] = DA_func(stu_pref, pgm_pref, pgm_capacity)
% DA   Implements Gale-Shapley Program-Proposing Deferred Acceptance algorithm
%
% Inputs:
% - stu_pref: students' ranking of programs (sparse (J,I) matrix sorted by pgm_id and stu_id). Highest rank = most preferred / 0 if unranked.
% - pgm_pref: program's ranking of students (spare (J,I) matrix sorted by pgm_id and stu_id). Highest rank = most preferred / 0 if unranked.
% - pgm_capacity: (J,1) vector of program capacities sorted by pgm_id
%
% Output:
% - assigned: (I,1) sparse vector of each student's assigned pgm_id
% - matched: (J,I) sparse matrix of pgm_id x stu_id matches

% # of students, # of programs
[npgm, nstu] = size(stu_pref);

counter = 0;

% Logical array to select last admitted student in each program
offers_selector = zeros(npgm, nstu); 
for pp=1:npgm
    offers_selector(pp,pgm_capacity(pp)) = 1;   
end
offers_selector = logical(offers_selector);

stop = 0;
while stop == 0
    counter=counter+1;
    % Sort students by priority in each program
    [priorities_stu, ~] = sort(pgm_pref,2,'descend');
    priorities_stu = priorities_stu';
    % Priority of last admitted student
    prior_last_admitted_stu = priorities_stu(offers_selector');
    % Priority cannot be zero -> replace by very 1
    prior_last_admitted_stu(prior_last_admitted_stu==0) = 1;
    % Offers are made to all students with higher priority
    offers = (pgm_pref >= repmat(prior_last_admitted_stu,[1 nstu]));
    % Add existing match to the matrix
    % Each student chooses the program with the highest utility out of offers
    matching.pgm = (stu_pref.*offers == repmat(max(stu_pref.*offers),[npgm 1])).*offers;
    % Declined offers
    declined_offers = offers - matching.pgm;
    % Stopping criterion: no new declined offers
    stop = 1 - any(declined_offers(:));
    % Update the preferences of programs that have been declined by students
    pgm_pref(logical(declined_offers)) = 0;
end

% ---------------- %
% MATCHING OUTCOME %
% ---------------- %

% matched: (J,I) matrix of program x student matches
matched = matching.pgm;

% assigned: (1,I) vector of students' assigned program (0 if unassigned)
assigned = (max(matching.pgm.*repmat((1:npgm)',[1 nstu]),[],1))';  

assigned(assigned==0) = NaN;
