%==========================================================================
%  Replication program for Section IV.C (numerical example):
%  Julien Grenet, YingHua He, and Dorothea Kbler
%  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
%  The Journal of Political Economy
%  28 November 2021
%==========================================================================

% Function for calculating the expected utility conditional on the realization of the first learned X
% Called by numerical_example.m

function [learn, nolearn, diff] = f_cond_eu(x,mu1,mu2,p1,p2,k,first)

% input
% x: realized value of the first learned univerity
% model premitives: mu1,mu2,p1,p2,k -- specified in numerical_example.m
% first: = 1 or 2, which university is learned first

% output
% learn: expected utility if learning the second university
% nolearn: expected utility if not learning the second university
% diff: difference between learn and nolearn (calculated w/ in a different way for cross checking)

if first == 1 % conditonal on having learned X1 already
    
    % x1star = mu2 + 0.5 - sqrt((k - 0.5*(1-p1)*p2*(mu2-0.5)^2)/(0.5*p1*p2));
    
    % case 1: x1 \in [mu1-0.5, 0]
    diff_1 = 0.5*p2*(0.5-mu2)^2 - k;
    eu_1_noinfo_12 = p2*mu2; % not learning X2
    eu_1_info_12 = eu_1_noinfo_12 + diff_1; % learning X2
    
    % case 2: x1 \in [0, mu2]
    diff_2 =  0.5*(1-p1)*p2*(0.5-mu2)^2 + 0.5*p1*p2*(x - mu2 + 0.5)^2 - k;
    eu_2_noinfo_12 = p2*mu2 + (1-p2)*p1*x;
    eu_2_info_12 = eu_2_noinfo_12 + diff_2;
    
    % case 3: x1 \in [mu2, 0.5+mu2]
    diff_3 = 0.5*(1-p1)*p2*(0.5-mu2)^2 + 0.5*p1*p2*(x - mu2 - 0.5)^2 - k;
    eu_3_noinfo_12 = p1*x  + (1-p1)*p2*mu2;
    eu_3_info_12 = eu_3_noinfo_12  + diff_3;
    
    % case 4: x1 \in [0.5+mu2, mu1+0.5]
    diff_4 = 0.5*(1-p1)*p2*(mu2-0.5)^2 - k;
    eu_4_noinfo_12 = p1*x + (1-p1)*p2*mu2;
    eu_4_info_12 = eu_4_noinfo_12 + diff_4;
    
    
    % expected utility
    learn = eu_1_info_12*(x<0) +  eu_2_info_12*(x>=0)*(x<mu2) ...
        + eu_3_info_12*(x>=mu2)*(x<0.5+mu2) + eu_4_info_12*(x>=0.5+mu2);
    
    nolearn = eu_1_noinfo_12*(x<0) +  eu_2_noinfo_12*(x>=0)*(x<mu2) ...
        + eu_3_noinfo_12*(x>=mu2)*(x<0.5+mu2) + eu_4_noinfo_12*(x>=0.5+mu2);
    
    diff = diff_1*(x<0) +  diff_2*(x>=0)*(x<mu2) ...
        + diff_3*(x>=mu2)*(x<0.5+mu2) + diff_4*(x>=0.5+mu2);
    
elseif first == 2
    
    % x2star = mu1 + 0.5 - sqrt((k - 0.5*(1-p2)*p1*(mu1-0.5)^2)/(0.5*p1*p2));
    
    % case 1: x2 \in [mu2-0.5, 0]
    diff_1 = 0.5*p1*(0.5-mu1)^2 - k;
    eu_1_noinfo_21 = p1*mu1;  % not learning X1
    eu_1_info_21 = eu_1_noinfo_21 + diff_1;  % learning X1
    
    % case 2: x2 \in [0, mu1]
    diff_2 = 0.5*(1-p2)*p1*(0.5-mu1)^2 ...
        + 0.5*p1*p2*(x - mu1 + 0.5)^2 - k;
    eu_2_noinfo_21 = p1*mu1 + (1-p1)*p2*x;
    eu_2_info_21 = eu_2_noinfo_21 + diff_2;
    
    % case 3: x2 \in [mu1, mu2+0.5]
    diff_3 = 0.5*(1-p2)*p1*(0.5-mu1)^2 + 0.5*p1*p2*(x - mu1 - 0.5)^2 - k;
    eu_3_noinfo_21 = p2*x  + (1-p2)*p1*mu1;    
    eu_3_info_21 = eu_3_noinfo_21 + diff_3;
        
    % expected utility
    learn = eu_1_info_21*(x<0) +  eu_2_info_21*(x>=0)*(x<mu1) ...
        + eu_3_info_21*(x>=mu1);
    
    nolearn = eu_1_noinfo_21*(x<0) +  eu_2_noinfo_21*(x>=0)*(x<mu1) ...
        + eu_3_noinfo_21*(x>=mu1);
    
    diff = diff_1*(x<0) +  diff_2*(x>=0)*(x<mu1) ...
        + diff_3*(x>=mu1);
end
end
