%==========================================================================
%  Replication program for Section IV.C (numerical example):
%  Julien Grenet, YingHua He, and Dorothea Kbler
%  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
%  The Journal of Political Economy
%  28 November 2021
%==========================================================================

% This is the main replication file for Section IV.C 
% (Costly Preference Discovery and Early-offer Effect: A Numerical Example)
% It calls for f_cond_eu.m (in subfolder m/func)
% which is a function for calculate the expected utility conditional on the realization of the first learned X

% Output: (all saved in the same folder as this .m file):
% 1) Table 6 in the paper: table_6_sim.csv (in folder output/)
% 2) Figure 5 panels A and B in the paper: figure_5a.eps and figure_5b.eps (in folder output/); a colored version is also saved  
% 3) A data file example_data.mat is saved in the same folder as this m. file before creating/fine-tuning the figures

clear

tic 
datetime('now') 
clear,home

if exist('set_path.m', 'file') == 2
    set_path
else 
    error('ERROR: specify path to folder containing replication files in change_directory.m and execute script')  
end

%% create the table for simulation results

% mechanism name
MechName = ["DA"; "DA"; "M-DA"; "M-DA"; "BM-DA"; "BM-DA"; ...
    "DA"; "DA"; "M-DA"; "M-DA"; "BM-DA"; "BM-DA"; ...
    "DA"; "M-DA"; "BM-DA"];

% Probability types
Prob = ["Pr(Learning X1)"; "Pr(Learning X2)"; "Pr(Learning X1)"; "Pr(Learning X2)"; "Pr(Learning X1)"; "Pr(Learning X2)"; ...
    "Pr(top rank univ. 1)"; "Pr(top rank univ. 2)"; "Pr(top rank univ. 1)"; "Pr(top rank univ. 2)"; "Pr(top rank univ. 1)"; "Pr(top rank univ. 2)"; ...
    " "; " "; " "];

% No early offer
NoOffer = NaN(15,1);

% early offer from 1
Offer1 = NaN(15,1);

% early offer from 2
Offer2 = NaN(15,1);

% early offer from 1 and then 2
Offer12 = NaN(15,1);

% early offer from 2 and then 1
Offer21 = NaN(15,1);

sim_table = table(MechName,Prob,NoOffer,Offer1,Offer2,Offer12,Offer21); 

%% set up the payoff functions

disp('====================================================================='); 
disp('1. Model setup and the payoff functions'); 
disp('====================================================================='); 
% no learning, learning X_1 first, and learning X_2 first, 

% primitives
syms mu1 mu2 p1 p2 k

p1_0 = 9/16;
p2_0 = 9/16;
mu1_0 = 1/16;
mu2_0 = 1/32; 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% not learning anything
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
eu_nolearning = p1*mu1 + (1-p1)*p2*mu2;

f_nolearning(mu1, mu2, p1, p2, k) = eu_nolearning;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% learning X_1 first: functions (ending with _12 -- learning 1 first then possibly 2)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
x1star = mu2 + 0.5 - sqrt((k - 0.5*(1-p1)*p2*(mu2-0.5)^2)/(0.5*p1*p2));

% case 1: x1 \in [mu1-0.5, 0]
eu_1_noinfo_12 = p2*mu2*(0.5-mu1); % not learning X2
eu_1_info_12 = eu_1_noinfo_12 + 0.5*p2*(0.5-mu2)^2*(0.5-mu1) - k*(0.5-mu1); % learning X2
 
% case 2: x1 \in [0, mu2]
eu_2_noinfo_12 = p2*mu2*mu2 + (1-p2)*p1*mu2^2/2;
eu_2_info_12 = eu_2_noinfo_12 + 0.5*(1-p1)*p2*(0.5-mu2)^2*mu2 + 0.5*p1*p2*(1/8 - (0.5-mu2)^3)/3 - k*mu2;

% case 3: x1 \in [mu2, x1star]
eu_3_noinfo_12 = p1*(x1star^2 - mu2^2)/2  + (1-p1)*p2*mu2*(x1star-mu2);

eu_3_info_12 = eu_3_noinfo_12 + 0.5*(1-p1)*p2*(0.5-mu2)^2*(x1star-mu2) ...
    + 0.5*p1*p2*((x1star - mu2 - 0.5)^3 + 1/8)/3 - k*(x1star-mu2);

% case 4: x1 \in [x1star, mu1+0.5]
eu_4_noinfo_12 = p1*((mu1+0.5)^2 - x1star^2 )/2 + (1-p1)*p2*mu2*(mu1+0.5-x1star);
eu_4_info_12 = eu_4_noinfo_12;

% expected utility
eu_noinfo_12 = simplify(eu_1_noinfo_12 + eu_2_noinfo_12 + eu_3_noinfo_12 + eu_4_noinfo_12 - k);
eu_info_12 = simplify(eu_1_info_12 + eu_2_info_12 + eu_3_info_12 + eu_4_info_12 - k,'Steps',5000);

% cross-check with the expression in the paper:
% expression derived in the paper
in_paper_12 = p1/2*(mu1+1/2)^2 + p2*(1/12 + 2*mu2/3 + mu2/6*(mu2+1/2)^2 - mu1/2*(mu2-1/2)^2) ...
    + p1*p2*(mu2^2/3 - mu2/3 - mu1*mu2) + (1-p1)*p2*x1star/3*(mu2-1/2)^2 ...
    -k*(5/3 + mu2/3 + 2*x1star/3 - mu1);
% check difference:
diff_12 = simplify(eu_info_12 - in_paper_12, 'Steps',5000);
disp(['Different from the expression in the paper? ', num2str(double(diff_12))]);

% functions:
f_12(mu1, mu2, p1, p2, k) = eu_info_12; % optimally learn X2
f_x1star(mu1, mu2, p1, p2, k) = x1star;
f_x1star_lowbnd(mu1, mu2, p1, p2, k) = (mu2 > x1star); % = 1 if binding
f_x1star_upbnd(mu1, mu2, p1, p2, k) = (mu2 + 0.5 < x1star) ; % = 1 if binding

% disp('====================================================================='); 
% disp('cross-checking with numerical solutions: expected utility and x1star'); 
% disp('====================================================================='); 
% 
% disp(['EU when no learning: ', num2str(double(f_nolearning(mu1_0, mu2_0, 1, 1, 0.03)))]);
% disp(['EU when learning 1 then 2: ', num2str(double(f_12( mu1_0, mu2_0, 1, 1, 0.03)))]);
% disp(['x1star when learning 1 then 2: ', num2str(double(f_x1star(mu1_0, mu2_0, 1, 1, 0.03)))]);
% disp(['lower bound on x1star binding when learning 1 then 2? ', ...
%     num2str(double(f_x1star_lowbnd(mu1_0, mu2_0, 1, 1, 0.03)))]);
% disp(['upper bound on x1star binding when learning 1 then 2? ', ...
%     num2str(double(f_x1star_upbnd(mu1_0, mu2_0, 1, 1, 0.03)))]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% learning X_2 first: functions (ending with _21 -- learning 2 first then possibly 1)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
x2star = mu1 + 0.5 - sqrt((k - 0.5*(1-p2)*p1*(mu1-0.5)^2)/(0.5*p1*p2));

x2star_bind = mu2 + 0.5;

% case 1: x2 \in [mu2-0.5, 0]
eu_1_noinfo_21 = p1*mu1*(0.5-mu2);  % not learning X1
eu_1_info_21 = eu_1_noinfo_21 + 0.5*p1*(0.5-mu1)^2*(0.5-mu2) - k*(0.5-mu2);  % learning X1

% case 2: x2 \in [0, mu1]
eu_2_noinfo_21 = p1*mu1*mu1 + (1-p1)*p2*mu1^2/2;
eu_2_info_21 = eu_2_noinfo_21 + 0.5*(1-p2)*p1*(0.5-mu1)^2*mu1 ...
    + 0.5*p1*p2*(1/8 - (0.5-mu1)^3)/3 - k*mu1;

% case 3: x2 \in [mu1, mu2+0.5]
eu_3_noinfo_21 = p2*((0.5+mu2)^2 - mu1^2)/2  + (1-p2)*p1*mu1*(mu2+0.5-mu1);

eu_3_info_21 = eu_3_noinfo_21 + 0.5*(1-p2)*p1*(0.5-mu1)^2*(x2star-mu1) ...
    + 0.5*p1*p2*((x2star - mu1 - 0.5)^3 + 1/8)/3 - k*(x2star-mu1);

% expected utility
eu_noinfo_21 = simplify(eu_1_noinfo_21 + eu_2_noinfo_21 + eu_3_noinfo_21 - k);
eu_info_21_nonbind = simplify(eu_1_info_21 + eu_2_info_21 + eu_3_info_21 - k,'Steps',5000);
% diff = simplify(eu_info - eu_noinfo)

% % cross-check with the expression in the paper:
% % expression derived in the paper
% in_paper_21 = p1/2*(1/24 + 23*mu1/12 - mu1^2/6 + mu1^3/3 - (mu1-0.5)^2*(mu2-0.5)) ...
%     + p2/2*(mu2+0.5)^2 + p1*p2*(mu1^2/3 - mu1/3 -mu1*mu2) ...
%     + p1*(1-p2)*x2star/3*(mu1-0.5)^2 ...
%     - k*(mu1/3 + 2*x2star/3 +5/3 -mu2);
% 
% % check difference:
% diff_21 = simplify(eu_info_21_nonbind - in_paper_21, 'Steps',5000);
% disp(['Different from the expression in the paper? ', num2str(double(diff_21))]);

% functions:
f_21(mu1, mu2, p1, p2, k) = eu_info_21_nonbind;  % optimally learning given the sequence 2--1
f_x2star(mu1, mu2, p1, p2, k) = x2star;
f_x2star_lowbnd(mu1, mu2, p1, p2, k) = (mu1 > x2star); % = 1 if binding
f_x2star_upbnd(mu1, mu2, p1, p2, k) = (mu2 + 0.5 < x2star) ; % = 1 if binding
% disp(['EU when no learning: ', num2str(double(f_nolearning( 0.04, 0.02, 1, 1, 0.04)))]);
% disp(['EU when learning 2 then 1: ', num2str(double(f_21( 0.04, 0.02, 1, 1, 0.04)))]);
% disp(['x2star when learning 2 then 1: ', num2str(double(f_x2star(0.04, 0.02, 1, 1, 0.04)))]);
% disp(['lower bound on x2star binding when learning 2 then 1? ', ...
%     num2str(double(f_x2star_lowbnd(0.04, 0.02, 1, 1, 0.04)))]);
% disp(['upper bound on x2star binding when learning 2 then 1? ', ...
%     num2str(double(f_x2star_upbnd(0.04, 0.02, 1, 1, 0.04)))]);

%% Derivation for mu1 = mu1_0; mu2 = mu2_0; p1 = 0.75, p2 = 0.5
disp('====================================================================='); 
fprintf('2. Derive conditions on k, given mu1 = %g; mu2 = %g; p1 = %g, p2 = %g\n',mu1_0,mu2_0,p1_0,p2_0);
disp('====================================================================='); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Difference between the three learning sequences: 1-2, 2-1, 0 (no learning)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
f_diff_12_21(mu1, mu2, p1, p2, k) = eu_info_12 - eu_info_21_nonbind;
f_diff_21_12(mu1, mu2, p1, p2, k) = eu_info_21_nonbind - eu_info_12;
f_diff_12_0(mu1, mu2, p1, p2, k) = eu_info_12 - eu_nolearning;
f_diff_21_0(mu1, mu2, p1, p2, k) = eu_info_21_nonbind - eu_nolearning;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% bounds on k from the assumptions on k to ensure "interior" solutions
% under DA, M-DA, and BM-DA conditional on all offer arrivals.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% lbnd = max((1-p1)*(mu2-0.5)^2/2, max((1-p2)*(mu1-0.5)^2 + p2*(mu1-mu2)^2/2, (mu1-mu2)^2/2)); % max(7^2/2^12, (2^2*3^3 + 3) / 2^12);
lbnd_1(mu1,mu2,p1,p2) =  (1-p1)*(mu2-0.5)^2/2;
lbnd_2(mu1,mu2,p1,p2) =  (1-p2)*(mu1-0.5)^2/2 + p2*(mu1-mu2)^2/2;
lbnd_3(mu1,mu2,p1,p2) =  (mu1-mu2)^2/2;
k_lbnd = max([lbnd_1(mu1_0, mu2_0, p1_0, p2_0), lbnd_2(mu1_0, mu2_0, p1_0, p2_0), lbnd_3(mu1_0, mu2_0, p1_0, p2_0)]);

% ubnd = min(p2*(mu2-0.5)^2/2, p1*(mu1-0.5)^2/2); % min(7^2/2^10, 3^3/2^9); 
ubnd_1(mu1,mu2,p1,p2) =  p2*(mu2-0.5)^2/2;
ubnd_2(mu1,mu2,p1,p2) =  p1*(mu1-0.5)^2/2;
k_ubnd = min([ubnd_1(mu1_0, mu2_0, p1_0, p2_0), ubnd_2(mu1_0, mu2_0, p1_0, p2_0)]);

disp(['lower bound of k for interior solutions: ', num2str(double(k_lbnd)), ' or ']) 
disp(k_lbnd)

disp(['upper bound of k for interior solutions: ', num2str(double(k_ubnd)), ' or ']) 
disp(k_ubnd)

% old value for the working paper version: 
% the mid-point of the admissible interval
% k0 = (double(k_lbnd) + double(k_ubnd))/2;

% new value in the published paper
k0 = 0.05; 

fprintf('In the numerical example, k = ')
disp(k0);

% disp('bounds from the paper: 37/1024, 49/1024');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Desired learning sequence:
% 1) no early offer: 1-2
% 2) early offer from 1: 1-2
% 3) early offer from 2: 2-1
% 4) early offers from both: 1-2

% translate into conditions on:
% f_diff_12_21(mu1, mu2, p1, p2, k)
% f_diff_12_0(mu1, mu2, p1, p2, k)
% f_diff_21_0(mu1, mu2, p1, p2, k) 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 1) no early offer: learning sequence 1-2

% f_diff_12_21(mu1, mu2, p1, p2, k) > 0 & f_diff_12_0(mu1, mu2, p1, p2, k) > 0

disp('======================================================='); 
disp('3.1. no early offer: solving expected utility and x1star'); 
disp('======================================================='); 

% disp('check if the constraints for x1star and x2star are satisfied:')
% disp(double(x1star_con(mu1_0, mu2_0, p1_0, p2_0, k)));
% disp(double(x2star_con(mu1_0, mu2_0, p1_0, p2_0, k)));

disp('no learning: EU'); 
disp(simplify(f_nolearning( mu1_0, mu2_0, p1_0, p2_0, k), 'Steps',5000));

disp('Learning 1 then 2 under DA: EU, x1star'); 
disp(simplify(f_12( mu1_0, mu2_0, p1_0, p2_0, k), 'Steps',5000));
disp(simplify(f_x1star(mu1_0, mu2_0, p1_0, p2_0, k), 'Steps',5000));

% check if x1star is an interior solution
x1star_not_interior = 0;
for jj = k_lbnd + [0:5000]/5000*(k_ubnd -  k_lbnd)
    if double(f_x1star(mu1_0, mu2_0, p1_0, p2_0, jj)) < 0 ...
            || double(f_x1star(mu1_0, mu2_0, p1_0, p2_0, jj)) > mu2_0 + 0.5 
        disp('x1star is not an interior solution');
        x1star_not_interior = x1star_not_interior + 1;
    end
end
disp(['x1star is an interior solution? ', num2str(x1star_not_interior==0)]);

disp('Learning 2 then 1 under DA: EU, x2star'); 
disp(simplify(f_21( mu1_0, mu2_0, p1_0, p2_0, k), 'Steps',5000));
disp(simplify(f_x2star(mu1_0, mu2_0, p1_0, p2_0, k), 'Steps',5000));

% check if x2star is an interior solution
x2star_not_interior = 0;
for jj = k_lbnd + [0:5000]/5000*(k_ubnd -  k_lbnd)
    if double(f_x2star(mu1_0, mu2_0, p1_0, p2_0, jj)) < 0 ...
            || double(f_x2star(mu1_0, mu2_0, p1_0, p2_0, jj)) > mu2_0 + 0.5 
        disp('x1star is not an interior solution');
        x2star_not_interior = x2star_not_interior + 1;
    end
end
disp(['x2star is an interior solution? ', num2str(x2star_not_interior==0)]);

disp('Difference between 1-2 and no learning under DA: '); 
disp(simplify(f_diff_12_0( mu1_0, mu2_0, p1_0, p2_0, k), 'Steps',5000)) ;

% % cross check with the expression in the paper:
% diff_in_paper = ((524288*k-14175)*(524288*k - 14175)^(1/2) + 24340095)/226492416 - 63*k/32; 
% disp(simplify(f_diff_12_0( mu1_0, mu2_0, p1_0, p2_0, k) - diff_in_paper, 'Steps',5000)) ;

% solve for k that makes the student indifferent between 1--2 and no learning
eqn1 = f_diff_12_0( mu1_0, mu2_0, p1_0, p2_0, k) == 0;
eqn2 = k >= k_lbnd; 
eqn3 = k <= k_ubnd; 
S1 = solve([eqn1,eqn2,eqn3],k,'ReturnConditions',true);
disp(['no solution? ', num2str(isempty(S1.k))]);

% check if 1--2 leads to a higher payoff than no learning for constrained k
disp('1--2 leads to a higher payoff than no learning for constrained k? Yes if no message.');

for jj = k_lbnd + [0:5000]/5000*(k_ubnd -  k_lbnd)
    if double(f_diff_12_0( mu1_0, mu2_0, p1_0, p2_0, jj)) <= 0 
        disp('1--2 does not lead to a higher payoff than no learning for constrained k')
    end
end

disp('Difference between 1--2 and 2--1 under DA: '); 
disp(simplify(f_diff_12_21( mu1_0, mu2_0, p1_0, p2_0, k), 'Steps',5000)) ;

% % cross check with the expression in the paper:
% diff_in_paper = k/16 +((524288*k-14175)*sqrt(524288*k-14175) - 358425)/226492416 ...
%     - ((131072*k-3087)*sqrt(131072*k - 3087))/28311552; 
% disp(simplify(f_diff_12_21( mu1_0, mu2_0, p1_0, p2_0, k) - diff_in_paper, 'Steps',5000)) ;
 
% solve for k that makes the student indifferent between 1--2 and 2--1
eqn1 = f_diff_12_21( mu1_0, mu2_0, p1_0, p2_0, k) == 0;
eqn2 = k >= k_lbnd; 
eqn3 = k <= k_ubnd; 
S2 = solve([eqn1,eqn2,eqn3],k,'ReturnConditions',true);
disp(['no solution? ', num2str(isempty(S2.k))]);

% check if 1--2 leads to a higher payoff than 2--1 for constrained k
disp('1--2 leads to a higher payoff than 2--1 for constrained k? Yes if no message.');
for jj = k_lbnd + [0:5000]/5000*(k_ubnd -  k_lbnd)
    if double(f_diff_12_21( mu1_0, mu2_0, p1_0, p2_0, jj)) <= 0 
        disp('1--2 does not lead to a higher payoff than 2--1 for constrained k');
    end
end

fprintf('\nProb(learning X2 under DA & k0): ');
disp((100*(double(f_x1star(mu1_0, mu2_0, p1_0, p2_0, k0))+0.5-mu1_0)));

fprintf('\nWelfare under DA w/ no offer & k0: ');
disp(1000*double(f_12( mu1_0, mu2_0, p1_0, p2_0, k0)));

%% 2) early offer from 1: learning sequence 1-2

disp('======================================================='); 
disp('3.2. only early offer from university 1: solving expected utility and x1star'); 
disp('======================================================='); 
disp('no learning: EU'); 
disp(simplify(f_nolearning( mu1_0, mu2_0, 1, p2_0, k), 'Steps',5000));

disp('Learning 1 then 2 under M-DA/BM-DA: EU, x1star'); 
disp(simplify(f_12( mu1_0, mu2_0, 1, p2_0, k), 'Steps',5000));
disp(simplify(f_x1star(mu1_0, mu2_0, 1, p2_0, k), 'Steps',5000));

% check if x1star is an interior solution
x1star_not_interior = 0;
for jj = k_lbnd + [0:5000]/5000*(k_ubnd -  k_lbnd)
    if double(f_x1star(mu1_0, mu2_0, 1, p2_0, jj)) < 0 ...
            || double(f_x1star(mu1_0, mu2_0, 1, p2_0, jj)) > mu2_0 + 0.5 
        disp('x1star is not an interior solution');
        x1star_not_interior = x1star_not_interior + 1;
    end
end
disp(['x1star is an interior solution? ', num2str(x1star_not_interior==0)]);

disp('Learning 2 then 1 under M-DA/BM-DA: EU, x2star'); 
disp(simplify(f_21( mu1_0, mu2_0, 1, p2_0, k), 'Steps',5000));
disp(simplify(f_x2star(mu1_0, mu2_0, 1, p2_0, k), 'Steps',5000));

% check if x1star is an interior solution
x2star_not_interior = 0;
for jj = k_lbnd + [0:5000]/5000*(k_ubnd -  k_lbnd)
    if double(f_x2star(mu1_0, mu2_0, 1, p2_0, jj)) < 0 ...
            || double(f_x2star(mu1_0, mu2_0, 1, p2_0, jj)) > mu2_0 + 0.5 
        disp('x1star is not an interior solution');
        x2star_not_interior = x2star_not_interior + 1;
    end
end
disp(['x2star is an interior solution? ', num2str(x2star_not_interior==0)]);

disp('Difference between 1--2 and no learning under M-DA/BM-DA: '); 
disp(simplify(f_diff_12_0( mu1_0, mu2_0, 1, p2_0, k), 'Steps',5000)) ;
 
% % cross check with the expression in the paper:
% diff_in_paper = 8*k*sqrt(2*k)/9 - (63*k)/32 + 151505/1048576;
% disp(simplify(f_diff_12_0( mu1_0, mu2_0, 1, p2_0, k) - diff_in_paper, 'Steps',5000)) ;

eqn1 = f_diff_12_0( mu1_0, mu2_0, 1, p2_0, k) == 0;
eqn2 = k >= k_lbnd;
eqn3 = k <= k_ubnd; 
S1 = solve([eqn1,eqn2,eqn3],k,'ReturnConditions',true); 
disp(['no solution? ', num2str(isempty(S1.k))]);

% check if 1--2 leads to a higher payoff than no learning for constrained k
disp('1--2 leads to a higher payoff than no learning for constrained k? Yes if no message.');
for jj = k_lbnd + [0:5000]/5000*(k_ubnd -  k_lbnd)
    if double(f_diff_12_0( mu1_0, mu2_0, 1, p2_0, jj)) <= 0 
        disp('1--2 does not lead to a higher payoff than no learning for constrained k')
    end
end

disp('Difference between 1--2 and 2--1 under M-DA/BM-DA: '); 
disp(simplify(f_diff_12_21( mu1_0, mu2_0, 1, p2_0, k), 'Steps',5000)) ;

% % cross check with the expression in the paper:
% diff_in_paper = k/16 + 8*k*sqrt(2*k)/9 - (8192*k-343) *sqrt(8192*k - 343)/589824 - 1375/1048576;
% disp(simplify(f_diff_12_21( mu1_0, mu2_0, 1, p2_0, k) - diff_in_paper, 'Steps',5000)) ;

% solve for k that makes the student indifferent between 1--2 and 2--1
eqn1 = f_diff_12_21( mu1_0, mu2_0, 1, p2_0, k) == 0;
eqn2 = k >= k_lbnd;
eqn3 = k <= k_ubnd; 
S2 = solve([eqn1,eqn2,eqn3],k,'ReturnConditions',true); 
disp(['no solution? ', num2str(isempty(S2.k))]);

% check if 1--2 leads to a higher payoff than 2--1 for constrained k
disp('1--2 leads to a higher payoff than 2--1 for constrained k? Yes if no message.');
for jj = k_lbnd + [0:5000]/5000*(k_ubnd -  k_lbnd)
    if double(f_diff_12_21( mu1_0, mu2_0, 1, p2_0, jj)) <= 0 
        disp('1--2 does not lead to a higher payoff than 2--1 for constrained k')
    end
end

fprintf('\nProb(learning X2 under M-DA/BM-DA w/ offer 1 & k0): ');
disp((100*(double(f_x1star(mu1_0, mu2_0, 1, p2_0, k0))+0.5-mu1_0)));

fprintf('\nWelfare under M-DA/BM-DA w/ offer 1 & k0: '); 
disp(1000*double(f_12( mu1_0, mu2_0, 1, p2_0, k0)));

%% 3) early offer from 2: learning sequence 2--1

disp('======================================================='); 
disp('3.3. only early offer from university 2: solving expected utility and x2star'); 
disp('======================================================='); 
disp('no learning: EU'); 
disp(simplify(f_nolearning( mu1_0, mu2_0, p1_0, 1, k), 'Steps',5000));

disp('Learning 1 then 2 under M-DA/BM-DA: EU, x1star'); 
disp(simplify(f_12( mu1_0, mu2_0, p1_0, 1, k), 'Steps',5000));
disp(simplify(f_x1star(mu1_0, mu2_0, p1_0, 1, k), 'Steps',5000));

% check if x1star is an interior solution
x1star_not_interior = 0;
for jj = k_lbnd + [0:5000]/5000*(k_ubnd -  k_lbnd)
    if double(f_x1star(mu1_0, mu2_0, p1_0, 1, jj)) < 0 ...
            || double(f_x1star(mu1_0, mu2_0, p1_0, 1, jj)) > mu2_0 + 0.5 
        disp('x1star is not an interior solution');
        x1star_not_interior = x1star_not_interior + 1;
    end
end
disp(['x1star is an interior solution? ', num2str(x1star_not_interior==0)]);

disp('Learning 2 then 1 under M-DA/BM-DA: EU, x2star'); 
disp(simplify(f_21( mu1_0, mu2_0, p1_0, 1, k), 'Steps',5000));
disp(simplify(f_x2star(mu1_0, mu2_0, p1_0, 1, k), 'Steps',5000));

% check if x2star is an interior solution
x2star_not_interior = 0;
for jj = k_lbnd + [0:5000]/5000*(k_ubnd -  k_lbnd)
    if double(f_x2star(mu1_0, mu2_0, p1_0, 1, jj)) < 0 ...
            || double(f_x2star(mu1_0, mu2_0, p1_0, 1, jj)) > mu2_0 + 0.5 
        disp('x1star is not an interior solution');
        x2star_not_interior = x2star_not_interior + 1;
    end
end
disp(['x2star is an interior solution? ', num2str(x2star_not_interior==0)]);

disp('Difference between 2--1 and no learning under M-DA/BM-DA: '); 
disp(simplify(f_diff_21_0( mu1_0, mu2_0, p1_0, 1, k), 'Steps',5000)) ;

% % cross check with the expression in the paper:
%  diff_in_paper = 8*k*sqrt(2*k)/9 - 65*k/32 + 39501/262144;
%  disp(simplify(f_diff_21_0( mu1_0, mu2_0, p1_0, 1, k) - diff_in_paper, 'Steps',5000)) ;

eqn1 = f_diff_21_0( mu1_0, mu2_0, p1_0, 1, k) == 0;
eqn2 = k >= k_lbnd;
eqn3 = k <= k_ubnd; 
S1 = solve([eqn1,eqn2,eqn3],k,'ReturnConditions',true); 
disp(['no solution? ', num2str(isempty(S1.k))]);

% check if 2--1 leads to a higher payoff than no learning for constrained k
disp('2--1 leads to a higher payoff than no learning for constrained k? Yes if no message.');

for jj = k_lbnd + [0:5000]/5000*(k_ubnd -  k_lbnd)
    if double(f_diff_21_0( mu1_0, mu2_0, p1_0, 1, jj)) <= 0 
        disp('2--1 does not lead to a higher payoff than no learning for constrained k')
    end
end

disp('Difference between 2--1 and 1--2 under M-DA/BM-DA: '); 
disp(simplify(f_diff_21_12( mu1_0, mu2_0, p1_0, 1, k), 'Steps',5000)) ;

% % cross check with the expression in the paper:
% diff_in_paper = 8*k*sqrt(2*k)/9 - k/16 - (32768*k - 1575)*sqrt(32768*k - 1575)/4718592 + 789/524288;
% disp(simplify(f_diff_21_12(mu1_0, mu2_0, p1_0, 1, k) - diff_in_paper, 'Steps',5000)) ;

% solve for k that makes the student indifferent between 2--1 and 1--2
eqn1 = f_diff_21_12( mu1_0, mu2_0, p1_0, 1, k) == 0;
eqn2 = k >= k_lbnd;
eqn3 = k <= k_ubnd; 
S2 = solve([eqn1,eqn2,eqn3],k,'ReturnConditions',true); 
disp(['no solution? ', num2str(isempty(S2.k))]);

% check if 2--1 leads to a higher payoff than 1--2 for constrained k
disp('2--1 leads to a higher payoff than 1--2 for constrained k? Yes if no message.');
for jj = k_lbnd + [0:5000]/5000*(k_ubnd -  k_lbnd)
    if double(f_diff_21_12( mu1_0, mu2_0, p1_0, 1, jj)) <= 0 
        disp('2--1 does not lead to a higher payoff than 1--2 for constrained k')
    end
end

fprintf('\nProb(learning X1 under M-DA/BM-DA w/ offer 2 & k0): ');
disp((100*(double(f_x2star(mu1_0, mu2_0, p1_0, 1, k0))+0.5-mu2_0)));

fprintf('\nWelfare under M-DA/BM-DA w/ offer 2 & k0: '); 
disp(1000*double(f_21( mu1_0, mu2_0, p1_0, 1, k0)));

%% 4) early offers from 1 and 2: learning sequence 1--2 under BM-DA

disp('======================================================='); 
disp('3.4. early offers from universities 1 and 2: solving expected utility and x1star for BM-DA'); 
disp('======================================================='); 
disp('no learning: EU'); 
disp(simplify(f_nolearning( mu1_0, mu2_0, 1, 1, k), 'Steps',5000));

disp('Learning 1 then 2 under BM-DA: EU, x1star'); 
disp(simplify(f_12( mu1_0, mu2_0, 1, 1, k), 'Steps',5000));
disp(simplify(f_x1star(mu1_0, mu2_0, 1, 1, k), 'Steps',5000));

% check if x1star is an interior solution
x1star_not_interior = 0;
for jj = k_lbnd + [0:5000]/5000*(k_ubnd -  k_lbnd)
    if double(f_x1star(mu1_0, mu2_0, 1, 1, jj)) < 0 ...
            || double(f_x1star(mu1_0, mu2_0, 1, 1, jj)) > mu2_0 + 0.5 
        disp('x1star is not an interior solution');
        x1star_not_interior = x1star_not_interior + 1;
    end
end
disp(['x1star is an interior solution? ', num2str(x1star_not_interior==0)]);

disp('Learning 2 then 1 under BM-DA: EU, x2star'); 
disp(simplify(f_21( mu1_0, mu2_0, 1, 1, k), 'Steps',5000));
disp(simplify(f_x2star(mu1_0, mu2_0, 1, 1, k), 'Steps',5000));

% check if x2star is an interior solution
x2star_not_interior = 0;
for jj = k_lbnd + [0:5000]/5000*(k_ubnd -  k_lbnd)
    if double(f_x2star(mu1_0, mu2_0, 1, 1, jj)) < 0 ...
            || double(f_x2star(mu1_0, mu2_0, 1, 1, jj)) > mu2_0 + 0.5 
        disp('x1star is not an interior solution');
        x2star_not_interior = x2star_not_interior + 1;
    end
end
disp(['x2star is an interior solution? ', num2str(x2star_not_interior==0)]);

disp('Difference between 1--2 and no learning under BM-DA: '); 
disp(simplify(f_diff_12_0( mu1_0, mu2_0, 1, 1, k), 'Steps',5000)) ;

% % cross check with the expression in the paper:
% diff_in_paper = 2*k*sqrt(2*k)/3 - 63*k/32 + 35867/196608;
% disp(simplify(f_diff_12_0(mu1_0, mu2_0, 1, 1, k) - diff_in_paper, 'Steps',5000)) ;

eqn1 = f_diff_12_0( mu1_0, mu2_0, 1, 1, k) == 0;
eqn2 = k > k_lbnd;
eqn3 = k < k_ubnd; 
S1 = solve([eqn1,eqn2,eqn3],k,'ReturnConditions',true); 
disp(['no solution? ', num2str(isempty(S1.k))]);

% check if 1--2 leads to a higher payoff than no learning for constrained k
fprintf('\n 2--1 leads to a higher payoff than no learning for constrained k? Yes if no message.\n');

for jj = k_lbnd + [0:5000]/5000*(k_ubnd -  k_lbnd)
    if double(f_diff_12_0( mu1_0, mu2_0, 1, 1, jj)) <= 0 
        disp('1--2 does not lead to a higher payoff than no learning for constrained k')
    end
end

fprintf('\n Difference between 1--2 and 2--1 under BM-DA: '); 
disp(simplify(f_diff_12_21( mu1_0, mu2_0, 1, 1, k), 'Steps',5000)) ;

% % cross check with the expression in the paper:
% diff_in_paper = k/16 - 1/196608;
% disp(simplify(f_diff_12_21(mu1_0, mu2_0, 1, 1, k) - diff_in_paper, 'Steps',5000)) ;

% solve for k that makes the student indifferent between 1--2 and 2--1
eqn1 = f_diff_12_21( mu1_0, mu2_0, 1, 1, k) == 0;
eqn2 = k > k_lbnd;
eqn3 = k < k_ubnd; 
S2 = solve([eqn1,eqn2,eqn3],k,'ReturnConditions',true); 
disp(['no solution? ', num2str(isempty(S2.k))]);

% check if 1--2 leads to a higher payoff than 2--1 for constrained k
fprintf('\n1--2 leads to a higher payoff than 2--1 for constrained k? Yes if no message.\n');
for jj = k_lbnd + [0:5000]/5000*(k_ubnd -  k_lbnd)
    if double(f_diff_12_21( mu1_0, mu2_0, 1, 1, jj)) <= 0 
        disp('1--2 does not lead to a higher payoff than 2--1 for constrained k')
    end
end

fprintf('\nProb(learning X2 under M-DA/BM-DA w/ offers 1 & 2 & k0): ');
disp((100*(double(f_x1star(mu1_0, mu2_0, 1, 1, k0))+0.5-mu1_0)));

fprintf('\nWelfare under BM-DA w/ offers 1 & 2 & k0: '); 
disp(1000*double(f_12( mu1_0, mu2_0, 1, 1, k0)));

%% 5) early offer from 1 and 2 under M-DA: arrival order matters

disp('======================================================='); 
disp('3.5. M-DA: early offers from universities 1 and then 2'); 
disp('======================================================='); 
% arrival order: 1--2
% M-DA: 1--2

% Calculate two values of x1star
fprintf('\nThe first x1star (w/ offer 1 but not offer 2): ') 
disp(simplify(f_x1star(mu1_0, mu2_0, 1, p2_0, k), 'Steps',5000));
fprintf('The second x1star (w/ offer 1 and offer 2): ')
disp(simplify(f_x1star(mu1_0, mu2_0, 1, 1, k), 'Steps',5000));
fprintf('Difference between the two X1star (the new one is larger): ')
disp(simplify(f_x1star(mu1_0, mu2_0, 1, 1, k) - f_x1star(mu1_0, mu2_0, 1, p2_0, k), 'Steps',5000));

fprintf('Conclusion: after receiving offer 2, the student will learn more.\n')

fprintf('\nLearning 1 then 2 under M-DA EU: '); 
disp(simplify(f_12( mu1_0, mu2_0, 1, 1, k), 'Steps',5000));
fprintf('\nProb(learning X2 under M-DA w/ offers 2--1 & k0): ');
disp((100*(double(f_x1star(mu1_0, mu2_0, 1, 1, k0))+0.5-mu1_0)));

fprintf('\nWelfare under M-DA w/ offers 1 then 2 & k0: '); 
disp(1000*double(f_12( mu1_0, mu2_0, 1, 1, k0)));

disp('======================================================='); 
disp('M-DA: early offers from universities 2 and then 1'); 
disp('======================================================='); 
% arrival order: 2--1
% M-DA: 2--1

% Calculate two values of x1star
fprintf('\nThe first x2star (w/ offer 2 but not offer 1): ') 
disp(simplify(f_x2star(mu1_0, mu2_0, p1_0, 1, k), 'Steps',5000));
fprintf('The second x2star (w/ offer 2 and offer 1): ')
disp(simplify(f_x2star(mu1_0, mu2_0, 1, 1, k), 'Steps',5000));
fprintf('Difference between the two X2star (the new one is larger): ')
disp(simplify(f_x2star(mu1_0, mu2_0, 1, 1, k) - f_x2star(mu1_0, mu2_0, p1_0, 1, k), 'Steps',5000));

fprintf('Conclusion: after receiving offer 1, the student will learn more.\n')


fprintf('\nLearning 2 then 1 under M-DA EU: '); 
disp(simplify(f_21( mu1_0, mu2_0, 1, 1, k), 'Steps',5000));
fprintf('\nProb(learning X1 under M-DA w/ offers 2--1 & k0): ');
disp((100*(double(f_x2star(mu1_0, mu2_0, 1, 1, k0))+0.5-mu2_0)));

fprintf('\nWelfare under M-DA w/ offers 2 then 1 & k0: '); 
disp(1000*double(f_21( mu1_0, mu2_0, 1, 1, k0)));

%% 6) Expected payoff under DA conditional on early offers

disp('======================================================='); 
disp('3.6. Expected payoff under DA conditional on early offers'); 
disp('======================================================='); 

% x1star = mu2 + 0.5 - sqrt((k - 0.5*(1-p1)*p2*(mu2-0.5)^2)/(0.5*p1*p2));
% fix p1 and p2 at DA levels.
x1star_da = mu2 + 0.5 - sqrt((k - 0.5*(1-p1_0)*p2_0*(mu2-0.5)^2)/(0.5*p1_0*p2_0));

% case 1: x1 \in [mu1-0.5, 0]
eu_1_noinfo_12 = p2*mu2*(0.5-mu1);
eu_1_info_12 = eu_1_noinfo_12 + 0.5*p2*(0.5-mu2)^2*(0.5-mu1) - k*(0.5-mu1);

% case 2: x1 \in [0, mu2]
eu_2_noinfo_12 = p2*mu2*mu2 + (1-p2)*p1*mu2^2/2;
eu_2_info_12 = eu_2_noinfo_12 + 0.5*(1-p1)*p2*(0.5-mu2)^2*mu2 + 0.5*p1*p2*(1/8 - (0.5-mu2)^3)/3 - k*mu2;

% case 3: x1 \in [mu2, x1star]
eu_3_noinfo_12 = p1*(x1star_da^2 - mu2^2)/2  + (1-p1)*p2*mu2*(x1star_da-mu2);

eu_3_info_12 = eu_3_noinfo_12 + 0.5*(1-p1)*p2*(0.5-mu2)^2*(x1star_da-mu2) ...
    + 0.5*p1*p2*((x1star_da - mu2 - 0.5)^3 + 1/8)/3 - k*(x1star_da-mu2);

% case 4: x1 \in [x1star, mu1+0.5]
eu_4_noinfo_12 = p1*((mu1+0.5)^2 - x1star_da^2 )/2 + (1-p1)*p2*mu2*(mu1+0.5-x1star_da);
eu_4_info_12 = eu_4_noinfo_12;


% expected utility
eu_info_da = simplify(eu_1_info_12 + eu_2_info_12 + eu_3_info_12 + eu_4_info_12 - k,'Steps',5000);

f_da(mu1, mu2, p1, p2, k) = eu_info_da;

fprintf('\nEU under DA conditional on no offer: Cross Check \n'); 
disp(simplify(f_da( mu1_0, mu2_0, p1_0, p2_0, k), 'Steps',5000));
fprintf('\nWelfare under DA w/o offer & k0: '); 
disp(1000*double(f_da( mu1_0, mu2_0, p1_0, p2_0, k0)));

fprintf('\nEU under DA conditional on offer 1 only: \n'); 
disp(simplify(f_da( mu1_0, mu2_0, 1, p2_0, k), 'Steps',5000));
fprintf('\nWelfare under DA w/ offer 1 & k0: '); 
disp(1000*double(f_da( mu1_0, mu2_0, 1, p2_0, k0)));

fprintf('\nEU under DA conditional on offer 2 only: \n'); 
disp(simplify(f_da( mu1_0, mu2_0, p1_0, 1, k), 'Steps',5000));
fprintf('\nWelfare under DA w/ offer 2 & k0: '); 
disp(1000*double(f_da( mu1_0, mu2_0, p1_0, 1, k0)));

fprintf('\nEU under DA conditional on offer 1 and offer 2: \n'); 
disp(simplify(f_da( mu1_0, mu2_0, 1, 1, k), 'Steps',5000));
fprintf('\nWelfare under DA w/ offers 1 & 2 & k0: '); 
disp(1000*double(f_da( mu1_0, mu2_0, 1, 1, k0)));

%% Learning probabilities under each mechanism 

disp('======================================================='); 
disp('Learing probabilities in the simulation table'); 
disp('======================================================='); 

% optimally learning X1 then X2
% DA is invariant to offer arrival
sim_table.NoOffer(1) = 100;
sim_table.Offer1(1) = 100;
sim_table.Offer2(1) = 100;
sim_table.Offer12(1) = 100;
sim_table.Offer21(1) = 100;

sim_table.NoOffer(2) = (100*(double(f_x1star(mu1_0, mu2_0, p1_0, p2_0, k0))+0.5-mu1_0));
sim_table.Offer1(2) = sim_table.NoOffer(2);
sim_table.Offer2(2) = sim_table.NoOffer(2);
sim_table.Offer12(2) = sim_table.NoOffer(2);
sim_table.Offer21(2) = sim_table.NoOffer(2);

% M-DA
sim_table.NoOffer(3) = 100;
sim_table.Offer1(3) = 100;
sim_table.Offer12(3) = 100;

sim_table.NoOffer(4) = (100*(double(f_x1star(mu1_0, mu2_0, p1_0, p2_0, k0))+0.5-mu1_0));
sim_table.Offer1(4) = (100*(double(f_x1star(mu1_0, mu2_0, 1, p2_0, k0))+0.5-mu1_0));
sim_table.Offer12(4) = (100*(double(f_x1star(mu1_0, mu2_0, 1, 1, k0))+0.5-mu1_0));

% BM-DA
sim_table.NoOffer(5) = 100;
sim_table.Offer1(5) = 100;
sim_table.Offer12(5) = 100;
sim_table.Offer21(5) = 100;

sim_table.NoOffer(6) = (100*(double(f_x1star(mu1_0, mu2_0, p1_0, p2_0, k0))+0.5-mu1_0));
sim_table.Offer1(6) = (100*(double(f_x1star(mu1_0, mu2_0, 1, p2_0, k0))+0.5-mu1_0));
sim_table.Offer12(6) = (100*(double(f_x1star(mu1_0, mu2_0, 1, 1, k0))+0.5-mu1_0));
sim_table.Offer21(6) = (100*(double(f_x1star(mu1_0, mu2_0, 1, 1, k0))+0.5-mu1_0));

% optimally learning X2 then X1
sim_table.Offer2(3) = (100*(double(f_x2star(mu1_0, mu2_0, p1_0, 1, k0))+0.5-mu2_0));
sim_table.Offer2(4) = 100;
sim_table.Offer2(5) = (100*(double(f_x1star(mu1_0, mu2_0, p1_0, 1, k0))+0.5-mu1_0));
sim_table.Offer2(6) = 100;
sim_table.Offer21(3) = (100*(double(f_x2star(mu1_0, mu2_0, 1, 1, k0))+0.5-mu2_0));
sim_table.Offer21(4) = 100;

%% 7) ranking probabilities: filling the simulation table

disp('======================================================='); 
disp('Ranking probabilities in the simulation table'); 
disp('======================================================='); 

% learning sequence: 1--2
% top ranking 1
f_P1_12(mu1, mu2, p1, p2, k) =  0.5*x1star^2 - x1star*(0.5 + mu2) + (mu1+0.5); 
% top ranking 2
f_P2_12(mu1, mu2, p1, p2, k) =  (mu2+0.5)*(0.5-mu1 + x1star) - 0.5*x1star^2; 

% learning sequence: 2--1
% top ranking 1
f_P1_21(mu1, mu2, p1, p2, k) =  (mu1+0.5)*(0.5-mu2+x2star) - 0.5*x2star^2; 
% top ranking 2
f_P2_21(mu1, mu2, p1, p2, k) =  0.5*x2star^2 + (0.5-mu1)*x2star + (mu2+0.5-x2star); 

%%%%%% DA
fprintf('\nProb(top ranking 1 under DA): ')
disp(simplify(f_P1_12( mu1_0, mu2_0, p1_0, p2_0, k), 'Steps',5000));
fprintf('Prob(top ranking 1 under DA given k0): '); 
sim_table.NoOffer(7) = 100*double(f_P1_12( mu1_0, mu2_0, p1_0, p2_0, k0)); 
disp(100*double(f_P1_12( mu1_0, mu2_0, p1_0, p2_0, k0)));

% DA is equivalent to M-DA and BM-DA when there is no early offer
sim_table.NoOffer(9) = sim_table.NoOffer(7);
sim_table.NoOffer(11) = sim_table.NoOffer(7);

fprintf('\nProb(top ranking 2 under DA): ')
disp(simplify(f_P2_12( mu1_0, mu2_0, p1_0, p2_0, k), 'Steps',5000));
fprintf('Prob(top ranking 2 under DA given k0): '); 
sim_table.NoOffer(8) = 100*double(f_P2_12( mu1_0, mu2_0, p1_0, p2_0, k0));
disp(100*double(f_P2_12( mu1_0, mu2_0, p1_0, p2_0, k0)));

% DA is equivalent to M-DA and BM-DA when there is no early offer
sim_table.NoOffer(10) = sim_table.NoOffer(8);
sim_table.NoOffer(12) = sim_table.NoOffer(8);

% DA is invariant to offer arrival
sim_table.Offer1(7) = sim_table.NoOffer(7);
sim_table.Offer1(8) = sim_table.NoOffer(8);
sim_table.Offer2(7) = sim_table.NoOffer(7);
sim_table.Offer2(8) = sim_table.NoOffer(8);
sim_table.Offer12(7) = sim_table.NoOffer(7);
sim_table.Offer12(8) = sim_table.NoOffer(8);
sim_table.Offer21(7) = sim_table.NoOffer(7);
sim_table.Offer21(8) = sim_table.NoOffer(8);


%%%%%% M-DA/BM-DA w/ one early offer
% offer from univ 1
fprintf('\nProb(top ranking 1 under M-DA/BM-DA given early offer from 1): ')
disp(simplify(f_P1_12( mu1_0, mu2_0, 1, p2_0, k), 'Steps',5000));
fprintf('Prob(top ranking 1 under M-DA/BM-DA given early offer from 1 & k0): '); 
sim_table.Offer1(9) = 100*double(f_P1_12( mu1_0, mu2_0, 1, p2_0, k0)); 
sim_table.Offer1(11) = sim_table.Offer1(9); 
disp(100*double(f_P1_12( mu1_0, mu2_0, 1, p2_0, k0)));

fprintf('\nProb(top ranking 2 under M-DA/BM-DA given early offer from 1): ')
disp(simplify(f_P2_12( mu1_0, mu2_0, 1, p2_0, k), 'Steps',5000));
fprintf('Prob(top ranking 2 under M-DA/BM-DA given early offer from 1 & k0): '); 
sim_table.Offer1(10) = 100*double(f_P2_12( mu1_0, mu2_0, 1, p2_0, k0));
sim_table.Offer1(12) = sim_table.Offer1(10);
disp(100*double(f_P2_12( mu1_0, mu2_0, 1, p2_0, k0)));

% offer from univ 2
fprintf('\nProb(top ranking 1 under M-DA/BM-DA given early offer from 2): ')
disp(simplify(f_P1_21( mu1_0, mu2_0, p1_0, 1, k), 'Steps',5000));
fprintf('Prob(top ranking 1 under M-DA/BM-DA given early offer from 2 & k0): '); 
sim_table.Offer2(9) = 100*double(f_P1_21( mu1_0, mu2_0, p1_0, 1, k0)); 
sim_table.Offer2(11) = sim_table.Offer2(9); 
disp(100*double(f_P1_21( mu1_0, mu2_0, p1_0, 1, k0)));

fprintf('\nProb(top ranking 2 under M-DA/BM-DA given early offer from 2): ')
disp(simplify(f_P2_21( mu1_0, mu2_0, p1_0, 1, k), 'Steps',5000));
fprintf('Prob(top ranking 2 under M-DA/BM-DA given early offer from 2 & k0): '); 
sim_table.Offer2(10) = 100*double(f_P2_21( mu1_0, mu2_0, p1_0, 1, k0)); 
sim_table.Offer2(12) = sim_table.Offer2(10); 
disp(100*double(f_P2_21( mu1_0, mu2_0, p1_0, 1, k0)));

%%%%%% M-DA/BM-DA w/ two early offers 
% 1--2
fprintf('\nProb(top ranking 1 under M-DA/BM-DA given early offer from 1-2): ')
disp(simplify(f_P1_12( mu1_0, mu2_0, 1, 1, k), 'Steps',5000));
fprintf('Prob(top ranking 1 under M-DA/BM-DA given early offers from 1-2 & k0): '); 
sim_table.Offer12(9) = 100*double(f_P1_12( mu1_0, mu2_0, 1, 1, k0)); 
sim_table.Offer12(11) = sim_table.Offer12(9); 
disp(100*double(f_P1_12( mu1_0, mu2_0, 1, 1, k0)));

fprintf('\nProb(top ranking 2 under M-DA/BM-DA given early offer from 1-2): ')
disp(simplify(f_P2_12( mu1_0, mu2_0, 1, 1, k), 'Steps',5000));
fprintf('Prob(top ranking 2 under M-DA/BM-DA given early offers from 1-2 & k0): '); 
sim_table.Offer12(10) = 100*double(f_P2_12( mu1_0, mu2_0, 1, 1, k0)); 
sim_table.Offer12(12) = sim_table.Offer12(10); 
disp(100*double(f_P2_12( mu1_0, mu2_0, 1, 1, k0)));

% 2--1
fprintf('\nProb(top ranking 1 under M-DA given early offer from 2-1): ')
disp(simplify(f_P1_21( mu1_0, mu2_0, 1, 1, k), 'Steps',5000));
fprintf('Prob(top ranking 1 under M-DA/BM-DA given early offer from 2-1 & k0): '); 
sim_table.Offer21(9) = 100*double(f_P1_21( mu1_0, mu2_0, 1, 1, k0)); 
disp(100*double(f_P1_21( mu1_0, mu2_0, 1, 1, k0)));

fprintf('\nProb(top ranking 2 under M-DA given early offer from 2-1): ')
disp(simplify(f_P2_21( mu1_0, mu2_0, 1, 1, k), 'Steps',5000));
fprintf('Prob(top ranking 2 under M-DA/BM-DA given early offer from 2-1 & k0): '); 
sim_table.Offer21(10) = 100*double(f_P2_21( mu1_0, mu2_0, 1, 1, k0)); 
disp(100*double(f_P2_21( mu1_0, mu2_0, 1, 1, k0)));

% BM-DA is invariant to 1--2 or 2--1
sim_table.Offer21(11) = sim_table.Offer12(11); 
sim_table.Offer21(12) = sim_table.Offer12(12); 

%% 8) checking results 

% i) Welfare: BM-DA strictly dominates M-DA with two offers (2--1)
%             BM-DA strictly dominates DA with any offer

fprintf('\ni) Checking the welfare dominance of BM-DA over M-DA and DA...\n');
ind_mda = 0;
ind_da = 0;

for jj = k_lbnd + [0:5000]/5000*(k_ubnd -  k_lbnd)
    if double(f_12( mu1_0, mu2_0, 1, 1, jj)-f_21(mu1_0, mu2_0, 1, 1, jj)) <= 0
        ind_mda = ind_mda + 1;
    end
    if double(f_12( mu1_0, mu2_0, 1, 1, jj)-f_da(mu1_0, mu2_0, 1, 1, jj)) <= 0 || ...
            double(f_21( mu1_0, mu2_0, p1_0, 1, jj)-f_da(mu1_0, mu2_0, p1_0, 1, jj)) <= 0  || ...
            double(f_12( mu1_0, mu2_0, 1, p2_0, jj)-f_da(mu1_0, mu2_0, 1, p2_0, jj)) <= 0
        ind_da = ind_da + 1;
    end
end
if ind_mda == 0
    disp('BM-DA dominates M-DA in terms of welfare for constrained k w/ offers 2--1');
elseif ind_mda > 0
    disp('BM-DA does NOT dominate M-DA in terms of welfare for constrained k w/ offers 2--1');
end
if ind_da == 0
    disp('BM-DA dominates DA in terms of welfare for constrained k w/ any offer');
elseif ind_da > 0
    disp('BM-DA does NOT dominate DA in terms of welfare for constrained k w/ any offer');
end

% ii) Welfare: DA strictly dominates M-DA with two offers (2--1)

fprintf('\nii) Checking the welfare dominance of DA over M-DA w/ offers 2--1...\n');
ind_da = 0;

for jj = k_lbnd + [0:5000]/5000*(k_ubnd -  k_lbnd)
    if double(f_da( mu1_0, mu2_0, 1, 1, jj)-f_21(mu1_0, mu2_0, 1, 1, jj)) <= 0 
        ind_da = ind_da + 1;
    end
end
if ind_da == 0
    disp('DA dominates M-DA in terms of welfare for constrained k w/ offers 2--1');
elseif ind_da > 0
    disp('DA does NOT dominate M-DA in terms of welfare for constrained k w/ offers 2--1');
end

% iii) Learning behavior under M-DA, 
%          for either university, its early offer increases the
%          probability that the university?s quality is learned by the
%          student.  

fprintf('\niii) Check the learning probabilities: early offer effects...\n');
ind_learn = 0;

for jj = k_lbnd + [0:5000]/5000*(k_ubnd -  k_lbnd)
    if double(1 - 1) < 0  || ... % offer 1 versus no offer. 
            double(f_x1star(mu1_0, mu2_0, 1, 1, jj) - f_x1star(mu1_0, mu2_0, 1, p2_0, jj)) < 0 || ... % offers 1--2 versus just 1. 
            double(1 + mu2_0 - 0.5 - f_x2star(mu1_0, mu2_0, p1_0, 1, jj)) < 0 || ... % offers 1--2 versus just 2. 
            double(1 + mu1_0 - 0.5- f_x1star(mu1_0, mu2_0, 1, p2_0, jj)) < 0 || ...    % offers 2--1 versus just 1. 
            double(f_x2star(mu1_0, mu2_0, 1, 1, jj) - f_x2star(mu1_0, mu2_0, p1_0, 1, jj)) < 0 || ...    % offers 2--1 versus just 2. 
            double(1 + mu1_0 - 0.5 - f_x1star(mu1_0, mu2_0, p1_0, p2_0, jj)) < 0        % offer 2 versus no offer
        ind_learn = ind_learn + 1;
    end
end
if ind_learn == 0
    disp('M-DA: early offer increases the prob. of it being learned');
elseif ind_learn > 0
    disp('M-DA: early offer doest NOT increase the prob. of it being learned');
end

% (iv) Early offer effects on offer acceptance under M-DA: 
%      Under M-DA, for either university, receiving an early offer from it
%      strictly increases the probability that the offer is accepted.   
fprintf('\niv) Check the acceptance probabilities: early offer effects...\n');
ind_rank = 0;

for jj = k_lbnd + [0:5000]/5000*(k_ubnd -  k_lbnd)
    if double(f_P1_12(mu1_0, mu2_0, 1, p2_0, jj) - f_P1_12(mu1_0, mu2_0, p1_0, p2_0, jj)) <= 0  || ... % offer 1 versus no offer. 
            double(f_P2_12(mu1_0, mu2_0, 1, 1, jj) - f_P2_12(mu1_0, mu2_0, 1, p2_0, jj)) <= 0 || ... % offers 1--2 versus just 1. 
            double(f_P1_12(mu1_0, mu2_0, 1, 1, jj) - f_P1_21(mu1_0, mu2_0, p1_0, 1, jj)) <= 0 || ... % offers 1--2 versus just 2. 
            double(f_P2_21(mu1_0, mu2_0, 1, 1, jj) - f_P2_12(mu1_0, mu2_0, 1, p2_0, jj)) <= 0 || ...    % offers 2--1 versus just 1. 
            double(f_P1_21(mu1_0, mu2_0, 1, 1, jj) - f_P1_12(mu1_0, mu2_0, p1_0, 1, jj)) <= 0 || ...    % offers 2--1 versus just 2. 
            double(f_P2_21(mu1_0, mu2_0, p1_0, 1, jj) - f_P2_12(mu1_0, mu2_0, p1_0, p2_0, jj)) <= 0       % offer 2 versus no offer
        ind_rank = ind_rank + 1;
    end
end
if ind_learn == 0
    disp('M-DA: early offer strictly increases the prob. of it being accepted');
elseif ind_learn > 0
    disp('M-DA: early offer doest NOT strictly increase the prob. of it being accepted');
end

% (v) First early offer effects on offer acceptance under M-DA: 
%     Under M-DA, conditional on the students receiving two early offers, 
%     if a university sends the first early offer, the probability that its 
%     offer is accepted is strictly increased    

fprintf('\nv) Check the acceptance probabilities: first early offer effects...\n');
ind_first = 0;

for jj = k_lbnd + [0:5000]/5000*(k_ubnd -  k_lbnd)
    if double(f_P1_12(mu1_0, mu2_0, 1, 1, jj) - f_P1_21(mu1_0, mu2_0, 1, 1, jj)) <= 0 || ... % offers 1--2 versus  2--1: top rank 1 
          double(f_P2_21(mu1_0, mu2_0, 1, 1, jj) - f_P2_12(mu1_0, mu2_0, 1, 1, jj)) <= 0    % offers 2--1 versus 1--2: top rank 2 
        ind_first = ind_first + 1;
    end
end
if ind_first == 0
    disp('M-DA: first early offer strictly increases the prob. of it being accepted');
elseif ind_first > 0
    disp('M-DA: first early offer doest NOT strictly increase the prob. of it being accepted');
end

%% Welfare under each mechanism and welfare difference

% welfare under each mechanism

disp('======================================================='); 
disp('Welfare in the simulation table'); 
disp('======================================================='); 

disp('welfare under DA: no early offer, offer from 1, offer from 2, offer from 1--2/2--1');
sim_table.NoOffer(13) = 1000*double(f_da( mu1_0, mu2_0, p1_0, p2_0, k0)); 
sim_table.Offer1(13) = 1000*double(f_da( mu1_0, mu2_0, 1, p2_0, k0));
sim_table.Offer2(13) = 1000*double(f_da( mu1_0, mu2_0, p1_0, 1, k0));
sim_table.Offer12(13) = 1000*double(f_da( mu1_0, mu2_0, 1, 1, k0));
sim_table.Offer21(13) = sim_table.Offer12(13); 

disp(1000*double(f_da( mu1_0, mu2_0, p1_0, p2_0, k0)));
disp(1000*double(f_da( mu1_0, mu2_0, 1, p2_0, k0)));
disp(1000*double(f_da( mu1_0, mu2_0, p1_0, 1, k0)));
disp(1000*double(f_da( mu1_0, mu2_0, 1, 1, k0)));

disp('welfare under M-DA: no early offer, offer from 1, offer from 2, offer from 1--2, 2--1');
sim_table.NoOffer(14) = 1000*double(f_12( mu1_0, mu2_0, p1_0, p2_0, k0)); 
sim_table.Offer1(14) = 1000*double(f_12( mu1_0, mu2_0, 1, p2_0, k0));
sim_table.Offer2(14) = 1000*double(f_21( mu1_0, mu2_0, p1_0, 1, k0));
sim_table.Offer12(14) = 1000*double(f_12( mu1_0, mu2_0, 1, 1, k0));
sim_table.Offer21(14) = 1000*double(f_21( mu1_0, mu2_0, 1, 1, k0));

disp(1000*double(f_12( mu1_0, mu2_0, p1_0, p2_0, k0)));
disp(1000*double(f_12( mu1_0, mu2_0, 1, p2_0, k0)));
disp(1000*double(f_21( mu1_0, mu2_0, p1_0, 1, k0)));
disp(1000*double(f_12( mu1_0, mu2_0, 1, 1, k0)));
disp(1000*double(f_21( mu1_0, mu2_0, 1, 1, k0)));

disp('welfare under BM-DA: no early offer, offer from 1, offer from 2, offer from 1--2/2--1');
sim_table.NoOffer(15) = 1000*double(f_12( mu1_0, mu2_0, p1_0, p2_0, k0)); 
sim_table.Offer1(15) = 1000*double(f_12( mu1_0, mu2_0, 1, p2_0, k0));
sim_table.Offer2(15) = 1000*double(f_21( mu1_0, mu2_0, p1_0, 1, k0));
sim_table.Offer12(15) = 1000*double(f_12( mu1_0, mu2_0, 1, 1, k0));
sim_table.Offer21(15) = 1000*double(f_12( mu1_0, mu2_0, 1, 1, k0));

disp(1000*double(f_12( mu1_0, mu2_0, p1_0, p2_0, k0)));
disp(1000*double(f_12( mu1_0, mu2_0, 1, p2_0, k0)));
disp(1000*double(f_21( mu1_0, mu2_0, p1_0, 1, k0)));
disp(1000*double(f_12( mu1_0, mu2_0, 1, 1, k0)));

% welfare difference
disp('=====');
fprintf('\n Checking welfare difference...\n');

disp('M-DA/BM-DA vs. DA: offer from 1');
disp(simplify((f_12( mu1_0, mu2_0, 1, p2_0, k) - f_da( mu1_0, mu2_0, 1, p2_0, k)),'Steps',5000));
disp(1000*double((f_12( mu1_0, mu2_0, 1, p2_0, k0) - f_da( mu1_0, mu2_0, 1, p2_0, k0))));

disp('M-DA/BM-DA vs. DA: offer from 2');
disp(simplify((f_21( mu1_0, mu2_0, p1_0, 1, k) - f_da( mu1_0, mu2_0, p1_0, 1, k)),'Steps',5000));
disp(1000*double((f_21( mu1_0, mu2_0, p1_0, 1, k0) - f_da( mu1_0, mu2_0, p1_0, 1, k0))));

disp('BM-DA vs. DA: offers from 2--1 or 1--2');
disp(simplify((f_12( mu1_0, mu2_0, 1, 1, k) - f_da( mu1_0, mu2_0, 1, 1, k)),'Steps',5000));
disp(1000*double((f_12( mu1_0, mu2_0, 1, 1, k0) - f_da( mu1_0, mu2_0, 1, 1, k0))));

fprintf('\n Checking welfare difference: BM-DA vs. DA...\n');
ind_diff = 0;

for jj = k_lbnd + [0:500]/500*(k_ubnd -  k_lbnd)
    if double(f_12(mu1_0, mu2_0, 1, p2_0, jj) - f_da(mu1_0, mu2_0, 1, p2_0, jj)) <= 0  || ...  
            double(f_21(mu1_0, mu2_0, p1_0, 1, jj) - f_da(mu1_0, mu2_0, p1_0, 1, jj)) <= 0 || ...
            double(f_12(mu1_0, mu2_0, 1, 1, jj) - f_da(mu1_0, mu2_0, 1, 1, jj)) <= 0 
        ind_diff = ind_diff + 1;
    end
end
if ind_diff == 0
    disp('BM-DA dominates DA');
elseif ind_diff > 0
    disp('BM-DA does NOT dominate DA');
end

disp('=====');

disp('M-DA vs. BM-DA: offers from 2--1');
disp(simplify((f_12( mu1_0, mu2_0, 1, 1, k) - f_21( mu1_0, mu2_0, 1, 1, k)),'Steps',5000));
disp(1000*double((f_12( mu1_0, mu2_0, 1, 1, k0) - f_21( mu1_0, mu2_0, 1, 1, k0))));

disp('=====');

disp('M-DA vs. DA: offers from 2--1');
disp(simplify((f_da( mu1_0, mu2_0, 1, 1, k) - f_21( mu1_0, mu2_0, 1, 1, k)),'Steps',5000));
disp(1000*double((f_da( mu1_0, mu2_0, 1, 1, k0) - f_21( mu1_0, mu2_0, 1, 1, k0))));

fprintf('\n Check welfare difference (offers 2--1): DA vs. M-DA...\n');
ind_diff = 0;

for jj = k_lbnd + [0:500]/500*(k_ubnd -  k_lbnd)
    if double(f_21(mu1_0, mu2_0, 1, 1, jj) - f_da(mu1_0, mu2_0, 1, 1, jj)) >= 0  
        ind_diff = ind_diff + 1;
    end
end
if ind_diff == 0
    disp('DA dominates M-DA');
elseif ind_diff > 0
    disp('DA does NOT dominate M-DA');
end

%% save the table and data

writetable(sim_table,fullfile(dir_fig,'table_6.csv'),'Delimiter',',','QuoteStrings',true)

save(fullfile(dir_fig,'example_data.mat'))

toc
datetime('now') 

%% Creating two figures: data preperation

tic
datetime('now') 

load('example_data.mat');

learn_0 = NaN(1,1000);
nolearn_0 = learn_0;
learn_1 = learn_0;
nolearn_1 = learn_0;

diff_0 = learn_0;
diff_1 = learn_0;
diff_12 = learn_0;
first = 1;
x1star_0 = mu2_0 + 0.5 - sqrt((k0 - 0.5*(1-p1_0)*p2_0*(mu2_0-0.5)^2)/(0.5*p1_0*p2_0));

x = [1:1000]/1000-0.5+mu1_0; 
parfor jj = 1:1000
    [learn_0(jj), nolearn_0(jj), diff_0(jj)] = f_cond_eu(x(jj),mu1_0,mu2_0,p1_0,p2_0,k0,first);
end

% early offer from 1
x1star_1 = mu2_0 + 0.5 - sqrt((k0 - 0.5*(1-1)*p2_0*(mu2_0-0.5)^2)/(0.5*1*p2_0));
parfor jj = 1:1000
    [learn_1(jj), nolearn_1(jj), diff_1(jj)] = f_cond_eu(x(jj),mu1_0,mu2_0,1,p2_0,k0,first);
end

% early offer from 1 then from 2
x1star_12 = mu2_0 + 0.5 - sqrt((k0 - 0.5*(1-1)*1*(mu2_0-0.5)^2)/(0.5*1*1));
parfor jj = 1:1000
    [~, ~, diff_12(jj)] = f_cond_eu(x(jj),mu1_0,mu2_0,1,1,k0,first);
end

%% figure:  no early offer; learning sequence 1-2; color

close all

figure('Name','Expected Utility with/without Learning X_2','NumberTitle','off')
% axis equal;
axis([mu1_0-0.5 mu1_0+0.5 0 0.57]);
legend_names_g=cell(2,1);
legend_names_g{2} = ['Payoff given learning $X_2$ \& {\bf no} early offer'];
legend_names_g{1} = ['Payoff given {\bf not} learning $X_2$ \& {\bf no} early offer'];

hold on;
% no early offer
plot(x,nolearn_0,'-','Color','blue','MarkerSize',4,'LineWidth',2);
plot(x,learn_0,'-.','Color','red','MarkerSize',4,'LineWidth',2);

xlabel({'{\bf Realization of $X_1$ (already learned by student)}'},'FontSize',20,'Interpreter', 'latex');
ylabel({'{\bf Payoff given realization of $X_1$}'}, 'FontSize',19,'Interpreter', 'latex');

line([x1star_0 x1star_0], [0 1],'LineStyle',':','LineWidth',2);

line([0 0], [0 1],'LineStyle',':','LineWidth',2);


txt1 = '{The student does not learn $X_2$ and ranks $1$ above $2$.}';
%txt2 = '{~~and ranks univ. $1$ above $2$.}';
text(x1star_0+0.015,0.555,txt1,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
%text(x1star_0,0.54,txt2,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')

txt1 = '{The student learns $X_2$}';
txt2 = 'and, depending on ';
txt3 = 'the realization of $X_2$, ';
txt4 = 'top-ranks 1 or 2.';
text(0.008,0.555,txt1,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(0.008,0.525,txt2,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(0.008,0.495,txt3,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(0.008,0.465,txt4,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')

txt0 = '{Program 1 is unacceptable.}';
txt1 = '{The student learns $X_2$ and,}';
txt2 = 'depending on the realization of $X_2$,';
txt3 = 'top-ranks 2 or the outside option.';
text(mu1_0-0.47,0.555,txt0,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(mu1_0-0.47,0.525,txt1,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(mu1_0-0.47,0.495,txt2,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(mu1_0-0.47,0.465,txt3,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')

% no early offer 
txt = '$\swarrow$';
text(x1star_0,0.02,txt,'Interpreter', 'latex','FontSize',20)
txt = '{Threshold w/o early offer}: $X^*_1(p_1^0,p_2^0)$'; % \equiv \mu_2 + \frac{1}{2} - \sqrt{\frac{2k - (1-p_1^0)p_2^0(\mu_2-\frac{1}{2})^2}{p_1^0p_2^0}}$';
text(x1star_0+0.01,0.04,txt,'Interpreter', 'latex','FontSize',20)


% color the region that X_2 is learned
p = patch([mu1_0-0.5 mu1_0-0.5 x1star_0 x1star_0],[0 0.6 0.6 0],'');
set(p,'FaceAlpha',0.05)
set(p,'EdgeColor','none')

% color the region that X_2 is learned and x_1>0
p = patch([0 0 x1star_0 x1star_0],[0 0.6 0.6 0],'');
set(p,'FaceAlpha',0.06)
set(p,'EdgeColor','none')

g_legend = legend(legend_names_g,'FontSize',20, 'EdgeColor', 'none', 'Location','southwest','Orientation','vertical','Interpreter', 'latex');
legend('boxoff');
set(g_legend,'FontSize',24);
hold off;

disp('Manually ddjust the graph before saving it. Press any key to continue.');
pause 

print(fullfile(dir_fig,'figure_5a_color.eps'),'-depsc2');
% close all
% disp('-------------------------------------------------------------------')

%% figure:  no early offer; learning sequence 1-2; no color

close all

figure('Name','Expected Utility with/without Learning X_2','NumberTitle','off')
% axis equal;
axis([mu1_0-0.5 mu1_0+0.5 0 0.57]);
legend_names_g=cell(2,1);
legend_names_g{2} = ['Payoff given learning $X_2$ \& {\bf no} early offer'];
legend_names_g{1} = ['Payoff given {\bf not} learning $X_2$ \& {\bf no} early offer'];

hold on;
% no early offer
plot(x,nolearn_0,'-','Color','black','MarkerSize',4,'LineWidth',3);
plot(x,learn_0,'-.','Color','black','MarkerSize',6,'LineWidth',3);

xlabel({'{\bf Realization of $X_1$ (already learned by student)}'},'FontSize',20,'Interpreter', 'latex');
ylabel({'{\bf Payoff given realization of $X_1$}'}, 'FontSize',19,'Interpreter', 'latex');

line([x1star_0 x1star_0], [0 1],'LineStyle',':','LineWidth',2,'Color','black');

line([0 0], [0 1],'LineStyle',':','LineWidth',2,'Color','black');


txt1 = '{The student does not learn $X_2$ and ranks $1$ above $2$.}';
%txt2 = '{~~and ranks univ. $1$ above $2$.}';
text(x1star_0+0.015,0.555,txt1,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
%text(x1star_0,0.54,txt2,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')

txt1 = '{The student learns $X_2$}';
txt2 = 'and, depending on ';
txt3 = 'the realization of $X_2$, ';
txt4 = 'top-ranks 1 or 2.';
text(0.008,0.555,txt1,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(0.008,0.525,txt2,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(0.008,0.495,txt3,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(0.008,0.465,txt4,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')

txt0 = '{Program 1 is unacceptable.}';
txt1 = '{The student learns $X_2$ and,}';
txt2 = 'depending on the realization of $X_2$,';
txt3 = 'top-ranks 2 or the outside option.';
text(mu1_0-0.47,0.555,txt0,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(mu1_0-0.47,0.525,txt1,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(mu1_0-0.47,0.495,txt2,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(mu1_0-0.47,0.465,txt3,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')

% no early offer 
txt = '$\swarrow$';
text(x1star_0,0.02,txt,'Interpreter', 'latex','FontSize',20)
txt = '{Threshold w/o early offer}: $X^*_1(p_1^0,p_2^0)$'; % \equiv \mu_2 + \frac{1}{2} - \sqrt{\frac{2k - (1-p_1^0)p_2^0(\mu_2-\frac{1}{2})^2}{p_1^0p_2^0}}$';
text(x1star_0+0.01,0.04,txt,'Interpreter', 'latex','FontSize',20)


% color the region where X_2 is learned
% p = patch([mu1_0-0.5 mu1_0-0.5 x1star_0 x1star_0],[0 0.6 0.6 0],'');
% set(p,'FaceAlpha',0.05)
% set(p,'EdgeColor','none')

% color the region that X_2 is learned and x_1>0
p = patch([0 0 x1star_0 x1star_0],[0 0.6 0.6 0],'');
set(p,'FaceAlpha',0.1,'FaceColor', [17 17 17]/255)
set(p,'EdgeColor','none')

g_legend = legend(legend_names_g,'FontSize',20, 'EdgeColor', 'none', 'Location','southwest','Orientation','vertical','Interpreter', 'latex');
legend('boxoff');
set(g_legend,'FontSize',24);
hold off;

disp('Manually ddjust the graph before saving it. Press any key to continue.');
pause 

print(fullfile(dir_fig,'figure_5a.eps'),'-depsc2');

%% figure: one early offer from 1, color

close all

figure('Name','Expected Utility with/without Learning X_2','NumberTitle','off')
% axis equal;
axis([mu1_0-0.5 mu1_0+0.5 0 0.57]);
% ax.PlotBoxAspectRatio = [1 0.75 0.75];

legend_names_g=cell(4,1);
legend_names_g{4} = ['Payoff given learning $X_2$ \& {\bf early offer from 1}'];
legend_names_g{3} = ['Payoff given {\bf not} learning $X_2$ \& {\bf early offer from 1}'];
legend_names_g{2} = ['~'];
legend_names_g{1} = ['~'];

hold on;
% no early offer
plot1 = plot(x,nolearn_0,'-','Color',[0.9 0.9 0.9],'MarkerSize',4,'LineWidth',2);
plot2 = plot(x,learn_0,'-.','Color',[0.9 0.9 0.9],'MarkerSize',4,'LineWidth',2);
% early offer from 1
plot3 = plot(x,nolearn_1,'-','Color','blue','MarkerSize',4,'LineWidth',2);
plot4 = plot(x,learn_1,'-.','Color','red','MarkerSize',4,'LineWidth',2);


xlabel({'{\bf Realization of $X_1$ (already learned by student)}'},'FontSize',20,'Interpreter', 'latex');
% ylabel({'{\bf Expected utility (EU) given the realization of $X_1$}'}, 'FontSize',19,'Interpreter', 'latex');
ylabel({'{\bf Payoff given realization of $X_1$}'}, 'FontSize',19,'Interpreter', 'latex');

line([x1star_0 x1star_0], [0 1],'LineStyle',':','LineWidth',1.5,'Color',[17 17 17]/255);

line([x1star_1 x1star_1], [0 1],'LineStyle',':','LineWidth',2);

line([0 0], [0 1],'LineStyle',':','LineWidth',2);


txt1 = '{The student does not learn $X_2$ and ranks $1$ above $2$.}';
%txt2 = '{~~and ranks univ. $1$ above $2$.}';
text(x1star_1+0.015,0.555,txt1,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
%text(x1star_0,0.54,txt2,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')

txt1 = '{The student}';
txt2 = 'learns $X_2$ and,';
txt3 = 'depending on';
txt4 = 'the realization';
txt5 = 'of $X_2$, top';
txt6 = '-ranks 1 or 2.';
text(0.01,0.555,txt1,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(0.01,0.525,txt2,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(0.01,0.495,txt3,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(0.01,0.465,txt4,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(0.01,0.435,txt5,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(0.01,0.405,txt6,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')

txt0 = '{Program 1 is unacceptable.}';
txt1 = '{The student learns $X_2$ and,}';
txt2 = 'depending on the realization of $X_2$,';
txt3 = 'top-ranks 2 or the outside option.';
text(mu1_0-0.47,0.555,txt0,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(mu1_0-0.47,0.525,txt1,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(mu1_0-0.47,0.495,txt2,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(mu1_0-0.47,0.465,txt3,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')

% no early offer 
txt = '$\swarrow$';
text(x1star_0,0.06,txt,'Interpreter', 'latex','FontSize',20)
txt = '{Threshold {\bf w/o} early offer}:~~~~~~~~~$X^*_1(p_1^0,p_2^0)$'; % \equiv \mu_2 + \frac{1}{2} - \sqrt{\frac{2k - (1-p_1^0)p_2^0(\mu_2-\frac{1}{2})^2}{p_1^0p_2^0}}$';
text(x1star_0+0.01,0.075,txt,'Interpreter', 'latex','FontSize',20)

% early offer from 1
txt = '$\longleftarrow$\textbf{\textemdash\textemdash}';
text(x1star_1,0.03,txt,'Interpreter', 'latex','FontSize',20)
txt = '{Threshold {\bf w/} early offer from 1}: $ X^*_1(1,p_2^0)$'; % \equiv \mu_2 + \frac{1}{2} - \sqrt{\frac{2k}{p_2^0}}$';
text(x1star_0+0.01,0.03,txt,'Interpreter', 'latex','FontSize',20)

% effects of early offer from 1
txt = '{\bf $\Longleftarrow$}';
text(x1star_1+0.004,0.41,txt,'Interpreter', 'latex','FontSize',30, 'color','red')
txt = '{\bf Effects of early offer from 1}:';
text(x1star_0+0.01,0.45,txt,'Interpreter', 'latex','FontSize',20)
txt = '$\Pr$(learning $X_2$)~~~{\bf $\downarrow$}';
text(x1star_0+0.01,0.41,txt,'Interpreter', 'latex','FontSize',20)
txt = '$\Pr$(top-ranking $1$) {\bf $\uparrow$}';
text(x1star_0+0.01,0.37,txt,'Interpreter', 'latex','FontSize',20)

% color the region that is changed ranking behavior
p = patch([x1star_1 x1star_1 x1star_0 x1star_0],[0 0.6 0.6 0],'');
set(p,'FaceAlpha',0.05,'FaceColor',[17 17 17]/255)
set(p,'EdgeColor','none')

% color the region where X_2 is not learned
p = patch([mu1_0-0.5 mu1_0-0.5 x1star_1 x1star_1],[0 0.6 0.6 0],'');
set(p,'FaceAlpha',0.05)
set(p,'EdgeColor','none')

% color the region that is changed ranking behavior
p = patch([0 0 x1star_1 x1star_1],[0 0.6 0.6 0],'');
set(p,'FaceAlpha',0.06)
set(p,'EdgeColor','none')

g_legend = legend([plot3 plot4],{legend_names_g{3} legend_names_g{4}}, 'EdgeColor', 'none', 'Location','southwest','Orientation','vertical','Interpreter', 'latex');
legend('boxoff');
set(g_legend,'FontSize',24);
hold off;

disp('Manually ddjust the graph before saving it. Press any key to continue.');
pause 

print(fullfile(dir_fig,'figure_5b_color.eps'),'-depsc2');

toc 
datetime('now') 

%% figure: one early offer from 1, no color

close all

figure('Name','Expected Utility with/without Learning X_2','NumberTitle','off')
% axis equal;
axis([mu1_0-0.5 mu1_0+0.5 0 0.57]);
% ax.PlotBoxAspectRatio = [1 0.75 0.75];

legend_names_g=cell(4,1);
legend_names_g{4} = ['Payoff given learning $X_2$ \& {\bf early offer from 1}'];
legend_names_g{3} = ['Payoff given {\bf not} learning $X_2$ \& {\bf early offer from 1}'];
legend_names_g{2} = ['~'];
legend_names_g{1} = ['~'];

hold on;
% no early offer
plot1 = plot(x,nolearn_0,'-','Color','black','MarkerSize',2,'LineWidth',1);
plot2 = plot(x,learn_0,'-.','Color','black','MarkerSize',2,'LineWidth',1);
% early offer from 1
plot3 = plot(x,nolearn_1,'-','Color','black','MarkerSize',4,'LineWidth',3);
plot4 = plot(x,learn_1,'-.','Color','black','MarkerSize',6,'LineWidth',3);


xlabel({'{\bf Realization of $X_1$ (already learned by student)}'},'FontSize',20,'Interpreter', 'latex');
% ylabel({'{\bf Expected utility (EU) given the realization of $X_1$}'}, 'FontSize',19,'Interpreter', 'latex');
ylabel({'{\bf Payoff given realization of $X_1$}'}, 'FontSize',19,'Interpreter', 'latex');

line([x1star_0 x1star_0], [0 1],'LineStyle',':','LineWidth',1.5,'Color','black');

line([x1star_1 x1star_1], [0 1],'LineStyle',':','LineWidth',2,'Color','black');

line([0 0], [0 1],'LineStyle',':','LineWidth',2,'Color','black');


txt1 = '{The student does not learn $X_2$ and ranks $1$ above $2$.}';
%txt2 = '{~~and ranks univ. $1$ above $2$.}';
text(x1star_1+0.015,0.555,txt1,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
%text(x1star_0,0.54,txt2,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')

txt1 = '{The student}';
txt2 = 'learns $X_2$ and,';
txt3 = 'depending on';
txt4 = 'the realization';
txt5 = 'of $X_2$, top';
txt6 = '-ranks 1 or 2.';
text(0.01,0.555,txt1,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(0.01,0.525,txt2,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(0.01,0.495,txt3,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(0.01,0.465,txt4,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(0.01,0.435,txt5,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(0.01,0.405,txt6,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')

txt0 = '{Program 1 is unacceptable.}';
txt1 = '{The student learns $X_2$ and,}';
txt2 = 'depending on the realization of $X_2$,';
txt3 = 'top-ranks 2 or the outside option.';
text(mu1_0-0.47,0.555,txt0,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(mu1_0-0.47,0.525,txt1,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(mu1_0-0.47,0.495,txt2,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')
text(mu1_0-0.47,0.465,txt3,'FontSize',20, 'HorizontalAlignment', 'left','Interpreter', 'latex')

% no early offer 
txt = '$\swarrow$';
text(x1star_0,0.06,txt,'Interpreter', 'latex','FontSize',20)
txt = '{Threshold {\bf w/o} early offer}:~~~~~~~~~$X^*_1(p_1^0,p_2^0)$'; % \equiv \mu_2 + \frac{1}{2} - \sqrt{\frac{2k - (1-p_1^0)p_2^0(\mu_2-\frac{1}{2})^2}{p_1^0p_2^0}}$';
text(x1star_0+0.01,0.075,txt,'Interpreter', 'latex','FontSize',20)

% early offer from 1
txt = '$\longleftarrow$\textbf{\textemdash\textemdash}';
text(x1star_1,0.03,txt,'Interpreter', 'latex','FontSize',20)
txt = '{Threshold {\bf w/} early offer from 1}: $ X^*_1(1,p_2^0)$'; % \equiv \mu_2 + \frac{1}{2} - \sqrt{\frac{2k}{p_2^0}}$';
text(x1star_0+0.01,0.03,txt,'Interpreter', 'latex','FontSize',20)

% effects of early offer from 1
txt = '{\bf $\Longleftarrow$}';
text(x1star_1+0.004,0.41,txt,'Interpreter', 'latex','FontSize',30, 'color','black')
txt = '{\bf Effects of early offer from 1}:';
text(x1star_0+0.01,0.45,txt,'Interpreter', 'latex','FontSize',20)
txt = '$\Pr$(learning $X_2$)~~~{\bf $\downarrow$}';
text(x1star_0+0.01,0.41,txt,'Interpreter', 'latex','FontSize',20)
txt = '$\Pr$(top-ranking $1$) {\bf $\uparrow$}';
text(x1star_0+0.01,0.37,txt,'Interpreter', 'latex','FontSize',20)

% % color the region that is changed learning behavior
% p = patch([x1star_1 x1star_1 x1star_0 x1star_0],[0 0.6 0.6 0],'');
% set(p,'FaceAlpha',0.05,'FaceColor',[17 17 17]/255)
% set(p,'EdgeColor','none')
% 
% % color the region that X_2 is learned
% p = patch([mu1_0-0.5 mu1_0-0.5 x1star_1 x1star_1],[0 0.6 0.6 0],'');
% set(p,'FaceAlpha',0.05)
% set(p,'EdgeColor','none')

% color the region that X_2 is learned and x_1>0
p = patch([0 0 x1star_1 x1star_1],[0 0.6 0.6 0],'');
set(p,'FaceAlpha',0.1,'FaceColor', [17 17 17]/255)
set(p,'EdgeColor','none')

g_legend = legend([plot3 plot4],{legend_names_g{3} legend_names_g{4}}, 'EdgeColor', 'none', 'Location','southwest','Orientation','vertical','Interpreter', 'latex');
legend('boxoff');
set(g_legend,'FontSize',24);
hold off;

disp('Manually ddjust the graph before saving it. Press any key to continue.');
pause 

print(fullfile(dir_fig,'figure_5b.eps'),'-depsc2');

toc 
datetime('now') 

close all
disp('-------------------------------------------------------------------')
