%==========================================================================
%  Replication program for Section IV.D (simulations):
%  Julien Grenet, YingHua He, and Dorothea Kbler
%  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
%  The Journal of Political Economy
%  28 November 2021
%==========================================================================

% This is the main replication file for Section IV.D
% (Simulation Results)
% Required functions (in subfolder m/func): 
% - DA_func: Implements Gale-Shapley Program-proposing Deferred Acceptance algorithm
% - feasible_func: Determines each student's set of ex-post feasible programs
% - rank_by_group_func.m: Computes rank order by group
% - rank_feasible_func.m: Computes relative rank order of program among the student's feasible set
% - ParforProgressbar.m: To monitor progress of parallel for-loops
% - progressbar.m: Called by ParforProgressbar.m function
% - set_path.m: Set paths to the different subfolders

% Output (saved in the same folder as this .m file):
% - simulation_results.xlsx: Excel file containing summary statistics on
% ranking behavior and expected utility under the different mechanisms

clear

if exist('set_path.m', 'file') == 2
    set_path
else 
    error('ERROR: specify path to folder containing replication files in change_directory.m and execute script')  
end

%==========================================================================
% SET SIMULATION PARAMETERS
%==========================================================================

% S: number of Monte Carlo samples
S = 10000;

%==========================================================================
% IMPORT SIMULATION DATA
%==========================================================================

% Read simulation data (.csv file)
DATA = readtable(fullfile(dir_data,strcat('simulation_data','.csv')));

% Program capacity
pgm_capacity = unique(sortrows([DATA.pgm_id DATA.pgm_capacity],1),'rows');
pgm_capacity(pgm_capacity(:,2)==0,2)=1;
pgm_capacity = pgm_capacity(:,2);

% Students' Abitur percentile rank (between 0 and 1)
stu_abitur_rk = unique(sortrows([DATA.stu_id DATA.stu_abitur_rk],1),'rows');
stu_abitur_rk = stu_abitur_rk(:,2);

%==========================================================================
% FIXED PARAMETERS
%==========================================================================

% N: number of observations (77,835)
N = size(DATA.stu_id,1);

% I: number of students (21,711)
I = numel(unique(DATA.stu_id));
list_stu = (1:I)';
stu_id =  DATA.stu_id;

% J: number of programs (376)
J = numel(unique(DATA.pgm_id));
pgm_id =  DATA.pgm_id;

%%% STUDENTS' SCORES 

% Generate students' score for each program (I*J matrix)
rng(4);
% eta: Random component of students' score
eta = rand(N,1);
% Student scores: weighted average of Abitur percentile rank and random component
stu_scores = 0.5*stu_abitur_rk(stu_id) + 0.5*eta;

%%% PROGRAMS' RANKING OF STUDENTS

% Program preferences: (J,I) matrix where value (j,i) is program j's (inverse) ranking of student i (0 if unranked)
[stu_ranks, stu_invranks] = rank_by_group_func(pgm_id,stu_scores);

% Convert programs' rankings to sparse matrix
pgm_pref = sparse(pgm_id, stu_id, stu_invranks);
clear stu_invranks;

%%% EARLY OFFERS

% Determine which students receive early offer / no early offer
EO = (stu_ranks <= pgm_capacity(pgm_id));
clear stu_ranks;

% number of early offers received by each student
stu_nb_EO = accumarray(stu_id, EO, [], @sum);
nb_EO = stu_nb_EO(stu_id);
clear stu_nb_EO;

% Predicted utility under (EO=0/1,FEO=0/1): used to compute students' ranking behavior
V_Fullinfo = DATA.V_Fullinfo;
V_Fullinfo_se = DATA.V_Fullinfo_se;

% Convert vectors to short form
[~,idx]=ismember(unique(DATA.stu_id),DATA.stu_id);
stu_length_init_rol = DATA.stu_length_init_rol(idx);
stu_n_feasible_ext = DATA.stu_n_feasible_ext(idx);
clear idx;

%==========================================================================
% SIMULATE RANKING BEHAVIOR AND MATCHING OUTCOME UNDER ALTERNATIVE MECHANISMS
%==========================================================================

% Pre-allocate utility of matching outcome under alternative mechanisms
[U_match_DA, U_match_MDA, U_match_BMDA, U_match_Fullinfo]  = deal(NaN(I,S));
% Pre-allocate program id of matching outcome under alternative mechanisms
[id_match_DA, id_match_MDA, id_match_BMDA, id_match_Fullinfo]  = deal(NaN(I,S));
% Pre-allocate utility of worse program under full information
U_worse_Fullinfo = NaN(I,S);
% Pre-allocate rank-ordered lists under alternative mechanisms
[ROL_DA, ROL_MDA, ROL_BMDA, ROL_Fullinfo]  = deal(NaN(N,S));
% Pre-allocate inverse rank-ordered lists under alternative mechanisms
[ROLinv_DA, ROLinv_MDA, ROLinv_BMDA, ROLinv_Fullinfo]  = deal(NaN(N,S));
% Pre-allocate ex-post feasibility of programs
[Feasible_DA, Feasible_MDA, Feasible_BMDA, Feasible_Fullinfo]  = deal(NaN(N,S));

% Array with all applications of students (for determining which programs
% are learned)

% Start with all feasible programs
feas_applications = [stu_id pgm_id ones(N,1) DATA.stu_length_init_rol]; 

% Missing applications
% Students with non-feasible applications
stu_with_nonfeas = [unique(stu_id), stu_length_init_rol - stu_n_feasible_ext + 1]; % outside option is added
stu_with_nonfeas = stu_with_nonfeas(stu_with_nonfeas(:,2)>0,:);
nonfeas_applications = repelem(stu_with_nonfeas(:,1),stu_with_nonfeas(:,2));
clear stu_with_nonfeas;
% Assign ad-hoc program ids to non-feasible applications
nb_nonfeas = size(nonfeas_applications,1);
nonfeas_applications = [nonfeas_applications, 998+(1:nb_nonfeas)', zeros(nb_nonfeas,1)];
nonfeas_applications = [nonfeas_applications, stu_length_init_rol(nonfeas_applications(:,1),:)];

% All applications : stu_id | pgm_id | feas | stu_length_init_rol_exp
all_applications = [feas_applications; nonfeas_applications];
NN = size(all_applications,1);
% split
stu_id_exp = all_applications(:,1);
pgm_id_exp = all_applications(:,2);
feas_exp = all_applications(:,3);
stu_length_init_rol_exp = all_applications(:,4);

clear all_applications feas_applications nonfeas_applications;

% Construct a ParforProgressbar object
ppm = ParforProgressbar(S);

% Loop over MC samples
parfor ss = 1:S
    
    [U_match_DA_ss, U_match_MDA_ss, U_match_BMDA_ss, U_match_Fullinfo_ss]  = deal(NaN(I,1));

    % Idiosyncratic components of preferences in MC sample (assumed to be uncorrelated for now)
    rng(ss,'twister')
    
    % Idisyncratic component of utility under full information
    E_ij_Fullinfo_ss = -log(-log(rand(N,1)));   
    % Idisyncratic component of utility under no information
    E_ij_Noinfo_ss = -log(-log(rand(N,1)));   
    
    % U_Fullinfo: Utility under full information
    U_Fullinfo = V_Fullinfo + E_ij_Fullinfo_ss;
    
    % U_noinfo: Utility under no information
    U_Noinfo = normrnd(V_Fullinfo,V_Fullinfo_se)+ E_ij_Noinfo_ss;
   
    % ROL/inverse ROL under full information
    [ROL_Fullinfo_ss, ROLinv_Fullinfo_ss] = rank_by_group_func(stu_id,U_Fullinfo);  
  
    % Random first early offer
    U_random = rand(N,1);
    [~, ROLinv_random] = rank_by_group_func(stu_id,U_random);  

    % Most preferred early offer
    [invorder_EO_ss, ~] = rank_by_group_func(stu_id,EO.*ROLinv_random);
    invorder_EO_ss = invorder_EO_ss.*EO;
    order_EO_ss = (nb_EO - invorder_EO_ss+1).*EO;
    FEO_ss  = (order_EO_ss == 1);
    EO_notfirst_ss = EO - FEO_ss;
    % Expanded versions
    EO_exp = [EO; zeros(nb_nonfeas,1)];
    order_EO_exp_ss = [order_EO_ss; zeros(nb_nonfeas,1)];
    invorder_EO_exp_ss = [invorder_EO_ss; zeros(nb_nonfeas,1)];
    
    % LEARNING
    
    % DA -> randomly learn half of the programs (rounded up to the next
    % lower integer)
    % Randomly order all applications
    rand_DA = rand(NN,1);
    [rk_learn_DA, ~] = rank_by_group_func(stu_id_exp, rand_DA);
    % Learn half
    has_learned_DA = rk_learn_DA<= floor(stu_length_init_rol_exp./2);
    % Restrict to feasible programs
    has_learned_DA = has_learned_DA(feas_exp==1,:);

    % MDA -> Learn half with priority to FEO, then EO (in random order)
    rand_MDA = rand_DA;
    MDA_init = [stu_id_exp pgm_id_exp order_EO_exp_ss invorder_EO_exp_ss rand_MDA (1:NN)'];
    MDA_sorted_EO = sortrows(MDA_init,[1 -4 -5]);
    MDA_sorted_not_EO = sortrows(MDA_init,[1 -5]);
    MDA_learning = [];
    EO_order_id = 0;
    for oo = 1:13 % loop over programs in ROL
        learned_oo = [];
        learned_oo_v2 = [];
        forbidden = [];
        stu_forbidden = [];
        % if odd -> search for early offers
        if rem(oo,2) ~= 0   
            EO_order_id = EO_order_id + 1;
            % If learns from EO list
            [~,out_first_odd,~] = unique(MDA_sorted_EO(:,1), 'first');
            learned_oo  = MDA_sorted_EO(out_first_odd,:);
            % If does not learn from EO list
            if oo>=3
                [~,out_first_odd_v2,~] = unique(MDA_sorted_not_EO(:,1), 'first');
                learned_oo_v2 = MDA_sorted_not_EO(out_first_odd_v2,:); 
                % Identify student who should not learn from v1 and remove them
                forbidden = learned_oo(:,3)>EO_order_id;
                stu_forbidden = learned_oo(forbidden,1);
                learned_oo(forbidden,:) = [];
                % Keep records from these students in v2
                learned_oo_v2 = learned_oo_v2(ismember(learned_oo_v2(:,1), stu_forbidden),:);
                % Concatenate results
                learned_oo = vertcat(learned_oo,learned_oo_v2);
            end
        % if even 
        elseif rem(oo,2) == 0
            [~,out_first_even,~] = unique(MDA_sorted_not_EO(:,1), 'first');
            learned_oo = MDA_sorted_not_EO(out_first_even,:);                  
        end
        % if student has learned early offer than has not yet arrived,
        % replace by learning from set unordered with respect to EO
        % identify students who have learned "forbidden" EO      
        if oo == 1
           MDA_learning = [learned_oo oo.*ones(size(learned_oo,1),1)];
        elseif oo>1
           MDA_learning = vertcat(MDA_learning, [learned_oo oo.*ones(size(learned_oo,1),1)]); 
        end
        MDA_sorted_EO = setdiff(MDA_sorted_EO,learned_oo,'rows','stable');
        MDA_sorted_not_EO = setdiff(MDA_sorted_not_EO,learned_oo,'rows','stable');
    end
    MDA_learning = sortrows(MDA_learning,6);    
    rk_learn_MDA = MDA_learning(:,7);
    % Learn half
    has_learned_MDA = rk_learn_MDA<= floor(stu_length_init_rol_exp./2);
    % Restrict to feasible programs
    has_learned_MDA = has_learned_MDA(feas_exp==1,:);
    
    % BM-DA -> Learn half with priority to EO in order of random order
    % under DA
    rand_BMDA = rand_DA;
    rand_BMDA = EO_exp.*10 + rand_BMDA;
    [rk_learn_BMDA, ~] = rank_by_group_func(stu_id_exp, rand_BMDA);
    % Learn half
    has_learned_BMDA = rk_learn_BMDA<= floor(stu_length_init_rol_exp./2);
    % Restrict to feasible programs
    has_learned_BMDA = has_learned_BMDA(feas_exp==1,:);
   
    %%% STUDENTS' RANKING OF PROGRAMS UNDER EACH MECHANISM
      
    U_DA = has_learned_DA.*U_Fullinfo + (1-has_learned_DA).*U_Noinfo;
    U_MDA = has_learned_MDA.*U_Fullinfo + (1-has_learned_MDA).*U_Noinfo;
    U_BMDA = has_learned_BMDA.*U_Fullinfo + (1-has_learned_BMDA).*U_Noinfo;
     
    % Students' ROLs/inverse ROLs
    [ROL_DA_ss, ROLinv_DA_ss] = rank_by_group_func(stu_id,U_DA);   
    [ROL_MDA_ss, ROLinv_MDA_ss] = rank_by_group_func(stu_id,U_MDA);
    [ROL_BMDA_ss, ROLinv_BMDA_ss] = rank_by_group_func(stu_id,U_BMDA);
 
    U_all = [stu_id, pgm_id, EO, FEO_ss, ...
             U_DA, U_MDA, U_BMDA, U_Fullinfo, ...
             ROL_DA_ss, ROL_MDA_ss, ROL_BMDA_ss, ROL_Fullinfo_ss];        
         
    % Utility of worse program (evaluated under full information)
    U_worse_Fullinfo(:,ss) =  U_Fullinfo(ROLinv_Fullinfo_ss==1,:);
    
    % Students' preferences (J*I) where value (j,i) is student i's inverse ranking of program j (0 if unranked)
    stu_pref_DA = sparse(pgm_id, stu_id, ROLinv_DA_ss);
    stu_pref_MDA = sparse(pgm_id, stu_id, ROLinv_MDA_ss);
    stu_pref_BMDA = sparse(pgm_id, stu_id, ROLinv_BMDA_ss);
    stu_pref_Fullinfo = sparse(pgm_id, stu_id, ROLinv_Fullinfo_ss);
    
    % Run program-proposing DA for each mechanism
    [assigned_DA_ss, matched_DA_ss] = DA_func(stu_pref_DA, pgm_pref, pgm_capacity);
    [assigned_MDA_ss, matched_MDA_ss] = DA_func(stu_pref_MDA, pgm_pref, pgm_capacity);
    [assigned_BMDA_ss, matched_BMDA_ss] = DA_func(stu_pref_BMDA, pgm_pref, pgm_capacity);
    [assigned_Fullinfo_ss, matched_Fullinfo_ss] = DA_func(stu_pref_Fullinfo, pgm_pref, pgm_capacity);
   
    % Program cutoffs
    % Create sparse matrix of scores
    stu_scores_sparse = sparse(pgm_id, stu_id, stu_scores);   
    Feasible_DA_ss = feasible_func(stu_scores_sparse, matched_DA_ss, stu_scores, pgm_id, pgm_capacity);
    Feasible_MDA_ss = feasible_func(stu_scores_sparse, matched_MDA_ss, stu_scores, pgm_id, pgm_capacity);
    Feasible_BMDA_ss = feasible_func(stu_scores_sparse, matched_BMDA_ss, stu_scores, pgm_id, pgm_capacity);
    Feasible_Fullinfo_ss = feasible_func(stu_scores_sparse, matched_Fullinfo_ss, stu_scores, pgm_id, pgm_capacity);
 
    % SAVE ROLs
    ROL_DA(:,ss) = ROL_DA_ss;
    ROL_MDA(:,ss ) = ROL_MDA_ss;    
    ROL_BMDA(:,ss ) = ROL_BMDA_ss;    
    ROL_Fullinfo(:,ss ) = ROL_Fullinfo_ss;    
 
    ROLinv_DA(:,ss) = ROLinv_DA_ss;
    ROLinv_MDA(:,ss ) = ROLinv_MDA_ss;    
    ROLinv_BMDA(:,ss ) = ROLinv_BMDA_ss;    
    ROLinv_Fullinfo(:,ss ) = ROLinv_Fullinfo_ss;    
   
    % SAVE Feasible programs
    Feasible_DA(:,ss) = Feasible_DA_ss;
    Feasible_MDA(:,ss) = Feasible_MDA_ss;
    Feasible_BMDA(:,ss) = Feasible_BMDA_ss;
    Feasible_Fullinfo(:,ss) = Feasible_Fullinfo_ss;
   
    % EVALUATE UTILITY OF MATCHING OUTCOME UNDER FULL INFORMATION
    sparse_U_Fullinfo = sparse(stu_id,pgm_id,U_Fullinfo);
    
    U_match_func = @(assigned) (sparse_U_Fullinfo(sub2ind([I J],list_stu(assigned>0),assigned(assigned>0))));
    
    % (1) DA
    id_match_DA(:,ss) = assigned_DA_ss;
    U_match_DA_ss(assigned_DA_ss>0,:) = U_match_func(assigned_DA_ss);
    U_match_DA(:,ss) = U_match_DA_ss; 
    
    % (2) M-DA
    id_match_MDA(:,ss) = assigned_MDA_ss;
    U_match_MDA_ss(assigned_MDA_ss>0,:) = U_match_func(assigned_MDA_ss);
    U_match_MDA(:,ss) = U_match_MDA_ss;
    
    % (3) BM-DA
    id_match_BMDA(:,ss) = assigned_BMDA_ss;
    U_match_BMDA_ss(assigned_BMDA_ss>0,:) = U_match_func(assigned_BMDA_ss);
    U_match_BMDA(:,ss) = U_match_BMDA_ss;

    % (4) Full information
    id_match_Fullinfo(:,ss) = assigned_Fullinfo_ss;
    U_match_Fullinfo_ss(assigned_Fullinfo_ss>0,:) = U_match_func(assigned_Fullinfo_ss);
    U_match_Fullinfo(:,ss) = U_match_Fullinfo_ss;
     
    % increment counter to track progress
    pause(100/S);
    ppm.increment();
    
end

% Delete the progress handle when the parfor loop is done (otherwise the timer that keeps updating the progress might not stop).
delete(ppm);

disp('done')

%==========================================================================
% STATISTICS ON RANKING BEHAVIOR AND EXPECTED UTILITY
%==========================================================================

% Concatenate utility matrices: I*S*4
U_match = cat(3,U_match_DA,U_match_MDA,U_match_BMDA,U_match_Fullinfo);
ROLinvs = cat(3,ROLinv_DA,ROLinv_MDA,ROLinv_BMDA,ROLinv_Fullinfo);
Feasibles = cat(3,Feasible_DA,Feasible_MDA,Feasible_BMDA,Feasible_Fullinfo);

% A. RANKING BEHAVIOR
% Proportion of students ranking ex-post feasible programs in the order of
% full information preferences

same_FeasROL_as_Fullinfo_3D = NaN(I,S,3);
for ii = 1:I % Loop over students
    nb_feas_ii = stu_n_feasible_ext(ii);
    stu_id_ii = (stu_id==ii);
    for mm = 1:3 % Loop over mechanisms
        ROLinv_mm_ii = squeeze(ROLinvs(stu_id_ii,:,mm));
        ROLinv_Fullinfo_ii = squeeze(ROLinv_Fullinfo(stu_id_ii,:));
        Feasible_mm_ii = squeeze(Feasibles(stu_id_ii,:,mm));    
        relranking_mm_ii = rank_feasible_func(ROLinv_mm_ii,Feasible_mm_ii);
        relranking_Fullinfo_ii =  rank_feasible_func(ROLinv_Fullinfo_ii,Feasible_mm_ii);
        compare_FeasROLs_mm =  (relranking_mm_ii == relranking_Fullinfo_ii);
        same_FeasROL_as_Fullinfo_3D(ii,:,mm) = sum(compare_FeasROLs_mm,1) == nb_feas_ii.*ones(1,S);
    end
end

clear ROLs ROLinvs Feasibles ii mm nb_feas_ii stu_id_ii ROLinv_mm_ii ROLinv_Fullinfo_ii Feasible_mm_ii...
    relranking_mm_ii relranking_Fullinfo_ii compare_FeasROLs_mm;

mean_same_FeasROL = squeeze(mean(mean(same_FeasROL_as_Fullinfo_3D,1,'omitnan'),2));

Ranking_Behavior = table((1:3)',string({'DA','M-DA','BM-DA'}'), mean_same_FeasROL, ...
                         'VariableNames',{'id','mechanism','same_feas_rol'});

clear same_FeasROL_as_Fullinfo_3D mean_same_FeasROL; 

% B. EXPECTED UTILITY
% Expected utility of matching outcome under the different mechanisms

% For unassigned students, replace utility of matching outcome by utility
% of worse program (under full information) minus 1 s.d. of epsilon
U_match_replace = U_match;
U_worse_Fullinfo_rep = repmat(U_worse_Fullinfo,[1 1 5]);
U_match_replace(isnan(U_match_replace)) = U_worse_Fullinfo_rep(isnan(U_match_replace))- 1.*(pi/sqrt(6));

% Expected utility of each student under the different mechanisms
EU_match_replace = permute(mean(U_match_replace,2),[1 3 2]);

select_stu = ones(I,1)==1;
    
% Pairwise comparison of expected utility under the different mechanisms
EU_better = NaN(4,4);
EU_same = NaN(4,4);
for m1=1:4 % loop over mechanism 1
   for m2=1:4 % loop over mechanism 2
       EU_better(m1,m2) = mean(EU_match_replace(select_stu,m2) > EU_match_replace(select_stu,m1));
       EU_same(m1,m2) = mean(EU_match_replace(select_stu,m2) == EU_match_replace(select_stu,m1));
   end
end

clear m1 m2 EU_match_replace select_stu;

FullInfo_vs_DA = table(1,{'DA'}, {'Fullinfo'}, EU_better(4,1), EU_same(4,1), EU_better(1,4), ...
                        'VariableNames',{'id','baseline','comparison','worse','same','better'});
MDA_vs_DA = {2,{'DA'}, {'MDA'}, EU_better(2,1), EU_same(2,1), EU_better(1,2)};
BMDA_vs_DA = {3,{'DA'}, {'BMDA'}, EU_better(3,1), EU_same(3,1), EU_better(1,3)};
BMDA_vs_MDA = {4,{'MDA'}, {'BMDA'}, EU_better(3,2), EU_same(3,2), EU_better(2,3)};
Expected_Utility = [FullInfo_vs_DA; MDA_vs_DA; BMDA_vs_DA; BMDA_vs_MDA];

clear FullInfo_vs_DA MDA_vs_DA BMDA_vs_DA BMDA_vs_MDA;            

%==========================================================================
% EXPORT RESULTS TO EXCEL FILE
%==========================================================================

Sim_Param = array2table( [{'S'} num2str(S); {'I'} num2str(I)], 'VariableNames',{'Parameter','Value'});
path_xlsx = fullfile(dir_fig,'simulation_results.xlsx');

if isfile(path_xlsx)
    delete(path_xlsx)
end

writetable(Ranking_Behavior,path_xlsx,'Sheet','ranking_behavior')   
writetable(Expected_Utility,path_xlsx,'Sheet','expected_utility')  
writetable(Sim_Param,path_xlsx,'Sheet','simulation_parameters') 

disp('Results exported')
